=encoding utf8

=head1 NAME

Locale::CLDR::Locales::Hy - Package for language Armenian

=cut

package Locale::CLDR::Locales::Hy;
# This file auto generated from Data\common\main\hy.xml
#	on Thu 29 Feb  5:43:51 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.44.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Root');
has 'valid_algorithmic_formats' => (
    is => 'ro',
    isa => ArrayRef,
    init_arg => undef,
    default => sub {[ 'spellout-numbering-year','spellout-numbering','spellout-cardinal' ]},
);

has 'algorithmic_number_format_data' => (
    is => 'ro',
    isa => HashRef,
    init_arg => undef,
    default => sub {
        use bigfloat;
        return {
		'spellout-cardinal' => {
			'public' => {
				'-x' => {
					divisor => q(1),
					rule => q(հանած →→),
				},
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(զրո),
				},
				'x.x' => {
					divisor => q(1),
					rule => q(←← ստորակել →→),
				},
				'1' => {
					base_value => q(1),
					divisor => q(1),
					rule => q(մեկ),
				},
				'2' => {
					base_value => q(2),
					divisor => q(1),
					rule => q(երկու),
				},
				'3' => {
					base_value => q(3),
					divisor => q(1),
					rule => q(երեք),
				},
				'4' => {
					base_value => q(4),
					divisor => q(1),
					rule => q(չորս),
				},
				'5' => {
					base_value => q(5),
					divisor => q(1),
					rule => q(հինգ),
				},
				'6' => {
					base_value => q(6),
					divisor => q(1),
					rule => q(վեց),
				},
				'7' => {
					base_value => q(7),
					divisor => q(1),
					rule => q(յոթ),
				},
				'8' => {
					base_value => q(8),
					divisor => q(1),
					rule => q(ութ),
				},
				'9' => {
					base_value => q(9),
					divisor => q(1),
					rule => q(ինը),
				},
				'10' => {
					base_value => q(10),
					divisor => q(10),
					rule => q(տասն[­→→]),
				},
				'20' => {
					base_value => q(20),
					divisor => q(10),
					rule => q(քսան[­→→]),
				},
				'30' => {
					base_value => q(30),
					divisor => q(10),
					rule => q(երեսուն[­→→]),
				},
				'40' => {
					base_value => q(40),
					divisor => q(10),
					rule => q(քառասուն[­→→]),
				},
				'50' => {
					base_value => q(50),
					divisor => q(10),
					rule => q(հիսուն[­→→]),
				},
				'60' => {
					base_value => q(60),
					divisor => q(10),
					rule => q(վաթսուն[­→→]),
				},
				'70' => {
					base_value => q(70),
					divisor => q(10),
					rule => q(յոթանասուն[­→→]),
				},
				'80' => {
					base_value => q(80),
					divisor => q(10),
					rule => q(ութսուն[­→→]),
				},
				'90' => {
					base_value => q(90),
					divisor => q(10),
					rule => q(իննասուն[­→→]),
				},
				'100' => {
					base_value => q(100),
					divisor => q(100),
					rule => q(←←­հարյուր[ →→]),
				},
				'1000' => {
					base_value => q(1000),
					divisor => q(1000),
					rule => q(←← հազար[ →→]),
				},
				'1000000' => {
					base_value => q(1000000),
					divisor => q(1000000),
					rule => q(←← միլիօն[ →→]),
				},
				'1000000000' => {
					base_value => q(1000000000),
					divisor => q(1000000000),
					rule => q(←← միլիար[ →→]),
				},
				'1000000000000' => {
					base_value => q(1000000000000),
					divisor => q(1000000000000),
					rule => q(←← բիլիօն[ →→]),
				},
				'1000000000000000' => {
					base_value => q(1000000000000000),
					divisor => q(1000000000000000),
					rule => q(←← բիլիար[ →→]),
				},
				'1000000000000000000' => {
					base_value => q(1000000000000000000),
					divisor => q(1000000000000000000),
					rule => q(=#,##0=),
				},
				'max' => {
					base_value => q(1000000000000000000),
					divisor => q(1000000000000000000),
					rule => q(=#,##0=),
				},
			},
		},
		'spellout-numbering' => {
			'public' => {
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-cardinal=),
				},
				'max' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-cardinal=),
				},
			},
		},
		'spellout-numbering-year' => {
			'public' => {
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-numbering=),
				},
				'x.x' => {
					divisor => q(1),
					rule => q(=0.0=),
				},
				'max' => {
					divisor => q(1),
					rule => q(=0.0=),
				},
			},
		},
    } },
);

has 'display_name_language' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		 sub {
			 my %languages = (
				'aa' => 'աֆարերեն',
 				'ab' => 'աբխազերեն',
 				'ace' => 'աչեհերեն',
 				'ach' => 'աչոլի',
 				'ada' => 'ադանգմերեն',
 				'ady' => 'ադիղերեն',
 				'aeb' => 'թունիսական արաբերեն',
 				'af' => 'աֆրիկաանս',
 				'agq' => 'աղեմ',
 				'ain' => 'այներեն',
 				'ak' => 'աքան',
 				'akk' => 'աքքադերեն',
 				'ale' => 'ալեութերեն',
 				'alt' => 'հարավային ալթայերեն',
 				'am' => 'ամհարերեն',
 				'an' => 'արագոներեն',
 				'ang' => 'հին անգլերեն',
 				'ann' => 'օբոլո',
 				'anp' => 'անգիկա',
 				'ar' => 'արաբերեն',
 				'ar_001' => 'արդի ընդհանուր արաբերեն',
 				'arc' => 'արամեերեն',
 				'arn' => 'մապուչի',
 				'arp' => 'արապահո',
 				'arq' => 'ալժիրական արաբերեն',
 				'ars' => 'նեջդի արաբերեն',
 				'arz' => 'եգիպտական արաբերեն',
 				'as' => 'ասամերեն',
 				'asa' => 'ասու',
 				'ase' => 'ամերիկյան ժեստերի լեզու',
 				'ast' => 'աստուրերեն',
 				'atj' => 'աթիկամեկ',
 				'av' => 'ավարերեն',
 				'awa' => 'ավադհի',
 				'ay' => 'այմարա',
 				'az' => 'ադրբեջաներեն',
 				'ba' => 'բաշկիրերեն',
 				'ban' => 'բալիերեն',
 				'bas' => 'բասաա',
 				'be' => 'բելառուսերեն',
 				'bem' => 'բեմբա',
 				'bez' => 'բենա',
 				'bg' => 'բուլղարերեն',
 				'bgc' => 'հարյանվի',
 				'bgn' => 'արևմտաբելուջիերեն',
 				'bho' => 'բհոպուրի',
 				'bi' => 'բիսլամա',
 				'bin' => 'բինի',
 				'bla' => 'սիկսիկա',
 				'bm' => 'բամբարա',
 				'bn' => 'բենգալերեն',
 				'bo' => 'տիբեթերեն',
 				'br' => 'բրետոներեն',
 				'brx' => 'բոդո',
 				'bs' => 'բոսնիերեն',
 				'bss' => 'աքուզ',
 				'bug' => 'բուգիերեն',
 				'byn' => 'բիլին',
 				'ca' => 'կատալաներեն',
 				'cay' => 'կայուգա',
 				'ccp' => 'չակմա',
 				'ce' => 'չեչեներեն',
 				'ceb' => 'սեբուերեն',
 				'cgg' => 'չիգա',
 				'ch' => 'չամոռո',
 				'chk' => 'տրուկերեն',
 				'chm' => 'մարի',
 				'cho' => 'չոկտո',
 				'chp' => 'չիպևայան',
 				'chr' => 'չերոկի',
 				'chy' => 'շայեն',
 				'ckb' => 'սորանի քրդերեն',
 				'ckb@alt=menu' => 'քրդերեն (սորանի)',
 				'ckb@alt=variant' => 'սորանի',
 				'clc' => 'չիլկոտիներեն',
 				'co' => 'կորսիկերեն',
 				'cop' => 'ղպտերեն',
 				'crg' => 'միչիֆ',
 				'crh' => 'ղրիմյան թուրքերեն',
 				'crj' => 'հարավ-արևելյան քրի',
 				'crk' => 'հարթավայրերի քրի',
 				'crl' => 'հյուսիս-արևելյան քրի',
 				'crm' => 'մուզ քրի',
 				'crr' => 'կարոլինական ալգոնկիներեն',
 				'crs' => 'սեյշելյան խառնակերտ ֆրանսերեն',
 				'cs' => 'չեխերեն',
 				'csw' => 'ճահճի քրի',
 				'cu' => 'սլավոներեն, եկեղեցական',
 				'cv' => 'չուվաշերեն',
 				'cy' => 'ուելսերեն',
 				'da' => 'դանիերեն',
 				'dak' => 'դակոտա',
 				'dar' => 'դարգիներեն',
 				'dav' => 'թաիթա',
 				'de' => 'գերմաներեն',
 				'de_AT' => 'ավստրիական գերմաներեն',
 				'de_CH' => 'շվեյցարական վերին գերմաներեն',
 				'dgr' => 'դոգրիբ',
 				'dje' => 'զարմա',
 				'doi' => 'դոգրի',
 				'dsb' => 'ստորին սորբերեն',
 				'dua' => 'դուալա',
 				'dv' => 'դիվեհի',
 				'dyo' => 'ջոլա-ֆոնյի',
 				'dz' => 'ջոնգքհա',
 				'dzg' => 'դազագա',
 				'ebu' => 'էմբու',
 				'ee' => 'էվե',
 				'efi' => 'էֆիկ',
 				'egy' => 'հին եգիպտերեն',
 				'eka' => 'էկաջուկ',
 				'el' => 'հունարեն',
 				'en' => 'անգլերեն',
 				'en_AU' => 'ավստրալիական անգլերեն',
 				'en_CA' => 'կանադական անգլերեն',
 				'en_GB' => 'բրիտանական անգլերեն',
 				'en_US' => 'ամերիկյան անգլերեն',
 				'eo' => 'էսպերանտո',
 				'es' => 'իսպաներեն',
 				'es_419' => 'լատինամերիկյան իսպաներեն',
 				'es_ES' => 'եվրոպական իսպաներեն',
 				'es_MX' => 'մեքսիկական իսպաներեն',
 				'et' => 'էստոներեն',
 				'eu' => 'բասկերեն',
 				'ewo' => 'էվոնդո',
 				'fa' => 'պարսկերեն',
 				'fa_AF' => 'դարի',
 				'ff' => 'ֆուլահ',
 				'fi' => 'ֆիններեն',
 				'fil' => 'ֆիլիպիներեն',
 				'fit' => 'տորնադելեն ֆիններեն',
 				'fj' => 'ֆիջիերեն',
 				'fo' => 'ֆարյորերեն',
 				'fon' => 'ֆոն',
 				'fr' => 'ֆրանսերեն',
 				'fr_CA' => 'կանադական ֆրանսերեն',
 				'fr_CH' => 'շվեյցարական ֆրանսերեն',
 				'frc' => 'քաջունական ֆրանսերեն',
 				'fro' => 'հին ֆրանսերեն',
 				'frr' => 'հյուսիսային ֆրիզերեն',
 				'frs' => 'արևելաֆրիզերեն',
 				'fur' => 'ֆրիուլիերեն',
 				'fy' => 'արևմտաֆրիզերեն',
 				'ga' => 'իռլանդերեն',
 				'gaa' => 'գայերեն',
 				'gag' => 'գագաուզերեն',
 				'gbz' => 'զրադաշտական դարի',
 				'gd' => 'շոտլանդական գաելերեն',
 				'gez' => 'գեեզ',
 				'gil' => 'կիրիբատի',
 				'gl' => 'գալիսերեն',
 				'gn' => 'գուարանի',
 				'goh' => 'հին վերին գերմաներեն',
 				'gor' => 'գորոնտալո',
 				'got' => 'գոթերեն',
 				'grc' => 'հին հունարեն',
 				'gsw' => 'շվեյցարական գերմաներեն',
 				'gu' => 'գուջարաթի',
 				'guc' => 'վայուու',
 				'guz' => 'գուսի',
 				'gv' => 'մեներեն',
 				'gwi' => 'գվիչին',
 				'ha' => 'հաուսա',
 				'hai' => 'հայդա',
 				'haw' => 'հավայիերեն',
 				'hax' => 'հարավային հայդա',
 				'he' => 'եբրայերեն',
 				'hi' => 'հինդի',
 				'hi_Latn@alt=variant' => 'հինգլիշ',
 				'hil' => 'հիլիգայնոն',
 				'hmn' => 'հմոնգ',
 				'hr' => 'խորվաթերեն',
 				'hsb' => 'վերին սորբերեն',
 				'hsn' => 'սյան չինարեն',
 				'ht' => 'խառնակերտ հայիթերեն',
 				'hu' => 'հունգարերեն',
 				'hup' => 'հուպա',
 				'hur' => 'հալքոմելեմ',
 				'hy' => 'հայերեն',
 				'hz' => 'հերերո',
 				'ia' => 'ինտերլինգուա',
 				'iba' => 'իբաներեն',
 				'ibb' => 'իբիբիո',
 				'id' => 'ինդոնեզերեն',
 				'ie' => 'ինտերլինգուե',
 				'ig' => 'իգբո',
 				'ii' => 'սիչուան',
 				'ikt' => 'արևմտականադական ինուկտիտուտ',
 				'ilo' => 'իլոկերեն',
 				'inh' => 'ինգուշերեն',
 				'io' => 'իդո',
 				'is' => 'իսլանդերեն',
 				'it' => 'իտալերեն',
 				'iu' => 'ինուկտիտուտ',
 				'ja' => 'ճապոներեն',
 				'jbo' => 'լոժբան',
 				'jgo' => 'նգոմբա',
 				'jmc' => 'մաշամե',
 				'jv' => 'ճավայերեն',
 				'ka' => 'վրացերեն',
 				'kab' => 'կաբիլերեն',
 				'kac' => 'կաչիներեն',
 				'kaj' => 'ջյու',
 				'kam' => 'կամբա',
 				'kbd' => 'կաբարդերեն',
 				'kcg' => 'տիապ',
 				'kde' => 'մակոնդե',
 				'kea' => 'կաբուվերդերեն',
 				'kfo' => 'կորո',
 				'kgp' => 'կաինգան',
 				'kha' => 'քասիերեն',
 				'khq' => 'կոյրա չինի',
 				'ki' => 'կիկույու',
 				'kj' => 'կուանյամա',
 				'kk' => 'ղազախերեն',
 				'kkj' => 'կակո',
 				'kl' => 'կալաալիսուտ',
 				'kln' => 'կալենջին',
 				'km' => 'քմերերեն',
 				'kmb' => 'կիմբունդու',
 				'kn' => 'կաննադա',
 				'ko' => 'կորեերեն',
 				'koi' => 'պերմյակ կոմիերեն',
 				'kok' => 'կոնկանի',
 				'kpe' => 'կպելլեերեն',
 				'kr' => 'կանուրի',
 				'krc' => 'կարաչայ-բալկարերեն',
 				'krl' => 'կարելերեն',
 				'kru' => 'կուրուխ',
 				'ks' => 'քաշմիրերեն',
 				'ksb' => 'շամբալա',
 				'ksf' => 'բաֆիա',
 				'ksh' => 'քյոլներեն',
 				'ku' => 'քրդերեն',
 				'kum' => 'կումիկերեն',
 				'kv' => 'կոմիերեն',
 				'kw' => 'կոռներեն',
 				'kwk' => 'կվակվալա',
 				'ky' => 'ղրղզերեն',
 				'la' => 'լատիներեն',
 				'lad' => 'լադինո',
 				'lag' => 'լանգի',
 				'lb' => 'լյուքսեմբուրգերեն',
 				'lez' => 'լեզգիերեն',
 				'lg' => 'գանդա',
 				'li' => 'լիմբուրգերեն',
 				'lil' => 'լիլուետ',
 				'lkt' => 'լակոտա',
 				'ln' => 'լինգալա',
 				'lo' => 'լաոսերեն',
 				'lou' => 'լուիզիանական կրեոլերեն',
 				'loz' => 'լոզի',
 				'lrc' => 'հյուսիսային լուրիերեն',
 				'lsm' => 'սաամերեն',
 				'lt' => 'լիտվերեն',
 				'lu' => 'լուբա-կատանգա',
 				'lua' => 'լուբա-լուլուա',
 				'lun' => 'լունդա',
 				'luo' => 'լուո',
 				'lus' => 'միզո',
 				'luy' => 'լույա',
 				'lv' => 'լատվիերեն',
 				'mad' => 'մադուրերեն',
 				'mag' => 'մագահի',
 				'mai' => 'մայթիլի',
 				'mak' => 'մակասարերեն',
 				'mas' => 'մասաի',
 				'mdf' => 'մոկշայերեն',
 				'men' => 'մենդե',
 				'mer' => 'մերու',
 				'mfe' => 'մորիսյեն',
 				'mg' => 'մալգաշերեն',
 				'mgh' => 'մաքուա-մետտո',
 				'mgo' => 'մետա',
 				'mh' => 'մարշալերեն',
 				'mi' => 'մաորի',
 				'mic' => 'միկմակ',
 				'min' => 'մինանգկաբաու',
 				'mk' => 'մակեդոներեն',
 				'ml' => 'մալայալամ',
 				'mn' => 'մոնղոլերեն',
 				'mni' => 'մանիպուրի',
 				'moe' => 'իննու-այմուն',
 				'moh' => 'մոհավք',
 				'mos' => 'մոսսի',
 				'mr' => 'մարաթի',
 				'mrj' => 'արևմտամարիերեն',
 				'ms' => 'մալայերեն',
 				'mt' => 'մալթայերեն',
 				'mua' => 'մունդանգ',
 				'mul' => 'բազմալեզու',
 				'mus' => 'մասքոջի',
 				'mwl' => 'միրանդերեն',
 				'my' => 'բիրմայերեն',
 				'myv' => 'էրզյա',
 				'mzn' => 'մազանդարաներեն',
 				'na' => 'նաուրու',
 				'nap' => 'նեապոլերեն',
 				'naq' => 'նամա',
 				'nb' => 'գրքային նորվեգերեն',
 				'nd' => 'հյուսիսային նդեբելե',
 				'nds' => 'ստորին գերմաներեն',
 				'nds_NL' => 'ստորին սաքսոներեն',
 				'ne' => 'նեպալերեն',
 				'new' => 'նեվարերեն',
 				'ng' => 'նդոնգա',
 				'nia' => 'նիասերեն',
 				'niu' => 'նիուերեն',
 				'nl' => 'հոլանդերեն',
 				'nl_BE' => 'ֆլամանդերեն',
 				'nmg' => 'կվասիո',
 				'nn' => 'նոր նորվեգերեն',
 				'nnh' => 'նգիեմբուն',
 				'no' => 'նորվեգերեն',
 				'nog' => 'նոգայերեն',
 				'non' => 'հին նորվեգերեն',
 				'nqo' => 'նկո',
 				'nr' => 'հարավային նդեբելե',
 				'nso' => 'հյուսիսային սոթո',
 				'nus' => 'նուեր',
 				'nv' => 'նավախո',
 				'ny' => 'նյանջա',
 				'nyn' => 'նյանկոլե',
 				'oc' => 'օքսիտաներեն',
 				'oj' => 'օջիբվա',
 				'ojb' => 'հյուսիս-արևմտյան օջիբվե',
 				'ojc' => 'կենտրոնական օջիբվե',
 				'ojs' => 'օջի քրի',
 				'ojw' => 'արևմտյան օջիբվե',
 				'oka' => 'օկանագան',
 				'om' => 'օրոմո',
 				'or' => 'օրիյա',
 				'os' => 'օսերեն',
 				'osa' => 'օսեյջ',
 				'ota' => 'օսմաներեն',
 				'pa' => 'փենջաբերեն',
 				'pag' => 'պանգասինաներեն',
 				'pal' => 'պահլավերեն',
 				'pam' => 'պամպանգաերեն',
 				'pap' => 'պապյամենտո',
 				'pau' => 'պալաուերեն',
 				'pcd' => 'պիկարդերեն',
 				'pcm' => 'նիգերիական փիջին',
 				'pdc' => 'փենսիլվանական գերմաներեն',
 				'pdt' => 'պլատագերմաներեն',
 				'peo' => 'հին պարսկերեն',
 				'pfl' => 'պալատինյան գերմաներեն',
 				'phn' => 'փյունիկերեն',
 				'pi' => 'պալի',
 				'pis' => 'փիջին',
 				'pl' => 'լեհերեն',
 				'pms' => 'պիեմոնտերեն',
 				'pnt' => 'պոնտերեն',
 				'pon' => 'պոնպեերեն',
 				'pqm' => 'մալեսիտ-պասամակվոդի',
 				'prg' => 'պրուսերեն',
 				'pro' => 'հին պրովանսերեն',
 				'ps' => 'փուշթու',
 				'pt' => 'պորտուգալերեն',
 				'pt_BR' => 'բրազիլական պորտուգալերեն',
 				'pt_PT' => 'եվրոպական պորտուգալերեն',
 				'qu' => 'կեչուա',
 				'quc' => 'քիչե',
 				'raj' => 'ռաջաստաներեն',
 				'rap' => 'ռապանուի',
 				'rar' => 'ռարոտոնգաներեն',
 				'rgn' => 'ռոմանիոլերեն',
 				'rhg' => 'ռոհինջա',
 				'rif' => 'ռիֆերեն',
 				'rm' => 'ռոմանշերեն',
 				'rn' => 'ռունդի',
 				'ro' => 'ռումիներեն',
 				'ro_MD' => 'մոլդովերեն',
 				'rof' => 'ռոմբո',
 				'rom' => 'ռոմաներեն',
 				'rtm' => 'ռոտուման',
 				'ru' => 'ռուսերեն',
 				'rue' => 'ռուսիներեն',
 				'rug' => 'ռովիանա',
 				'rup' => 'արոմաներեն',
 				'rw' => 'կինյառուանդա',
 				'rwk' => 'ռվա',
 				'sa' => 'սանսկրիտ',
 				'sad' => 'սանդավե',
 				'sah' => 'յակուտերեն',
 				'saq' => 'սամբուրու',
 				'sat' => 'սանտալի',
 				'sba' => 'նգամբայ',
 				'sbp' => 'սանգու',
 				'sc' => 'սարդիներեն',
 				'scn' => 'սիցիլիերեն',
 				'sco' => 'շոտլանդերեն',
 				'sd' => 'սինդհի',
 				'sdh' => 'հարավային քրդերեն',
 				'se' => 'հյուսիսային սաամի',
 				'seh' => 'սենա',
 				'ses' => 'կոյրաբորո սեննի',
 				'sg' => 'սանգո',
 				'sga' => 'հին իռլանդերեն',
 				'sh' => 'սերբա-խորվաթերեն',
 				'shi' => 'տաշելհիթ',
 				'shn' => 'շաներեն',
 				'si' => 'սինհալերեն',
 				'sk' => 'սլովակերեն',
 				'sl' => 'սլովեներեն',
 				'slh' => 'հարավային լուշուցիդ',
 				'sm' => 'սամոաերեն',
 				'sma' => 'հարավային սաամի',
 				'smj' => 'լուլե սաամի',
 				'smn' => 'ինարի սաամի',
 				'sms' => 'սկոլտ սաամի',
 				'sn' => 'շոնա',
 				'snk' => 'սոնինկե',
 				'so' => 'սոմալիերեն',
 				'sq' => 'ալբաներեն',
 				'sr' => 'սերբերեն',
 				'srn' => 'սրանան տոնգո',
 				'ss' => 'սվազերեն',
 				'ssy' => 'սահոերեն',
 				'st' => 'հարավային սոթո',
 				'str' => 'սթրեյթս սալիշերեն',
 				'su' => 'սունդաներեն',
 				'suk' => 'սուկումա',
 				'sv' => 'շվեդերեն',
 				'sw' => 'սուահիլի',
 				'sw_CD' => 'կոնգոյի սուահիլի',
 				'swb' => 'կոմորերեն',
 				'syr' => 'ասորերեն',
 				'ta' => 'թամիլերեն',
 				'tce' => 'հարավային թուտչոնե',
 				'tcy' => 'տուլու',
 				'te' => 'թելուգու',
 				'tem' => 'տեմնե',
 				'teo' => 'տեսո',
 				'ter' => 'տերենո',
 				'tet' => 'տետում',
 				'tg' => 'տաջիկերեն',
 				'tgx' => 'թագիշ',
 				'th' => 'թայերեն',
 				'tht' => 'թալթան',
 				'ti' => 'տիգրինյա',
 				'tig' => 'տիգրե',
 				'tiv' => 'տիվերեն',
 				'tk' => 'թուրքմեներեն',
 				'tkl' => 'տոկելաու',
 				'tkr' => 'ցախուր',
 				'tl' => 'տագալերեն',
 				'tlh' => 'կլինգոն',
 				'tli' => 'տլինգիտ',
 				'tly' => 'թալիշերեն',
 				'tmh' => 'տամաշեկ',
 				'tn' => 'ցվանա',
 				'to' => 'տոնգերեն',
 				'tok' => 'տոկիպոնա',
 				'tpi' => 'տոկ փիսին',
 				'tr' => 'թուրքերեն',
 				'tru' => 'տուրոյո',
 				'trv' => 'տարոկո',
 				'ts' => 'ցոնգա',
 				'tsd' => 'ցակոներեն',
 				'tsi' => 'ցիմշյան',
 				'tt' => 'թաթարերեն',
 				'ttm' => 'հյուսիսային թուտչոնե',
 				'tum' => 'տումբուկա',
 				'tvl' => 'թուվալուերեն',
 				'tw' => 'տուի',
 				'twq' => 'տասավաք',
 				'ty' => 'թաիտերեն',
 				'tyv' => 'տուվերեն',
 				'tzm' => 'կենտրոնատլասյան թամազիղտ',
 				'udm' => 'ուդմուրտերեն',
 				'ug' => 'ույղուրերեն',
 				'uga' => 'ուգարիտերեն',
 				'uk' => 'ուկրաիներեն',
 				'umb' => 'ումբունդու',
 				'und' => 'անհայտ լեզու',
 				'ur' => 'ուրդու',
 				'uz' => 'ուզբեկերեն',
 				'vai' => 'վաի',
 				've' => 'վենդա',
 				'vec' => 'վենետերեն',
 				'vep' => 'վեպսերեն',
 				'vi' => 'վիետնամերեն',
 				'vls' => 'արևմտաֆլամանդերեն',
 				'vo' => 'վոլապյուկ',
 				'vot' => 'վոդերեն',
 				'vro' => 'վորո',
 				'vun' => 'վունջո',
 				'wa' => 'վալոներեն',
 				'wae' => 'վալսերեն',
 				'wal' => 'վոլայտա',
 				'war' => 'վարայերեն',
 				'was' => 'վաշո',
 				'wbp' => 'վարլպիրի',
 				'wo' => 'վոլոֆ',
 				'wuu' => 'վու չինարեն',
 				'xal' => 'կալմիկերեն',
 				'xh' => 'քոսա',
 				'xog' => 'սոգա',
 				'yao' => 'յաո',
 				'yap' => 'յափերեն',
 				'yav' => 'յանգբեն',
 				'ybb' => 'եմբա',
 				'yi' => 'իդիշ',
 				'yo' => 'յորուբա',
 				'yrl' => 'նինգաթու',
 				'yue' => 'կանտոներեն',
 				'yue@alt=menu' => 'չինարեն, կանտոներեն',
 				'za' => 'ժուանգ',
 				'zap' => 'սապոտեկերեն',
 				'zea' => 'զեյլանդերեն',
 				'zen' => 'զենագա',
 				'zgh' => 'ընդհանուր մարոկյան թամազիղտ',
 				'zh' => 'չինարեն',
 				'zh@alt=menu' => 'չինարեն, մանդարին',
 				'zh_Hans' => 'պարզեցված չինարեն',
 				'zh_Hans@alt=long' => 'պարզեցված մանդարին չինարեն',
 				'zh_Hant' => 'ավանդական չինարեն',
 				'zh_Hant@alt=long' => 'ավանդական մանդարին չինարեն',
 				'zu' => 'զուլուերեն',
 				'zun' => 'զունիերեն',
 				'zxx' => 'առանց լեզվային բովանդակության',
 				'zza' => 'զազաերեն',

			);
			if (@_) {
				return $languages{$_[0]};
			}
			return \%languages;
		}
	},
);

has 'display_name_script' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		sub {
			my %scripts = (
			'Adlm' => 'ադլամ',
 			'Arab' => 'արաբական',
 			'Aran' => 'նաստալիք',
 			'Armn' => 'հայկական',
 			'Beng' => 'բենգալական',
 			'Bopo' => 'բոպոմոֆո',
 			'Brai' => 'Բրայլ',
 			'Cakm' => 'չակմա',
 			'Cans' => 'կանադական միասնական վանկագիր',
 			'Cher' => 'չերոկի',
 			'Cyrl' => 'կյուրեղագիր',
 			'Deva' => 'դեւանագարի',
 			'Ethi' => 'եթովպական',
 			'Geor' => 'վրացական',
 			'Grek' => 'հունական',
 			'Gujr' => 'գուջարաթի',
 			'Guru' => 'գուրմուխի',
 			'Hanb' => 'հանբ',
 			'Hang' => 'հանգըլ',
 			'Hani' => 'չինական',
 			'Hans' => 'պարզեցված',
 			'Hans@alt=stand-alone' => 'պարզեցված չինական',
 			'Hant' => 'ավանդական',
 			'Hant@alt=stand-alone' => 'ավանդական չինական',
 			'Hebr' => 'եբրայական',
 			'Hira' => 'հիրագանա',
 			'Hrkt' => 'ճապոնական վանկագիր',
 			'Jamo' => 'ջամո',
 			'Jpan' => 'ճապոնական',
 			'Kana' => 'կատականա',
 			'Khmr' => 'քմերական',
 			'Knda' => 'կաննադա',
 			'Kore' => 'կորեական',
 			'Laoo' => 'լաոսական',
 			'Latn' => 'լատինական',
 			'Mlym' => 'մալայալամ',
 			'Mong' => 'մոնղոլական',
 			'Mtei' => 'մանիպուրի',
 			'Mymr' => 'մյանմարական',
 			'Nkoo' => 'նկո',
 			'Olck' => 'օլ չիկի',
 			'Orya' => 'օրիյա',
 			'Rohg' => 'հանիֆի',
 			'Sinh' => 'սինհալական',
 			'Sund' => 'սունդանական',
 			'Syrc' => 'ասորական',
 			'Taml' => 'թամիլական',
 			'Telu' => 'թելուգու',
 			'Tfng' => 'տիֆինաղ',
 			'Thaa' => 'թաանա',
 			'Thai' => 'թայական',
 			'Tibt' => 'տիբեթական',
 			'Vaii' => 'վայական',
 			'Yiii' => 'ի',
 			'Zmth' => 'մաթեմատիկական նշաններ',
 			'Zsye' => 'էմոջի',
 			'Zsym' => 'նշաններ',
 			'Zxxx' => 'չգրված',
 			'Zyyy' => 'ընդհանուր',
 			'Zzzz' => 'անհայտ գիր',

			);
			if ( @_ ) {
				return $scripts{$_[0]};
			}
			return \%scripts;
		}
	}
);

has 'display_name_region' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'001' => 'Աշխարհ',
 			'002' => 'Աֆրիկա',
 			'003' => 'Հյուսիսային Ամերիկա',
 			'005' => 'Հարավային Ամերիկա',
 			'009' => 'Օվկիանիա',
 			'011' => 'Արևմտյան Աֆրիկա',
 			'013' => 'Կենտրոնական Ամերիկա',
 			'014' => 'Արևելյան Աֆրիկա',
 			'015' => 'Հյուսիսային Աֆրիկա',
 			'017' => 'Կենտրոնական Աֆրիկա',
 			'018' => 'Հարավային Աֆրիկա',
 			'019' => 'Ամերիկա',
 			'021' => 'Հյուսիսային Ամերիկա - ԱՄՆ և Կանադա',
 			'029' => 'Կարիբներ',
 			'030' => 'Արևելյան Ասիա',
 			'034' => 'Հարավային Ասիա',
 			'035' => 'Հարավարևելյան Ասիա',
 			'039' => 'Հարավային Եվրոպա',
 			'053' => 'Ավստրալասիա',
 			'054' => 'Մելանեզիա',
 			'057' => 'Միկրոնեզյան տարածաշրջան',
 			'061' => 'Պոլինեզիա',
 			'142' => 'Ասիա',
 			'143' => 'Կենտրոնական Ասիա',
 			'145' => 'Արևմտյան Ասիա',
 			'150' => 'Եվրոպա',
 			'151' => 'Արևելյան Եվրոպա',
 			'154' => 'Հյուսիսային Եվրոպա',
 			'155' => 'Արևմտյան Եվրոպա',
 			'202' => 'Արևադարձային Աֆրիկա',
 			'419' => 'Լատինական Ամերիկա',
 			'AC' => 'Համբարձման կղզի',
 			'AD' => 'Անդորրա',
 			'AE' => 'Արաբական Միացյալ Էմիրություններ',
 			'AF' => 'Աֆղանստան',
 			'AG' => 'Անտիգուա և Բարբուդա',
 			'AI' => 'Անգուիլա',
 			'AL' => 'Ալբանիա',
 			'AM' => 'Հայաստան',
 			'AO' => 'Անգոլա',
 			'AQ' => 'Անտարկտիդա',
 			'AR' => 'Արգենտինա',
 			'AS' => 'Ամերիկյան Սամոա',
 			'AT' => 'Ավստրիա',
 			'AU' => 'Ավստրալիա',
 			'AW' => 'Արուբա',
 			'AX' => 'Ալանդյան կղզիներ',
 			'AZ' => 'Ադրբեջան',
 			'BA' => 'Բոսնիա և Հերցեգովինա',
 			'BB' => 'Բարբադոս',
 			'BD' => 'Բանգլադեշ',
 			'BE' => 'Բելգիա',
 			'BF' => 'Բուրկինա Ֆասո',
 			'BG' => 'Բուլղարիա',
 			'BH' => 'Բահրեյն',
 			'BI' => 'Բուրունդի',
 			'BJ' => 'Բենին',
 			'BL' => 'Սուրբ Բարդուղիմեոս',
 			'BM' => 'Բերմուդներ',
 			'BN' => 'Բրունեյ',
 			'BO' => 'Բոլիվիա',
 			'BQ' => 'Կարիբյան Նիդեռլանդներ',
 			'BR' => 'Բրազիլիա',
 			'BS' => 'Բահամյան կղզիներ',
 			'BT' => 'Բութան',
 			'BV' => 'Բուվե կղզի',
 			'BW' => 'Բոթսվանա',
 			'BY' => 'Բելառուս',
 			'BZ' => 'Բելիզ',
 			'CA' => 'Կանադա',
 			'CC' => 'Կոկոսյան (Քիլինգ) կղզիներ',
 			'CD' => 'Կոնգո - Կինշասա',
 			'CD@alt=variant' => 'Կոնգո (ԿԺՀ)',
 			'CF' => 'Կենտրոնական Աֆրիկյան Հանրապետություն',
 			'CG' => 'Կոնգո - Բրազավիլ',
 			'CG@alt=variant' => 'Կոնգո (Կոնգոյի Հանրապետություն)',
 			'CH' => 'Շվեյցարիա',
 			'CI' => 'Կոտ դ՚Իվուար',
 			'CI@alt=variant' => 'Փղոսկրի Ափ',
 			'CK' => 'Կուկի կղզիներ',
 			'CL' => 'Չիլի',
 			'CM' => 'Կամերուն',
 			'CN' => 'Չինաստան',
 			'CO' => 'Կոլումբիա',
 			'CP' => 'Քլիփերթոն կղզի',
 			'CR' => 'Կոստա Ռիկա',
 			'CU' => 'Կուբա',
 			'CV' => 'Կաբո Վերդե',
 			'CW' => 'Կյուրասաո',
 			'CX' => 'Սուրբ Ծննդյան կղզի',
 			'CY' => 'Կիպրոս',
 			'CZ' => 'Չեխիա',
 			'CZ@alt=variant' => 'Չեխիայի Հանրապետություն',
 			'DE' => 'Գերմանիա',
 			'DG' => 'Դիեգո Գարսիա',
 			'DJ' => 'Ջիբութի',
 			'DK' => 'Դանիա',
 			'DM' => 'Դոմինիկա',
 			'DO' => 'Դոմինիկյան Հանրապետություն',
 			'DZ' => 'Ալժիր',
 			'EA' => 'Սեուտա և Մելիլյա',
 			'EC' => 'Էկվադոր',
 			'EE' => 'Էստոնիա',
 			'EG' => 'Եգիպտոս',
 			'EH' => 'Արևմտյան Սահարա',
 			'ER' => 'Էրիթրեա',
 			'ES' => 'Իսպանիա',
 			'ET' => 'Եթովպիա',
 			'EU' => 'Եվրոպական Միություն',
 			'EZ' => 'Եվրագոտի',
 			'FI' => 'Ֆինլանդիա',
 			'FJ' => 'Ֆիջի',
 			'FK' => 'Ֆոլքլենդյան կղզիներ',
 			'FK@alt=variant' => 'Ֆոլքլենդյան (Մալվինյան) կղզիներ',
 			'FM' => 'Միկրոնեզիա',
 			'FO' => 'Ֆարերյան կղզիներ',
 			'FR' => 'Ֆրանսիա',
 			'GA' => 'Գաբոն',
 			'GB' => 'Միացյալ Թագավորություն',
 			'GB@alt=short' => 'ՄԹ',
 			'GD' => 'Գրենադա',
 			'GE' => 'Վրաստան',
 			'GF' => 'Ֆրանսիական Գվիանա',
 			'GG' => 'Գերնսի',
 			'GH' => 'Գանա',
 			'GI' => 'Ջիբրալթար',
 			'GL' => 'Գրենլանդիա',
 			'GM' => 'Գամբիա',
 			'GN' => 'Գվինեա',
 			'GP' => 'Գվադելուպա',
 			'GQ' => 'Հասարակածային Գվինեա',
 			'GR' => 'Հունաստան',
 			'GS' => 'Հարավային Ջորջիա և Հարավային Սենդվիչյան կղզիներ',
 			'GT' => 'Գվատեմալա',
 			'GU' => 'Գուամ',
 			'GW' => 'Գվինեա-Բիսաու',
 			'GY' => 'Գայանա',
 			'HK' => 'Հոնկոնգի ՀՎՇ',
 			'HK@alt=short' => 'Հոնկոնգ',
 			'HM' => 'Հերդ կղզի և ՄակԴոնալդի կղզիներ',
 			'HN' => 'Հոնդուրաս',
 			'HR' => 'Խորվաթիա',
 			'HT' => 'Հայիթի',
 			'HU' => 'Հունգարիա',
 			'IC' => 'Կանարյան կղզիներ',
 			'ID' => 'Ինդոնեզիա',
 			'IE' => 'Իռլանդիա',
 			'IL' => 'Իսրայել',
 			'IM' => 'Մեն կղզի',
 			'IN' => 'Հնդկաստան',
 			'IO' => 'Բրիտանական տարածք Հնդկական Օվկիանոսում',
 			'IO@alt=chagos' => 'Չագոս արշիպելագ',
 			'IQ' => 'Իրաք',
 			'IR' => 'Իրան',
 			'IS' => 'Իսլանդիա',
 			'IT' => 'Իտալիա',
 			'JE' => 'Ջերսի',
 			'JM' => 'Ճամայկա',
 			'JO' => 'Հորդանան',
 			'JP' => 'Ճապոնիա',
 			'KE' => 'Քենիա',
 			'KG' => 'Ղրղզստան',
 			'KH' => 'Կամբոջա',
 			'KI' => 'Կիրիբատի',
 			'KM' => 'Կոմորյան կղզիներ',
 			'KN' => 'Սենթ Քիտս և Նևիս',
 			'KP' => 'Հյուսիսային Կորեա',
 			'KR' => 'Հարավային Կորեա',
 			'KW' => 'Քուվեյթ',
 			'KY' => 'Կայմանյան կղզիներ',
 			'KZ' => 'Ղազախստան',
 			'LA' => 'Լաոս',
 			'LB' => 'Լիբանան',
 			'LC' => 'Սենթ Լյուսիա',
 			'LI' => 'Լիխտենշտեյն',
 			'LK' => 'Շրի Լանկա',
 			'LR' => 'Լիբերիա',
 			'LS' => 'Լեսոտո',
 			'LT' => 'Լիտվա',
 			'LU' => 'Լյուքսեմբուրգ',
 			'LV' => 'Լատվիա',
 			'LY' => 'Լիբիա',
 			'MA' => 'Մարոկկո',
 			'MC' => 'Մոնակո',
 			'MD' => 'Մոլդովա',
 			'ME' => 'Չեռնոգորիա',
 			'MF' => 'Սեն Մարտեն',
 			'MG' => 'Մադագասկար',
 			'MH' => 'Մարշալյան կղզիներ',
 			'MK' => 'Հյուսիսային Մակեդոնիա',
 			'ML' => 'Մալի',
 			'MM' => 'Մյանմա (Բիրմա)',
 			'MN' => 'Մոնղոլիա',
 			'MO' => 'Չինաստանի Մակաո ՀՎՇ',
 			'MO@alt=short' => 'Մակաո',
 			'MP' => 'Հյուսիսային Մարիանյան կղզիներ',
 			'MQ' => 'Մարտինիկա',
 			'MR' => 'Մավրիտանիա',
 			'MS' => 'Մոնսեռատ',
 			'MT' => 'Մալթա',
 			'MU' => 'Մավրիկիոս',
 			'MV' => 'Մալդիվներ',
 			'MW' => 'Մալավի',
 			'MX' => 'Մեքսիկա',
 			'MY' => 'Մալայզիա',
 			'MZ' => 'Մոզամբիկ',
 			'NA' => 'Նամիբիա',
 			'NC' => 'Նոր Կալեդոնիա',
 			'NE' => 'Նիգեր',
 			'NF' => 'Նորֆոլկ կղզի',
 			'NG' => 'Նիգերիա',
 			'NI' => 'Նիկարագուա',
 			'NL' => 'Նիդեռլանդներ',
 			'NO' => 'Նորվեգիա',
 			'NP' => 'Նեպալ',
 			'NR' => 'Նաուրու',
 			'NU' => 'Նիուե',
 			'NZ' => 'Նոր Զելանդիա',
 			'NZ@alt=variant' => 'Աոտեարոա Նոր Զելանդիա',
 			'OM' => 'Օման',
 			'PA' => 'Պանամա',
 			'PE' => 'Պերու',
 			'PF' => 'Ֆրանսիական Պոլինեզիա',
 			'PG' => 'Պապուա Նոր Գվինեա',
 			'PH' => 'Ֆիլիպիններ',
 			'PK' => 'Պակիստան',
 			'PL' => 'Լեհաստան',
 			'PM' => 'Սեն Պիեռ և Միքելոն',
 			'PN' => 'Պիտկեռն կղզիներ',
 			'PR' => 'Պուերտո Ռիկո',
 			'PS' => 'Պաղեստինյան տարածքներ',
 			'PS@alt=short' => 'Պաղեստին',
 			'PT' => 'Պորտուգալիա',
 			'PW' => 'Պալաու',
 			'PY' => 'Պարագվայ',
 			'QA' => 'Կատար',
 			'QO' => 'Արտաքին Օվկիանիա',
 			'RE' => 'Ռեյունիոն',
 			'RO' => 'Ռումինիա',
 			'RS' => 'Սերբիա',
 			'RU' => 'Ռուսաստան',
 			'RW' => 'Ռուանդա',
 			'SA' => 'Սաուդյան Արաբիա',
 			'SB' => 'Սողոմոնյան կղզիներ',
 			'SC' => 'Սեյշելներ',
 			'SD' => 'Սուդան',
 			'SE' => 'Շվեդիա',
 			'SG' => 'Սինգապուր',
 			'SH' => 'Սուրբ Հեղինեի կղզի',
 			'SI' => 'Սլովենիա',
 			'SJ' => 'Սվալբարդ և Յան Մայեն',
 			'SK' => 'Սլովակիա',
 			'SL' => 'Սիեռա Լեոնե',
 			'SM' => 'Սան Մարինո',
 			'SN' => 'Սենեգալ',
 			'SO' => 'Սոմալի',
 			'SR' => 'Սուրինամ',
 			'SS' => 'Հարավային Սուդան',
 			'ST' => 'Սան Տոմե և Փրինսիպի',
 			'SV' => 'Սալվադոր',
 			'SX' => 'Սինտ Մարտեն',
 			'SY' => 'Սիրիա',
 			'SZ' => 'Էսվատինի',
 			'SZ@alt=variant' => 'Սվազիլենդ',
 			'TA' => 'Տրիստան դա Կունյա',
 			'TC' => 'Թըրքս և Կայկոս կղզիներ',
 			'TD' => 'Չադ',
 			'TF' => 'Ֆրանսիական Հարավային Տարածքներ',
 			'TG' => 'Տոգո',
 			'TH' => 'Թայլանդ',
 			'TJ' => 'Տաջիկստան',
 			'TK' => 'Տոկելաու',
 			'TL' => 'Թիմոր Լեշտի',
 			'TL@alt=variant' => 'Արևելյան Թիմոր',
 			'TM' => 'Թուրքմենստան',
 			'TN' => 'Թունիս',
 			'TO' => 'Տոնգա',
 			'TR' => 'Թուրքիա',
 			'TT' => 'Տրինիդադ և Տոբագո',
 			'TV' => 'Տուվալու',
 			'TW' => 'Թայվան',
 			'TZ' => 'Տանզանիա',
 			'UA' => 'Ուկրաինա',
 			'UG' => 'Ուգանդա',
 			'UM' => 'Արտաքին կղզիներ (ԱՄՆ)',
 			'UN' => 'Միավորված ազգերի կազմակերպություն',
 			'UN@alt=short' => 'ՄԱԿ',
 			'US' => 'Միացյալ Նահանգներ',
 			'US@alt=short' => 'ԱՄՆ',
 			'UY' => 'Ուրուգվայ',
 			'UZ' => 'Ուզբեկստան',
 			'VA' => 'Վատիկան',
 			'VC' => 'Սենթ Վինսենթ և Գրենադիններ',
 			'VE' => 'Վենեսուելա',
 			'VG' => 'Բրիտանական Վիրջինյան կղզիներ',
 			'VI' => 'ԱՄՆ Վիրջինյան կղզիներ',
 			'VN' => 'Վիետնամ',
 			'VU' => 'Վանուատու',
 			'WF' => 'Ուոլիս և Ֆուտունա',
 			'WS' => 'Սամոա',
 			'XA' => 'կեղծ տարբերիչներ',
 			'XB' => 'կեղծ երկուղղված',
 			'XK' => 'Կոսովո',
 			'YE' => 'Եմեն',
 			'YT' => 'Մայոտ',
 			'ZA' => 'Հարավաֆրիկյան Հանրապետություն',
 			'ZM' => 'Զամբիա',
 			'ZW' => 'Զիմբաբվե',
 			'ZZ' => 'Անհայտ տարածաշրջան',

		}
	},
);

has 'display_name_variant' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'AREVELA' => 'արևելահայերեն',
 			'AREVMDA' => 'արեւմտահայերէն',

		}
	},
);

has 'display_name_key' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => 'օրացույց',
 			'cf' => 'արժույթի ձևաչափ',
 			'collation' => 'տեսակավորման կարգ',
 			'currency' => 'արժույթ',
 			'hc' => 'Ժամանակային համակարգ (12 կամ 24)',
 			'lb' => 'տողանցման ոճ',
 			'ms' => 'չափման համակարգ',
 			'numbers' => 'թվեր',

		}
	},
);

has 'display_name_type' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[Str]],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => {
 				'buddhist' => q{բուդդայական օրացույց},
 				'chinese' => q{չինական օրացույց},
 				'coptic' => q{ղպտական օրացույց},
 				'dangi' => q{դանգի օրացույց},
 				'ethiopic' => q{եթովպական օրացույց},
 				'ethiopic-amete-alem' => q{եթովպական Ամետե Ալեմ օրացույց},
 				'gregorian' => q{գրիգորյան օրացույց},
 				'hebrew' => q{հրեական օրացույց},
 				'islamic' => q{հիջրայի օրացույց},
 				'islamic-civil' => q{հիջրայի քաղաքացիական օրացույց (աղյուսակային)},
 				'islamic-umalqura' => q{հիջրայի օրացույց (Ում ալ Քուրա)},
 				'iso8601' => q{ISO-8601 օրացույց},
 				'japanese' => q{ճապոնական օրացույց},
 				'persian' => q{պարսկական օրացույց},
 				'roc' => q{մինգուո օրացույց},
 			},
 			'cf' => {
 				'account' => q{արժույթի հաշվապահական ձևաչափ},
 				'standard' => q{արժույթի ստանդարտ ձևաչափ},
 			},
 			'collation' => {
 				'ducet' => q{Յունիկոդ լռելյայն տեսակավորում},
 				'search' => q{որոնում},
 				'standard' => q{տեսակավորման ստանդարտ կարգ},
 			},
 			'hc' => {
 				'h11' => q{12-ժամյա համակարգ (0-11)},
 				'h12' => q{12-ժամյա համակարգ (1-12)},
 				'h23' => q{24-ժամյա համակարգ (0-23)},
 				'h24' => q{24-ժամյա համակարգ (1-24)},
 			},
 			'lb' => {
 				'loose' => q{փափուկ տողանցում},
 				'normal' => q{սովորական տողանցում},
 				'strict' => q{կոշտ տողանցում},
 			},
 			'ms' => {
 				'metric' => q{մետրիկ համակարգ},
 				'uksystem' => q{անգլիական համակարգ},
 				'ussystem' => q{ամերիկյան համակարգ},
 			},
 			'numbers' => {
 				'arab' => q{արաբա-հնդկական թվանշաններ},
 				'arabext' => q{արաբա-հնդկական թվերի ընդլայնված համակարգ},
 				'armn' => q{հայկական թվանշաններ},
 				'armnlow' => q{հայկական փոքր թվանշաններ},
 				'beng' => q{բենգալական թվանշաններ},
 				'cakm' => q{չակմա թվանշաններ},
 				'deva' => q{դևանագարի թվանշաններ},
 				'ethi' => q{եթովպական թվանշաններ},
 				'fullwide' => q{ամբողջ լայնքով թվանշաններ},
 				'geor' => q{վրացական թվանշաններ},
 				'grek' => q{հունական թվանշաններ},
 				'greklow' => q{հունական փոքրատառ թվանիշեր},
 				'gujr' => q{գուջարաթի թվանշաններ},
 				'guru' => q{գուրմուխի թվանշաններ},
 				'hanidec' => q{չինական տասնորդական թվանշաններ},
 				'hans' => q{պարզեցված չինարենի թվանշաններ},
 				'hansfin' => q{պարզեցված չինարենի ֆինանսական թվանշաններ},
 				'hant' => q{չինական ավանդական թվանիշեր},
 				'hantfin' => q{ավանդական չինարենի ֆինանսական թվանշաններ},
 				'hebr' => q{եբրայական թվանշաններ},
 				'java' => q{ճավայական թվանշաններ},
 				'jpan' => q{ճապոնական թվանշաններ},
 				'jpanfin' => q{ճապոնական ֆինանսական թվանշաններ},
 				'khmr' => q{քմերական թվանշաններ},
 				'knda' => q{կաննադա թվանշաններ},
 				'laoo' => q{լաոսական թվանշաններ},
 				'latn' => q{արևմտյան թվանշաններ},
 				'mlym' => q{մալայալամ թվանշաններ},
 				'mtei' => q{մանիպուրի թվանշաններ},
 				'mymr' => q{բիրմական թվանշաններ},
 				'olck' => q{օլ չիկի թվանշաններ},
 				'orya' => q{օրիյա թվանշաններ},
 				'roman' => q{հռոմեական թվանշաններ},
 				'romanlow' => q{հռոմեական փոքր թվանշաններ},
 				'taml' => q{թամիլական ավանդական թվանշաններ},
 				'tamldec' => q{թամիլական թվանշաններ},
 				'telu' => q{թելուգու թվանշաններ},
 				'thai' => q{թայական թվանշաններ},
 				'tibt' => q{տիբեթական թվանշաններ},
 				'vaii' => q{վայական թվանշաններ},
 			},

		}
	},
);

has 'display_name_measurement_system' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'metric' => q{Մետրական},
 			'UK' => q{Անգլիական},
 			'US' => q{Ամերիկյան},

		}
	},
);

has 'display_name_code_patterns' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'language' => 'Լեզու՝ {0}',
 			'script' => 'Գիր՝ {0}',
 			'region' => 'Տարածաշրջան՝ {0}',

		}
	},
);

has 'characters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> $^V ge v5.18.0
	? eval <<'EOT'
	sub {
		no warnings 'experimental::regex_sets';
		return {
			auxiliary => qr{[և]},
			index => ['Ա', 'Բ', 'Գ', 'Դ', 'Ե', 'Զ', 'Է', 'Ը', 'Թ', 'Ժ', 'Ի', 'Լ', 'Խ', 'Ծ', 'Կ', 'Հ', 'Ձ', 'Ղ', 'Ճ', 'Մ', 'Յ', 'Ն', 'Շ', 'Ո', 'Չ', 'Պ', 'Ջ', 'Ռ', 'Ս', 'Վ', 'Տ', 'Ր', 'Ց', 'Ւ', 'Փ', 'Ք', 'Օ', 'Ֆ'],
			main => qr{[ա բ գ դ ե զ է ը թ ժ ի լ խ ծ կ հ ձ ղ ճ մ յ ն շ ո չ պ ջ ռ ս վ տ ր ց ւ փ ք օ ֆ]},
			numbers => qr{[  \- ‑ , % ‰ + 0 1 2 3 4 5 6 7 8 9]},
			punctuation => qr{[֊ , ՝ \: ՜ ՞ . « » ՚ ՛ ՟]},
		};
	},
EOT
: sub {
		return { index => ['Ա', 'Բ', 'Գ', 'Դ', 'Ե', 'Զ', 'Է', 'Ը', 'Թ', 'Ժ', 'Ի', 'Լ', 'Խ', 'Ծ', 'Կ', 'Հ', 'Ձ', 'Ղ', 'Ճ', 'Մ', 'Յ', 'Ն', 'Շ', 'Ո', 'Չ', 'Պ', 'Ջ', 'Ռ', 'Ս', 'Վ', 'Տ', 'Ր', 'Ց', 'Ւ', 'Փ', 'Ք', 'Օ', 'Ֆ'], };
},
);


has 'more_information' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{(՞)},
);

has 'quote_start' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{«},
);

has 'quote_end' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{»},
);

has 'alternate_quote_start' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{«},
);

has 'alternate_quote_end' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> qq{»},
);

has 'units' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[HashRef[Str]]],
	init_arg	=> undef,
	default		=> sub { {
				'long' => {
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(կիբի{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(կիբի{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(մեբի{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(մեբի{0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(գիբի{0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(գիբի{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(տեբի{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(տեբի{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(փեբի{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(փեբի{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(Էքսբի{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(Էքսբի{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(զեբի{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(զեբի{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(Յոբի{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(Յոբի{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(դեցի{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(դեցի{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(պիկո{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(պիկո{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ֆեմտո{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ֆեմտո{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ատտո{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ատտո{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(սանտի{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(սանտի{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(զեպտո{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(զեպտո{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(յոկտո{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(յոկտո{0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ռոնտո{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ռոնտո{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(միլի{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(միլի{0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(քուեկտո{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(քուեկտո{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(միկրո{0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(միկրո{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(նանո{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(նանո{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(դեկա{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(դեկա{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(տերա{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(տերա{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(պետա{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(պետա{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(էքսա{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(էքսա{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(հեկտո{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(հեկտո{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(զետտա{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(զետտա{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(յոտտա{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(յոտտա{0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(ռոննա{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(ռոննա{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(կիլո{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(կիլո{0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(քուետտա{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(քուետտա{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(մեգա{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(մեգա{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(գիգա{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(գիգա{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(ազատ անկման արագացում),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(ազատ անկման արագացում),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(մետրեր/վայրկյան քառակուսի),
						'one' => q({0} մետր/վայրկյան քառակուսի),
						'other' => q({0} մետր/վայրկյան քառակուսի),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(մետրեր/վայրկյան քառակուսի),
						'one' => q({0} մետր/վայրկյան քառակուսի),
						'other' => q({0} մետր/վայրկյան քառակուսի),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'one' => q({0} րոպե),
						'other' => q({0} րոպե),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'one' => q({0} րոպե),
						'other' => q({0} րոպե),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'one' => q({0} վայրկյան),
						'other' => q({0} վայրկյան),
					},
					# Core Unit Identifier
					'arc-second' => {
						'one' => q({0} վայրկյան),
						'other' => q({0} վայրկյան),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(աստիճաններ),
						'one' => q({0} աստիճան),
						'other' => q({0} աստիճան),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(աստիճաններ),
						'one' => q({0} աստիճան),
						'other' => q({0} աստիճան),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'name' => q(ռադիաններ),
						'one' => q({0} ռադիան),
						'other' => q({0} ռադիան),
					},
					# Core Unit Identifier
					'radian' => {
						'name' => q(ռադիաններ),
						'one' => q({0} ռադիան),
						'other' => q({0} ռադիան),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(պտույտներ),
						'one' => q({0} պտույտ),
						'other' => q({0} պտույտ),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(պտույտներ),
						'one' => q({0} պտույտ),
						'other' => q({0} պտույտ),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ակրեր),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ակրեր),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(դունամներ),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(դունամներ),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(հեկտարներ),
						'one' => q({0} հեկտար),
						'other' => q({0} հեկտար),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(հեկտարներ),
						'one' => q({0} հեկտար),
						'other' => q({0} հեկտար),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(քառակուսի սանտիմետրեր),
						'one' => q({0} քառակուսի սանտիմետր),
						'other' => q({0} քառակուսի սանտիմետր),
						'per' => q({0} քառակուսի սանտիմետրի վրա),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(քառակուսի սանտիմետրեր),
						'one' => q({0} քառակուսի սանտիմետր),
						'other' => q({0} քառակուսի սանտիմետր),
						'per' => q({0} քառակուսի սանտիմետրի վրա),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(քառակուսի ֆուտեր),
						'one' => q({0} քառակուսի ֆուտ),
						'other' => q({0} քառակուսի ֆուտ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(քառակուսի ֆուտեր),
						'one' => q({0} քառակուսի ֆուտ),
						'other' => q({0} քառակուսի ֆուտ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(քառակուսի մատնաչափեր),
						'one' => q({0} քառակուսի մատնաչափ),
						'other' => q({0} քառակուսի մատնաչափ),
						'per' => q({0} քառակուսի մատնաչափի վրա),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(քառակուսի մատնաչափեր),
						'one' => q({0} քառակուսի մատնաչափ),
						'other' => q({0} քառակուսի մատնաչափ),
						'per' => q({0} քառակուսի մատնաչափի վրա),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(քառակուսի կիլոմետրեր),
						'one' => q({0} քառակուսի կիլոմետր),
						'other' => q({0} քառակուսի կիլոմետր),
						'per' => q({0} քառակուսի կիլոմետրի վրա),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(քառակուսի կիլոմետրեր),
						'one' => q({0} քառակուսի կիլոմետր),
						'other' => q({0} քառակուսի կիլոմետր),
						'per' => q({0} քառակուսի կիլոմետրի վրա),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(քառակուսի մետրեր),
						'one' => q({0} քառակուսի մետր),
						'other' => q({0} քառակուսի մետր),
						'per' => q({0} քառակուսի մետրի վրա),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(քառակուսի մետրեր),
						'one' => q({0} քառակուսի մետր),
						'other' => q({0} քառակուսի մետր),
						'per' => q({0} քառակուսի մետրի վրա),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'name' => q(քառակուսի մղոններ),
						'one' => q({0} քառակուսի մղոն),
						'other' => q({0} քառակուսի մղոն),
						'per' => q({0} քառակուսի մղոնի վրա),
					},
					# Core Unit Identifier
					'square-mile' => {
						'name' => q(քառակուսի մղոններ),
						'one' => q({0} քառակուսի մղոն),
						'other' => q({0} քառակուսի մղոն),
						'per' => q({0} քառակուսի մղոնի վրա),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(քառակուսի յարդեր),
						'one' => q({0} քառակուսի յարդ),
						'other' => q({0} քառակուսի յարդ),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(քառակուսի յարդեր),
						'one' => q({0} քառակուսի յարդ),
						'other' => q({0} քառակուսի յարդ),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'one' => q({0} միույթ),
						'other' => q({0} միույթ),
					},
					# Core Unit Identifier
					'item' => {
						'one' => q({0} միույթ),
						'other' => q({0} միույթ),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'name' => q(կարատ),
						'one' => q({0} կարատ),
						'other' => q({0} կարատ),
					},
					# Core Unit Identifier
					'karat' => {
						'name' => q(կարատ),
						'one' => q({0} կարատ),
						'other' => q({0} կարատ),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(միլիգրամներ դեցիլիտրի վրա),
						'one' => q({0} միլիգրամ դեցիլիտրի վրա),
						'other' => q({0} միլիգրամ դեցիլիտրի վրա),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(միլիգրամներ դեցիլիտրի վրա),
						'one' => q({0} միլիգրամ դեցիլիտրի վրա),
						'other' => q({0} միլիգրամ դեցիլիտրի վրա),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(միլիմոլներ լիտրի վրա),
						'one' => q({0} միլիմոլ լիտրի վրա),
						'other' => q({0} միլիմոլ լիտրի վրա),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(միլիմոլներ լիտրի վրա),
						'one' => q({0} միլիմոլ լիտրի վրա),
						'other' => q({0} միլիմոլ լիտրի վրա),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'name' => q(մոլեր),
						'one' => q({0} մոլ),
						'other' => q({0} մոլ),
					},
					# Core Unit Identifier
					'mole' => {
						'name' => q(մոլեր),
						'one' => q({0} մոլ),
						'other' => q({0} մոլ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'one' => q({0} տոկոս),
						'other' => q({0} տոկոս),
					},
					# Core Unit Identifier
					'percent' => {
						'one' => q({0} տոկոս),
						'other' => q({0} տոկոս),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'one' => q({0} պրոմիլ),
						'other' => q({0} պրոմիլ),
					},
					# Core Unit Identifier
					'permille' => {
						'one' => q({0} պրոմիլ),
						'other' => q({0} պրոմիլ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(մասնիկներ միլիոնի վրա),
						'one' => q({0} մասնիկ միլիոնի վրա),
						'other' => q({0} մասնիկ միլիոնի վրա),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(մասնիկներ միլիոնի վրա),
						'one' => q({0} մասնիկ միլիոնի վրա),
						'other' => q({0} մասնիկ միլիոնի վրա),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(պերմիրիադ),
						'one' => q({0} պերմիրիադ),
						'other' => q({0} պերմիրիադ),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(պերմիրիադ),
						'one' => q({0} պերմիրիադ),
						'other' => q({0} պերմիրիադ),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(լիտրեր 100 կիլոմետրի վրա),
						'one' => q({0} լիտր 100 կիլոմետրի վրա),
						'other' => q({0} լիտր 100 կիլոմետրի վրա),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(լիտրեր 100 կիլոմետրի վրա),
						'one' => q({0} լիտր 100 կիլոմետրի վրա),
						'other' => q({0} լիտր 100 կիլոմետրի վրա),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(լիտրեր կիլոմետրի վրա),
						'one' => q({0} լիտր կիլոմետրի վրա),
						'other' => q({0} լիտր կիլոմետրի վրա),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(լիտրեր կիլոմետրի վրա),
						'one' => q({0} լիտր կիլոմետրի վրա),
						'other' => q({0} լիտր կիլոմետրի վրա),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(մղոններ գալոնի վրա),
						'one' => q({0} մղոն գալոնի վրա),
						'other' => q({0} մղոն գալոնի վրա),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(մղոններ գալոնի վրա),
						'one' => q({0} մղոն գալոնի վրա),
						'other' => q({0} մղոն գալոնի վրա),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(մղոններ անգլիական գալոնի վրա),
						'one' => q({0} մղոն անգլիական գալոնի վրա),
						'other' => q({0} մղոն անգլիական գալոնի վրա),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(մղոններ անգլիական գալոնի վրա),
						'one' => q({0} մղոն անգլիական գալոնի վրա),
						'other' => q({0} մղոն անգլիական գալոնի վրա),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q(արևելյան երկարության {0}),
						'north' => q({0} հյուսիսային լայնության),
						'south' => q({0} հարավային լայնության),
						'west' => q(արևմտյան երկարության {0}),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q(արևելյան երկարության {0}),
						'north' => q({0} հյուսիսային լայնության),
						'south' => q({0} հարավային լայնության),
						'west' => q(արևմտյան երկարության {0}),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'name' => q(բիթեր),
						'one' => q({0} բիթ),
						'other' => q({0} բիթ),
					},
					# Core Unit Identifier
					'bit' => {
						'name' => q(բիթեր),
						'one' => q({0} բիթ),
						'other' => q({0} բիթ),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(բայթեր),
						'one' => q({0} բայթ),
						'other' => q({0} բայթ),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(բայթեր),
						'one' => q({0} բայթ),
						'other' => q({0} բայթ),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(գիգաբիթեր),
						'one' => q({0} գիգաբիթ),
						'other' => q({0} գիգաբիթ),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(գիգաբիթեր),
						'one' => q({0} գիգաբիթ),
						'other' => q({0} գիգաբիթ),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(գիգաբայթեր),
						'one' => q({0} գիգաբայթ),
						'other' => q({0} գիգաբայթ),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(գիգաբայթեր),
						'one' => q({0} գիգաբայթ),
						'other' => q({0} գիգաբայթ),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(կիլոբիթեր),
						'one' => q({0} կիլոբիթ),
						'other' => q({0} կիլոբիթ),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(կիլոբիթեր),
						'one' => q({0} կիլոբիթ),
						'other' => q({0} կիլոբիթ),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(կիլոբայթեր),
						'one' => q({0} կիլոբայթ),
						'other' => q({0} կիլոբայթ),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(կիլոբայթեր),
						'one' => q({0} կիլոբայթ),
						'other' => q({0} կիլոբայթ),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(մեգաբիթեր),
						'one' => q({0} մեգաբիթ),
						'other' => q({0} մեգաբիթ),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(մեգաբիթեր),
						'one' => q({0} մեգաբիթ),
						'other' => q({0} մեգաբիթ),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(մեգաբայթեր),
						'one' => q({0} մեգաբայթ),
						'other' => q({0} մեգաբայթ),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(մեգաբայթեր),
						'one' => q({0} մեգաբայթ),
						'other' => q({0} մեգաբայթ),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(պետաբայթեր),
						'one' => q({0} պետաբայթ),
						'other' => q({0} պետաբայթ),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(պետաբայթեր),
						'one' => q({0} պետաբայթ),
						'other' => q({0} պետաբայթ),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(տերաբիթեր),
						'one' => q({0} տերաբիթ),
						'other' => q({0} տերաբիթ),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(տերաբիթեր),
						'one' => q({0} տերաբիթ),
						'other' => q({0} տերաբիթ),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(տերաբայթեր),
						'one' => q({0} տերաբայթ),
						'other' => q({0} տերաբայթ),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(տերաբայթեր),
						'one' => q({0} տերաբայթ),
						'other' => q({0} տերաբայթ),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(դարեր),
						'one' => q({0} դար),
						'other' => q({0} դար),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(դարեր),
						'one' => q({0} դար),
						'other' => q({0} դար),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(օրեր),
						'one' => q({0} օր),
						'other' => q({0} օր),
						'per' => q(օրական {0}),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(օրեր),
						'one' => q({0} օր),
						'other' => q({0} օր),
						'per' => q(օրական {0}),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(տասնամյակներ),
						'one' => q({0} տասնամյակ),
						'other' => q({0} տասնամյակ),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(տասնամյակներ),
						'one' => q({0} տասնամյակ),
						'other' => q({0} տասնամյակ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ժամեր),
						'one' => q({0} ժամ),
						'other' => q({0} ժամ),
						'per' => q({0} ժամում),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ժամեր),
						'one' => q({0} ժամ),
						'other' => q({0} ժամ),
						'per' => q({0} ժամում),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(միկրովայրկյաններ),
						'one' => q({0} միկրովայրկյան),
						'other' => q({0} միկրովայրկյան),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(միկրովայրկյաններ),
						'one' => q({0} միկրովայրկյան),
						'other' => q({0} միկրովայրկյան),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(միլիվայրկյաններ),
						'one' => q({0} միլիվայրկյան),
						'other' => q({0} միլիվայրկյան),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(միլիվայրկյաններ),
						'one' => q({0} միլիվայրկյան),
						'other' => q({0} միլիվայրկյան),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(րոպեներ),
						'one' => q({0} րոպե),
						'other' => q({0} րոպե),
						'per' => q({0} րոպեում),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(րոպեներ),
						'one' => q({0} րոպե),
						'other' => q({0} րոպե),
						'per' => q({0} րոպեում),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ամիսներ),
						'one' => q({0} ամիս),
						'other' => q({0} ամիս),
						'per' => q(ամսական {0}),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ամիսներ),
						'one' => q({0} ամիս),
						'other' => q({0} ամիս),
						'per' => q(ամսական {0}),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'name' => q(նանովայրկյաններ),
						'one' => q({0} նանովայրկյան),
						'other' => q({0} նանովայրկյան),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'name' => q(նանովայրկյաններ),
						'one' => q({0} նանովայրկյան),
						'other' => q({0} նանովայրկյան),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'name' => q(եռամսյակներ),
						'one' => q({0} եռամսյակ),
						'other' => q({0} եռամսյակ),
					},
					# Core Unit Identifier
					'quarter' => {
						'name' => q(եռամսյակներ),
						'one' => q({0} եռամսյակ),
						'other' => q({0} եռամսյակ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(վայրկյաններ),
						'one' => q({0} վայրկյան),
						'other' => q({0} վայրկյան),
						'per' => q({0} վայրկյանում),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(վայրկյաններ),
						'one' => q({0} վայրկյան),
						'other' => q({0} վայրկյան),
						'per' => q({0} վայրկյանում),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(շաբաթներ),
						'one' => q({0} շաբաթ),
						'other' => q({0} շաբաթ),
						'per' => q(շաբաթական {0}),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(շաբաթներ),
						'one' => q({0} շաբաթ),
						'other' => q({0} շաբաթ),
						'per' => q(շաբաթական {0}),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(տարիներ),
						'one' => q({0} տարի),
						'other' => q({0} տարի),
						'per' => q(տարեկան {0}),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(տարիներ),
						'one' => q({0} տարի),
						'other' => q({0} տարի),
						'per' => q(տարեկան {0}),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(ամպերներ),
						'one' => q({0} ամպեր),
						'other' => q({0} ամպեր),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(ամպերներ),
						'one' => q({0} ամպեր),
						'other' => q({0} ամպեր),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(միլիամպերներ),
						'one' => q({0} միլիամպեր),
						'other' => q({0} միլիամպեր),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(միլիամպերներ),
						'one' => q({0} միլիամպեր),
						'other' => q({0} միլիամպեր),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'one' => q({0} օհմ),
						'other' => q({0} օհմ),
					},
					# Core Unit Identifier
					'ohm' => {
						'one' => q({0} օհմ),
						'other' => q({0} օհմ),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'name' => q(վոլտեր),
						'one' => q({0} վոլտ),
						'other' => q({0} վոլտ),
					},
					# Core Unit Identifier
					'volt' => {
						'name' => q(վոլտեր),
						'one' => q({0} վոլտ),
						'other' => q({0} վոլտ),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(բրիտանական ջերմային միավորներ),
						'one' => q({0} բրիտանական ջերմային միավոր),
						'other' => q({0} բրիտանական ջերմային միավոր),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(բրիտանական ջերմային միավորներ),
						'one' => q({0} բրիտանական ջերմային միավոր),
						'other' => q({0} բրիտանական ջերմային միավոր),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(կալորիաներ),
						'one' => q({0} կալորիա),
						'other' => q({0} կալորիա),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(կալորիաներ),
						'one' => q({0} կալորիա),
						'other' => q({0} կալորիա),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(էլեկտրոն-վոլտեր),
						'one' => q({0} էլեկտրոն-վոլտ),
						'other' => q({0} էլեկտրոն-վոլտ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(էլեկտրոն-վոլտեր),
						'one' => q({0} էլեկտրոն-վոլտ),
						'other' => q({0} էլեկտրոն-վոլտ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(կալորիաներ),
						'one' => q({0} կալորիա),
						'other' => q({0} կալորիա),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(կալորիաներ),
						'one' => q({0} կալորիա),
						'other' => q({0} կալորիա),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'name' => q(ջոուլներ),
						'one' => q({0} ջոուլ),
						'other' => q({0} ջոուլ),
					},
					# Core Unit Identifier
					'joule' => {
						'name' => q(ջոուլներ),
						'one' => q({0} ջոուլ),
						'other' => q({0} ջոուլ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(կիլոկալորիաներ),
						'one' => q({0} կիլոկալորիա),
						'other' => q({0} կիլոկալորիա),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(կիլոկալորիաներ),
						'one' => q({0} կիլոկալորիա),
						'other' => q({0} կիլոկալորիա),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'name' => q(կիլոջոուլներ),
						'one' => q({0} կիլոջոուլ),
						'other' => q({0} կիլոջոուլ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'name' => q(կիլոջոուլներ),
						'one' => q({0} կիլոջոուլ),
						'other' => q({0} կիլոջոուլ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(կիլովատտեր-ժամեր),
						'one' => q({0} կիլովատտ-ժամ),
						'other' => q({0} կիլովատտ-ժամ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(կիլովատտեր-ժամեր),
						'one' => q({0} կիլովատտ-ժամ),
						'other' => q({0} կիլովատտ-ժամ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ԱՄՆ ջերմեր),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ԱՄՆ ջերմեր),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'name' => q(կիլովատտ-ժամ 100 կիլոմետրի վրա),
						'one' => q({0} կիլովատտ-ժամ 100 կիլոմետրի վրա),
						'other' => q({0} կիլովատտ-ժամ 100 կիլոմետրի վրա),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'name' => q(կիլովատտ-ժամ 100 կիլոմետրի վրա),
						'one' => q({0} կիլովատտ-ժամ 100 կիլոմետրի վրա),
						'other' => q({0} կիլովատտ-ժամ 100 կիլոմետրի վրա),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(նյուտոններ),
						'one' => q({0} նյուտոն),
						'other' => q({0} նյուտոն),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(նյուտոններ),
						'one' => q({0} նյուտոն),
						'other' => q({0} նյուտոն),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ֆունտ-ուժեր),
						'one' => q({0} ֆունտ-ուժ),
						'other' => q({0} ֆունտ-ուժ),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ֆունտ-ուժեր),
						'one' => q({0} ֆունտ-ուժ),
						'other' => q({0} ֆունտ-ուժ),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(գիգահերցեր),
						'one' => q({0} գիգահերց),
						'other' => q({0} գիգահերց),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(գիգահերցեր),
						'one' => q({0} գիգահերց),
						'other' => q({0} գիգահերց),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'name' => q(հերցեր),
						'one' => q({0} հերց),
						'other' => q({0} հերց),
					},
					# Core Unit Identifier
					'hertz' => {
						'name' => q(հերցեր),
						'one' => q({0} հերց),
						'other' => q({0} հերց),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'name' => q(կիլոհերցեր),
						'one' => q({0} կիլոհերց),
						'other' => q({0} կիլոհերց),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'name' => q(կիլոհերցեր),
						'one' => q({0} կիլոհերց),
						'other' => q({0} կիլոհերց),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'name' => q(մեգահերցեր),
						'one' => q({0} մեգահերց),
						'other' => q({0} մեգահերց),
					},
					# Core Unit Identifier
					'megahertz' => {
						'name' => q(մեգահերցեր),
						'one' => q({0} մեգահերց),
						'other' => q({0} մեգահերց),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(կետեր սանտիմետրի վրա),
						'one' => q({0} կետ սանտիմետրի վրա),
						'other' => q({0} կետ սանտիմետրի վրա),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(կետեր սանտիմետրի վրա),
						'one' => q({0} կետ սանտիմետրի վրա),
						'other' => q({0} կետ սանտիմետրի վրա),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(կետեր մատնաչափի վրա),
						'one' => q({0} կետ մատնաչափի վրա),
						'other' => q({0} կետ մատնաչափի վրա),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(կետեր մատնաչափի վրա),
						'one' => q({0} կետ մատնաչափի վրա),
						'other' => q({0} կետ մատնաչափի վրա),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'name' => q(տպագրական em),
					},
					# Core Unit Identifier
					'em' => {
						'name' => q(տպագրական em),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'one' => q({0} մեգափիքսել),
						'other' => q({0} մեգափիքսել),
					},
					# Core Unit Identifier
					'megapixel' => {
						'one' => q({0} մեգափիքսել),
						'other' => q({0} մեգափիքսել),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'one' => q({0} փիքսել),
						'other' => q({0} փիքսել),
					},
					# Core Unit Identifier
					'pixel' => {
						'one' => q({0} փիքսել),
						'other' => q({0} փիքսել),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'name' => q(փիքսելներ սանտիմետրի վրա),
						'one' => q({0} փիքսել սանտիմետրի վրա),
						'other' => q({0} փիքսել սանտիմետրի վրա),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'name' => q(փիքսելներ սանտիմետրի վրա),
						'one' => q({0} փիքսել սանտիմետրի վրա),
						'other' => q({0} փիքսել սանտիմետրի վրա),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'name' => q(փիքսելներ մատնաչափի վրա),
						'one' => q({0} փիքսել մատնաչափի վրա),
						'other' => q({0} փիքսել մատնաչափի վրա),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'name' => q(փիքսելներ մատնաչափի վրա),
						'one' => q({0} փիքսել մատնաչափի վրա),
						'other' => q({0} փիքսել մատնաչափի վրա),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(աստղագիտական միավորներ),
						'one' => q({0} աստղագիտական միավոր),
						'other' => q({0} աստղագիտական միավոր),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(աստղագիտական միավորներ),
						'one' => q({0} աստղագիտական միավոր),
						'other' => q({0} աստղագիտական միավոր),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(սանտիմետրեր),
						'one' => q({0} սանտիմետր),
						'other' => q({0} սանտիմետր),
						'per' => q({0} սանտիմետրի վրա),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(սանտիմետրեր),
						'one' => q({0} սանտիմետր),
						'other' => q({0} սանտիմետր),
						'per' => q({0} սանտիմետրի վրա),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(դեցիմետրեր),
						'one' => q({0} դեցիմետր),
						'other' => q({0} դեցիմետր),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(դեցիմետրեր),
						'one' => q({0} դեցիմետր),
						'other' => q({0} դեցիմետր),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(երկրի շառավիղ),
						'one' => q({0} երկրի շառավիղ),
						'other' => q({0} երկրի շառավիղ),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(երկրի շառավիղ),
						'one' => q({0} երկրի շառավիղ),
						'other' => q({0} երկրի շառավիղ),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ծովային սաժեններ),
						'one' => q({0} ծովային սաժեն),
						'other' => q({0} ծովային սաժեն),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ծովային սաժեններ),
						'one' => q({0} ծովային սաժեն),
						'other' => q({0} ծովային սաժեն),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ֆուտեր),
						'one' => q({0} ֆուտ),
						'other' => q({0} ֆուտ),
						'per' => q({0} ֆուտի վրա),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ֆուտեր),
						'one' => q({0} ֆուտ),
						'other' => q({0} ֆուտ),
						'per' => q({0} ֆուտի վրա),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'one' => q({0} ֆուրլոնգ),
						'other' => q({0} ֆուրլոնգ),
					},
					# Core Unit Identifier
					'furlong' => {
						'one' => q({0} ֆուրլոնգ),
						'other' => q({0} ֆուրլոնգ),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(մատնաչափեր),
						'one' => q({0} մատնաչափ),
						'other' => q({0} մատնաչափ),
						'per' => q({0} մատնաչափի վրա),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(մատնաչափեր),
						'one' => q({0} մատնաչափ),
						'other' => q({0} մատնաչափ),
						'per' => q({0} մատնաչափի վրա),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(կիլոմետրեր),
						'one' => q({0} կիլոմետր),
						'other' => q({0} կիլոմետր),
						'per' => q({0} կիլոմետրի վրա),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(կիլոմետրեր),
						'one' => q({0} կիլոմետր),
						'other' => q({0} կիլոմետր),
						'per' => q({0} կիլոմետրի վրա),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(լուսատարիներ),
						'one' => q({0} լուսատարի),
						'other' => q({0} լուսատարի),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(լուսատարիներ),
						'one' => q({0} լուսատարի),
						'other' => q({0} լուսատարի),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(մետրեր),
						'one' => q({0} մետր),
						'other' => q({0} մետր),
						'per' => q({0} մետրի վրա),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(մետրեր),
						'one' => q({0} մետր),
						'other' => q({0} մետր),
						'per' => q({0} մետրի վրա),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(միկրոմետրեր),
						'one' => q({0} միկրոմետր),
						'other' => q({0} միկրոմետր),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(միկրոմետրեր),
						'one' => q({0} միկրոմետր),
						'other' => q({0} միկրոմետր),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(մղոններ),
						'one' => q({0} մղոն),
						'other' => q({0} մղոն),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(մղոններ),
						'one' => q({0} մղոն),
						'other' => q({0} մղոն),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(սկանդինավյան մղոններ),
						'one' => q({0} սկանդինավյան մղոն),
						'other' => q({0} սկանդինավյան մղոն),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(սկանդինավյան մղոններ),
						'one' => q({0} սկանդինավյան մղոն),
						'other' => q({0} սկանդինավյան մղոն),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(միլիմետրեր),
						'one' => q({0} միլիմետր),
						'other' => q({0} միլիմետր),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(միլիմետրեր),
						'one' => q({0} միլիմետր),
						'other' => q({0} միլիմետր),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(նանոմետրեր),
						'one' => q({0} նանոմետր),
						'other' => q({0} նանոմետր),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(նանոմետրեր),
						'one' => q({0} նանոմետր),
						'other' => q({0} նանոմետր),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ծովային մղոններ),
						'one' => q({0} ծովային մղոն),
						'other' => q({0} ծովային մղոն),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ծովային մղոններ),
						'one' => q({0} ծովային մղոն),
						'other' => q({0} ծովային մղոն),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(պարսեկներ),
						'one' => q({0} պարսեկ),
						'other' => q({0} պարսեկ),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(պարսեկներ),
						'one' => q({0} պարսեկ),
						'other' => q({0} պարսեկ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(պիկոմետրեր),
						'one' => q({0} պիկոմետր),
						'other' => q({0} պիկոմետր),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(պիկոմետրեր),
						'one' => q({0} պիկոմետր),
						'other' => q({0} պիկոմետր),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(արեգակնային շառավիղներ),
						'one' => q({0} արեգակնային շառավիղ),
						'other' => q({0} արեգակնային շառավիղ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(արեգակնային շառավիղներ),
						'one' => q({0} արեգակնային շառավիղ),
						'other' => q({0} արեգակնային շառավիղ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(յարդեր),
						'one' => q({0} յարդ),
						'other' => q({0} յարդ),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(յարդեր),
						'one' => q({0} յարդ),
						'other' => q({0} յարդ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'name' => q(կանդելա),
						'one' => q({0} կանդելա),
						'other' => q({0} կանդելա),
					},
					# Core Unit Identifier
					'candela' => {
						'name' => q(կանդելա),
						'one' => q({0} կանդելա),
						'other' => q({0} կանդելա),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'name' => q(լյումեն),
						'one' => q({0} լյումեն),
						'other' => q({0} լյումեն),
					},
					# Core Unit Identifier
					'lumen' => {
						'name' => q(լյումեն),
						'one' => q({0} լյումեն),
						'other' => q({0} լյումեն),
					},
					# Long Unit Identifier
					'light-lux' => {
						'name' => q(լյուքսեր),
						'one' => q({0} լյուքս),
						'other' => q({0} լյուքս),
					},
					# Core Unit Identifier
					'lux' => {
						'name' => q(լյուքսեր),
						'one' => q({0} լյուքս),
						'other' => q({0} լյուքս),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(արեգակնային լուսատվություններ),
						'one' => q({0} արեգակնային լուսատվություն),
						'other' => q({0} արեգակնային լուսատվություն),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(արեգակնային լուսատվություններ),
						'one' => q({0} արեգակնային լուսատվություն),
						'other' => q({0} արեգակնային լուսատվություն),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(կարատներ),
						'one' => q({0} կարատ),
						'other' => q({0} կարատ),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(կարատներ),
						'one' => q({0} կարատ),
						'other' => q({0} կարատ),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(դալտոններ),
						'one' => q({0} դալտոն),
						'other' => q({0} դալտոն),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(դալտոններ),
						'one' => q({0} դալտոն),
						'other' => q({0} դալտոն),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(երկրային զանգվածներ),
						'one' => q({0} երկրային զանգված),
						'other' => q({0} արևային զանգված),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(երկրային զանգվածներ),
						'one' => q({0} երկրային զանգված),
						'other' => q({0} արևային զանգված),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(գրամներ),
						'one' => q({0} գրամ),
						'other' => q({0} գրամ),
						'per' => q({0} գրամի վրա),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(գրամներ),
						'one' => q({0} գրամ),
						'other' => q({0} գրամ),
						'per' => q({0} գրամի վրա),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(կիլոգրամներ),
						'one' => q({0} կիլոգրամ),
						'other' => q({0} կիլոգրամ),
						'per' => q({0} կիլոգրամի վրա),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(կիլոգրամներ),
						'one' => q({0} կիլոգրամ),
						'other' => q({0} կիլոգրամ),
						'per' => q({0} կիլոգրամի վրա),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'name' => q(միկրոգրամներ),
						'one' => q({0} միկրոգրամ),
						'other' => q({0} միկրոգրամ),
					},
					# Core Unit Identifier
					'microgram' => {
						'name' => q(միկրոգրամներ),
						'one' => q({0} միկրոգրամ),
						'other' => q({0} միկրոգրամ),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(միլիգրամներ),
						'one' => q({0} միլիգրամ),
						'other' => q({0} միլիգրամ),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(միլիգրամներ),
						'one' => q({0} միլիգրամ),
						'other' => q({0} միլիգրամ),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ունկիներ),
						'one' => q({0} ունկի),
						'other' => q({0} ունկի),
						'per' => q({0} ունկիի վրա),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ունկիներ),
						'one' => q({0} ունկի),
						'other' => q({0} ունկի),
						'per' => q({0} ունկիի վրա),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(տրոյական ունկիներ),
						'one' => q({0} տրոյական ունկի),
						'other' => q({0} տրոյական ունկի),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(տրոյական ունկիներ),
						'one' => q({0} տրոյական ունկի),
						'other' => q({0} տրոյական ունկի),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ֆունտեր),
						'per' => q({0} ֆունտի վրա),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ֆունտեր),
						'per' => q({0} ֆունտի վրա),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(արեգակնային զանգվածներ),
						'one' => q({0} արեգակնային զանգված),
						'other' => q({0} արեգակնային զանգված),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(արեգակնային զանգվածներ),
						'one' => q({0} արեգակնային զանգված),
						'other' => q({0} արեգակնային զանգված),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ամերիկյան տոննաներ),
						'one' => q({0} ամերիկյան տոննա),
						'other' => q({0} ամերիկյան տոննա),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ամերիկյան տոննաներ),
						'one' => q({0} ամերիկյան տոննա),
						'other' => q({0} ամերիկյան տոննա),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(տոննաներ),
						'one' => q({0} տոննա),
						'other' => q({0} տոննա),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(տոննաներ),
						'one' => q({0} տոննա),
						'other' => q({0} տոննա),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(գիգավատտեր),
						'one' => q({0} գիգավատտ),
						'other' => q({0} գիգավատտ),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(գիգավատտեր),
						'one' => q({0} գիգավատտ),
						'other' => q({0} գիգավատտ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ձիաուժեր),
						'one' => q({0} ձիաուժ),
						'other' => q({0} ձիաուժ),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ձիաուժեր),
						'one' => q({0} ձիաուժ),
						'other' => q({0} ձիաուժ),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(կիլովատտեր),
						'one' => q({0} կիլովատտ),
						'other' => q({0} կիլովատտ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(կիլովատտեր),
						'one' => q({0} կիլովատտ),
						'other' => q({0} կիլովատտ),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(մեգավատտեր),
						'one' => q({0} մեգավատտ),
						'other' => q({0} մեգավատտ),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(մեգավատտեր),
						'one' => q({0} մեգավատտ),
						'other' => q({0} մեգավատտ),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(միլիվատտեր),
						'one' => q({0} միլիվատտ),
						'other' => q({0} միլիվատտ),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(միլիվատտեր),
						'one' => q({0} միլիվատտ),
						'other' => q({0} միլիվատտ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'name' => q(վատտեր),
						'one' => q({0} վատտ),
						'other' => q({0} վատտ),
					},
					# Core Unit Identifier
					'watt' => {
						'name' => q(վատտեր),
						'one' => q({0} վատտ),
						'other' => q({0} վատտ),
					},
					# Long Unit Identifier
					'power2' => {
						'one' => q(քառակուսի {0}),
						'other' => q(քառակուսի {0}),
					},
					# Core Unit Identifier
					'power2' => {
						'one' => q(քառակուսի {0}),
						'other' => q(քառակուսի {0}),
					},
					# Long Unit Identifier
					'power3' => {
						'one' => q(խորանարդ {0}),
						'other' => q(խորանարդ {0}),
					},
					# Core Unit Identifier
					'power3' => {
						'one' => q(խորանարդ {0}),
						'other' => q(խորանարդ {0}),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'name' => q(մթնոլորտներ),
						'one' => q({0} մթնոլորտ),
						'other' => q({0} մթնոլորտ),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'name' => q(մթնոլորտներ),
						'one' => q({0} մթնոլորտ),
						'other' => q({0} մթնոլորտ),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'name' => q(բարեր),
						'one' => q({0} բար),
						'other' => q({0} բար),
					},
					# Core Unit Identifier
					'bar' => {
						'name' => q(բարեր),
						'one' => q({0} բար),
						'other' => q({0} բար),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'name' => q(հեկտոպասկալ),
						'one' => q({0} հեկտոպասկալ),
						'other' => q({0} հեկտոպասկալ),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'name' => q(հեկտոպասկալ),
						'one' => q({0} հեկտոպասկալ),
						'other' => q({0} հեկտոպասկալ),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(սնդիկի սյան դյույմեր),
						'one' => q({0} դյույմ սնդիկի սյուն),
						'other' => q({0} դյույմ սնդիկի սյուն),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(սնդիկի սյան դյույմեր),
						'one' => q({0} դյույմ սնդիկի սյուն),
						'other' => q({0} դյույմ սնդիկի սյուն),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(կիլոպասկալներ),
						'one' => q({0} կիլոպասկալ),
						'other' => q({0} կիլոպասկալ),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(կիլոպասկալներ),
						'one' => q({0} կիլոպասկալ),
						'other' => q({0} կիլոպասկալ),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(մեգապասկալներ),
						'one' => q({0} մեգապասկալ),
						'other' => q({0} մեգապասկալ),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(մեգապասկալներ),
						'one' => q({0} մեգապասկալ),
						'other' => q({0} մեգապասկալ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(միլիբարեր),
						'one' => q({0} միլիբար),
						'other' => q({0} միլիբար),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(միլիբարեր),
						'one' => q({0} միլիբար),
						'other' => q({0} միլիբար),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(սնդիկի սյան միլիմետրեր),
						'one' => q({0} միլիմետր սնդիկի սյուն),
						'other' => q({0} միլիմետր սնդիկի սյուն),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(սնդիկի սյան միլիմետրեր),
						'one' => q({0} միլիմետր սնդիկի սյուն),
						'other' => q({0} միլիմետր սնդիկի սյուն),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'name' => q(պասկալներ),
						'one' => q({0} պասկալ),
						'other' => q({0} պասկալ),
					},
					# Core Unit Identifier
					'pascal' => {
						'name' => q(պասկալներ),
						'one' => q({0} պասկալ),
						'other' => q({0} պասկալ),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ֆունտեր քառակուսի դյույմի վրա),
						'one' => q({0} ֆունտ քառակուսի դյույմի վրա),
						'other' => q({0} ֆունտ քառակուսի դյույմի վրա),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ֆունտեր քառակուսի դյույմի վրա),
						'one' => q({0} ֆունտ քառակուսի դյույմի վրա),
						'other' => q({0} ֆունտ քառակուսի դյույմի վրա),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'name' => q(Բոֆորտ),
						'one' => q(Բոֆորտ {0}),
						'other' => q(Բոֆորտ {0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'name' => q(Բոֆորտ),
						'one' => q(Բոֆորտ {0}),
						'other' => q(Բոֆորտ {0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(կիլոմետրեր ժամում),
						'one' => q({0} կիլոմետր ժամում),
						'other' => q({0} կիլոմետր ժամում),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(կիլոմետրեր ժամում),
						'one' => q({0} կիլոմետր ժամում),
						'other' => q({0} կիլոմետր ժամում),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(հանգույցներ),
						'one' => q({0} հանգույց),
						'other' => q({0} հանգույց),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(հանգույցներ),
						'one' => q({0} հանգույց),
						'other' => q({0} հանգույց),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(մետրեր վայրկյանում),
						'one' => q({0} մետր վայրկյանում),
						'other' => q({0} մետր վայրկյանում),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(մետրեր վայրկյանում),
						'one' => q({0} մետր վայրկյանում),
						'other' => q({0} մետր վայրկյանում),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(մղոններ ժամում),
						'one' => q({0} մղոն ժամում),
						'other' => q({0} մղոն ժամում),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(մղոններ ժամում),
						'one' => q({0} մղոն ժամում),
						'other' => q({0} մղոն ժամում),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(աստիճաններ ըստ Ցելսիուսի),
						'one' => q({0} աստիճան ըստ Ցելսիուսի),
						'other' => q({0} աստիճան ըստ Ցելսիուսի),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(աստիճաններ ըստ Ցելսիուսի),
						'one' => q({0} աստիճան ըստ Ցելսիուսի),
						'other' => q({0} աստիճան ըստ Ցելսիուսի),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(աստիճաններ ըստ Ֆարենհայթի),
						'one' => q({0} աստիճան ըստ Ֆարենհայթի),
						'other' => q({0} աստիճան ըստ Ֆարենհայթի),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(աստիճաններ ըստ Ֆարենհայթի),
						'one' => q({0} աստիճան ըստ Ֆարենհայթի),
						'other' => q({0} աստիճան ըստ Ֆարենհայթի),
					},
					# Long Unit Identifier
					'temperature-generic' => {
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Core Unit Identifier
					'generic' => {
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'name' => q(կելվիններ),
						'one' => q({0} կելվին),
						'other' => q({0} կելվին),
					},
					# Core Unit Identifier
					'kelvin' => {
						'name' => q(կելվիններ),
						'one' => q({0} կելվին),
						'other' => q({0} կելվին),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(նյուտոն-մետրեր),
						'one' => q({0} նյուտոն-մետր),
						'other' => q({0} նյուտոն-մետր),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(նյուտոն-մետրեր),
						'one' => q({0} նյուտոն-մետր),
						'other' => q({0} նյուտոն-մետր),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(ֆունտ-ֆուտեր),
						'one' => q({0} ֆունտ-ֆուտ),
						'other' => q({0} ֆունտ-ֆուտ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(ֆունտ-ֆուտեր),
						'one' => q({0} ֆունտ-ֆուտ),
						'other' => q({0} ֆունտ-ֆուտ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ակրոֆուտեր),
						'one' => q({0} ակրոֆուտ),
						'other' => q({0} ակրոֆուտ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ակրոֆուտեր),
						'one' => q({0} ակրոֆուտ),
						'other' => q({0} ակրոֆուտ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(տակառներ),
						'one' => q({0} տակառ),
						'other' => q({0} տակառ),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(տակառներ),
						'one' => q({0} տակառ),
						'other' => q({0} տակառ),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'name' => q(բուշել),
						'one' => q({0} բուշել),
						'other' => q({0} բուշել),
					},
					# Core Unit Identifier
					'bushel' => {
						'name' => q(բուշել),
						'one' => q({0} բուշել),
						'other' => q({0} բուշել),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(սանտիլիտրեր),
						'one' => q({0} սանտիլիտր),
						'other' => q({0} սանտիլիտր),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(սանտիլիտրեր),
						'one' => q({0} սանտիլիտր),
						'other' => q({0} սանտիլիտր),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(խորանարդ սանտիմետրեր),
						'one' => q({0} խորանարդ սանտիմետր),
						'other' => q({0} խորանարդ սանտիմետր),
						'per' => q({0} խորանարդ սանտիմետրի վրա),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(խորանարդ սանտիմետրեր),
						'one' => q({0} խորանարդ սանտիմետր),
						'other' => q({0} խորանարդ սանտիմետր),
						'per' => q({0} խորանարդ սանտիմետրի վրա),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(խորանարդ ֆուտ),
						'one' => q({0} խորանարդ ֆուտ),
						'other' => q({0} խորանարդ ֆուտ),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(խորանարդ ֆուտ),
						'one' => q({0} խորանարդ ֆուտ),
						'other' => q({0} խորանարդ ֆուտ),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(խորանարդ մատնաչափեր),
						'one' => q({0} խորանարդ մատնաչափ),
						'other' => q({0} խորանարդ մատնաչափ),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(խորանարդ մատնաչափեր),
						'one' => q({0} խորանարդ մատնաչափ),
						'other' => q({0} խորանարդ մատնաչափ),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(խորանարդ կիլոմետրեր),
						'one' => q({0} խորանարդ կիլոմետր),
						'other' => q({0} խորանարդ կիլոմետր),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(խորանարդ կիլոմետրեր),
						'one' => q({0} խորանարդ կիլոմետր),
						'other' => q({0} խորանարդ կիլոմետր),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(խորանարդ մետրեր),
						'one' => q({0} խորանարդ մետր),
						'other' => q({0} խորանարդ մետր),
						'per' => q({0} խորանարդ մետրի վրա),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(խորանարդ մետրեր),
						'one' => q({0} խորանարդ մետր),
						'other' => q({0} խորանարդ մետր),
						'per' => q({0} խորանարդ մետրի վրա),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(խորանարդ մղոններ),
						'one' => q({0} խորանարդ մղոն),
						'other' => q({0} խորանարդ մղոն),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(խորանարդ մղոններ),
						'one' => q({0} խորանարդ մղոն),
						'other' => q({0} խորանարդ մղոն),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(խորանարդ յարդեր),
						'one' => q({0} խորանարդ յարդ),
						'other' => q({0} խորանարդ յարդ),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(խորանարդ յարդեր),
						'one' => q({0} խորանարդ յարդ),
						'other' => q({0} խորանարդ յարդ),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'one' => q({0} բաժակ),
						'other' => q({0} բաժակ),
					},
					# Core Unit Identifier
					'cup' => {
						'one' => q({0} բաժակ),
						'other' => q({0} բաժակ),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(մետրիկ բաժակներ),
						'one' => q({0} մետրիկ բաժակ),
						'other' => q({0} մետրիկ բաժակ),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(մետրիկ բաժակներ),
						'one' => q({0} մետրիկ բաժակ),
						'other' => q({0} մետրիկ բաժակ),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(դեցիլիտրեր),
						'one' => q({0} դեցիլիտր),
						'other' => q({0} դեցիլիտր),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(դեցիլիտրեր),
						'one' => q({0} դեցիլիտր),
						'other' => q({0} դեցիլիտր),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(աղանդերի գդալ),
						'one' => q({0} աղանդերի գդալ),
						'other' => q({0} աղանդերի գդալ),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(աղանդերի գդալ),
						'one' => q({0} աղանդերի գդալ),
						'other' => q({0} աղանդերի գդալ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(անգլիական աղանդերի գդալ),
						'one' => q({0} անգլիական աղանդերի գդալ),
						'other' => q({0} անգլիական աղանդերի գդալ),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(անգլիական աղանդերի գդալ),
						'one' => q({0} անգլիական աղանդերի գդալ),
						'other' => q({0} անգլիական աղանդերի գդալ),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(դրամ),
						'one' => q({0} դրամ),
						'other' => q({0} դրամ),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(դրամ),
						'one' => q({0} դրամ),
						'other' => q({0} դրամ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(հեղուկ ունկիներ),
						'one' => q({0} հեղուկ ունկի),
						'other' => q({0} հեղուկ ունկի),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(հեղուկ ունկիներ),
						'one' => q({0} հեղուկ ունկի),
						'other' => q({0} հեղուկ ունկի),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(անգլիական հեղուկ ունկիներ),
						'one' => q({0} անգլիական հեղուկ ունկի),
						'other' => q({0} անգլիական հեղուկ ունկի),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(անգլիական հեղուկ ունկիներ),
						'one' => q({0} անգլիական հեղուկ ունկի),
						'other' => q({0} անգլիական հեղուկ ունկի),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(գալոններ),
						'one' => q({0} գալոն),
						'other' => q({0} գալոն),
						'per' => q({0} գալոնի վրա),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(գալոններ),
						'one' => q({0} գալոն),
						'other' => q({0} գալոն),
						'per' => q({0} գալոնի վրա),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(անգլիական գալոններ),
						'one' => q({0} անգլիական գալոն),
						'other' => q({0} անգլիական գալոն),
						'per' => q({0} անգլիական գալոնի վրա),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(անգլիական գալոններ),
						'one' => q({0} անգլիական գալոն),
						'other' => q({0} անգլիական գալոն),
						'per' => q({0} անգլիական գալոնի վրա),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(հեկտոլիտրեր),
						'one' => q({0} հեկտոլիտր),
						'other' => q({0} հեկտոլիտր),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(հեկտոլիտրեր),
						'one' => q({0} հեկտոլիտր),
						'other' => q({0} հեկտոլիտր),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(լիտրեր),
						'one' => q({0} լիտր),
						'other' => q({0} լիտր),
						'per' => q({0} լիտրի վրա),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(լիտրեր),
						'one' => q({0} լիտր),
						'other' => q({0} լիտր),
						'per' => q({0} լիտրի վրա),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(մեգալիտրեր),
						'one' => q({0} մեգալիտր),
						'other' => q({0} մեգալիտր),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(մեգալիտրեր),
						'one' => q({0} մեգալիտր),
						'other' => q({0} մեգալիտր),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(միլիլիտրեր),
						'one' => q({0} միլիլիտր),
						'other' => q({0} միլիլիտր),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(միլիլիտրեր),
						'one' => q({0} միլիլիտր),
						'other' => q({0} միլիլիտր),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(մետրիկ փինթեր),
						'one' => q({0} մետրիկ փինթ),
						'other' => q({0} մետրիկ փինթ),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(մետրիկ փինթեր),
						'one' => q({0} մետրիկ փինթ),
						'other' => q({0} մետրիկ փինթ),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(քվարտեր),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(քվարտեր),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(ճաշի գդալ),
						'one' => q({0} ճաշի գդալ),
						'other' => q({0} ճաշի գդալ),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(ճաշի գդալ),
						'one' => q({0} ճաշի գդալ),
						'other' => q({0} ճաշի գդալ),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(թեյի գդալ),
						'one' => q({0} թեյի գդալ),
						'other' => q({0} թեյի գդալ),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(թեյի գդալ),
						'one' => q({0} թեյի գդալ),
						'other' => q({0} թեյի գդալ),
					},
				},
				'narrow' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ուղղ․),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ուղղ․),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'one' => q({0}G),
						'other' => q({0}G),
					},
					# Core Unit Identifier
					'g-force' => {
						'one' => q({0}G),
						'other' => q({0}G),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(րոպե),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(րոպե),
					},
					# Long Unit Identifier
					'area-acre' => {
						'one' => q({0}ակր),
						'other' => q({0}ակր),
					},
					# Core Unit Identifier
					'acre' => {
						'one' => q({0}ակր),
						'other' => q({0}ակր),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'one' => q({0}ֆտ²),
						'other' => q({0}ֆտ²),
					},
					# Core Unit Identifier
					'square-foot' => {
						'one' => q({0}ֆտ²),
						'other' => q({0}ֆտ²),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'one' => q({0}մղ²),
						'other' => q({0}մղ²),
					},
					# Core Unit Identifier
					'square-mile' => {
						'one' => q({0}մղ²),
						'other' => q({0}մղ²),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'one' => q({0}մմոլ/լ),
						'other' => q({0}մմոլ/լ),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'one' => q({0}մմոլ/լ),
						'other' => q({0}մմոլ/լ),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'one' => q({0}մոլ),
						'other' => q({0}մոլ),
					},
					# Core Unit Identifier
					'mole' => {
						'one' => q({0}մոլ),
						'other' => q({0}մոլ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(%),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(%),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(‰),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(‰),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(մմվ),
						'one' => q({0}մմվ),
						'other' => q({0}մմվ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(մմվ),
						'one' => q({0}մմվ),
						'other' => q({0}մմվ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'one' => q({0}լ/կմ),
						'other' => q({0}լ/կմ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'one' => q({0}լ/կմ),
						'other' => q({0}լ/կմ),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'one' => q({0} Բ),
						'other' => q({0} Բ),
					},
					# Core Unit Identifier
					'byte' => {
						'one' => q({0} Բ),
						'other' => q({0} Բ),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ԳԲ),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ԳԲ),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(կԲ),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(կԲ),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(ՄԲ),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(ՄԲ),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(օ),
						'one' => q({0} օ),
						'other' => q({0} օ),
						'per' => q({0}/օ),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(օ),
						'one' => q({0} օ),
						'other' => q({0} օ),
						'per' => q({0}/օ),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ա),
						'one' => q({0} ա),
						'other' => q({0} ա),
						'per' => q({0}/ա),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ա),
						'one' => q({0} ա),
						'other' => q({0} ա),
						'per' => q({0}/ա),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(վ),
						'one' => q({0} վ),
						'other' => q({0} վ),
						'per' => q({0}/վ),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(վ),
						'one' => q({0} վ),
						'other' => q({0} վ),
						'per' => q({0}/վ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(շ),
						'one' => q({0} շ),
						'other' => q({0} շ),
						'per' => q({0}/շ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(շ),
						'one' => q({0} շ),
						'other' => q({0} շ),
						'per' => q({0}/շ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'one' => q({0} կալ),
						'other' => q({0}կալ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'one' => q({0} կալ),
						'other' => q({0}կալ),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'one' => q({0} կՎտժ/100 կմ),
						'other' => q({0} կՎտժ/100 կմ),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'one' => q({0} կՎտժ/100 կմ),
						'other' => q({0} կՎտժ/100 կմ),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'name' => q(կտ),
					},
					# Core Unit Identifier
					'pixel' => {
						'name' => q(կտ),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'name' => q(կսմվ),
						'one' => q({0}կսմվ),
						'other' => q({0}կսմվ),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'name' => q(կսմվ),
						'one' => q({0}կսմվ),
						'other' => q({0}կսմվ),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ֆատոմ),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ֆատոմ),
					},
					# Long Unit Identifier
					'length-foot' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					# Core Unit Identifier
					'foot' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ֆուրլ․),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ֆուրլ․),
					},
					# Long Unit Identifier
					'length-inch' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					# Core Unit Identifier
					'inch' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'one' => q({0} լ. տ.),
						'other' => q({0} լ. տ.),
					},
					# Core Unit Identifier
					'light-year' => {
						'one' => q({0} լ. տ.),
						'other' => q({0} լ. տ.),
					},
					# Long Unit Identifier
					'length-yard' => {
						'one' => q({0} յդ.),
						'other' => q({0} յդ.),
					},
					# Core Unit Identifier
					'yard' => {
						'one' => q({0} յդ.),
						'other' => q({0} յդ.),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'one' => q({0} ունց),
						'other' => q({0} ունց),
					},
					# Core Unit Identifier
					'ounce' => {
						'one' => q({0} ունց),
						'other' => q({0} ունց),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'one' => q({0}#),
						'other' => q({0}#),
					},
					# Core Unit Identifier
					'pound' => {
						'one' => q({0}#),
						'other' => q({0}#),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'one' => q({0}տ),
						'other' => q({0}տ),
					},
					# Core Unit Identifier
					'tonne' => {
						'one' => q({0}տ),
						'other' => q({0}տ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'one' => q({0}ձ/ու),
						'other' => q({0}ձ/ու),
					},
					# Core Unit Identifier
					'horsepower' => {
						'one' => q({0}ձ/ու),
						'other' => q({0}ձ/ու),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'one' => q({0}կՎ),
						'other' => q({0}կՎ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'one' => q({0}կՎ),
						'other' => q({0}կՎ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'one' => q({0}Վ),
						'other' => q({0}Վ),
					},
					# Core Unit Identifier
					'watt' => {
						'one' => q({0}Վ),
						'other' => q({0}Վ),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'one' => q({0}" ս.ս.),
						'other' => q({0}" ս. ս.),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'one' => q({0}" ս.ս.),
						'other' => q({0}" ս. ս.),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'one' => q({0} մբ),
						'other' => q({0} մբ),
					},
					# Core Unit Identifier
					'millibar' => {
						'one' => q({0} մբ),
						'other' => q({0} մբ),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'one' => q(Բ{0}),
						'other' => q(Բ{0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'one' => q(Բ{0}),
						'other' => q(Բ{0}),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'one' => q({0}մ/վ),
						'other' => q({0}մ/վ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'one' => q({0}մ/վ),
						'other' => q({0}մ/վ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'one' => q({0}մղ/ժ),
						'other' => q({0}մղ/ժ),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'one' => q({0}մղ/ժ),
						'other' => q({0}մղ/ժ),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'one' => q({0}կմ³),
						'other' => q({0}կմ³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'one' => q({0}կմ³),
						'other' => q({0}կմ³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'one' => q({0}մղ³),
						'other' => q({0}մղ³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'one' => q({0}մղ³),
						'other' => q({0}մղ³),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(մետր․ փինթեր),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(մետր․ փինթեր),
					},
				},
				'short' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ուղղություն),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ուղղություն),
					},
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(Կի{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(Կի{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(Մի{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(Մի{0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(Գի{0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(Գի{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(Տի{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(Տի{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(Փի{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(Փի{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(Էի{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(Էի{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(Զի{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(Զի{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(Յի{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(Յի{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(դ{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(դ{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(պ{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(պ{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ֆ{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ֆ{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ա{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ա{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ս{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ս{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(զ{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(զ{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(յ{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(յ{0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ռ{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ռ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(մ{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(մ{0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ք{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ք{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(մկ{0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(մկ{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ն{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ն{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(դա{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(դա{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(Տ{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(Տ{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(Պ{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(Պ{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(Է{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(Է{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(հ{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(հ{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(Զ{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(Զ{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(Յ{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(Յ{0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(Ռ{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(Ռ{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(կ{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(կ{0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(Ք{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(Ք{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(Մ{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(Մ{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(Գ{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(Գ{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(g),
						'one' => q({0} g),
						'other' => q({0} g),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(g),
						'one' => q({0} g),
						'other' => q({0} g),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(մ/վ²),
						'one' => q({0} մ/վ²),
						'other' => q({0} մ/վ²),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(մ/վ²),
						'one' => q({0} մ/վ²),
						'other' => q({0} մ/վ²),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(րոպեներ),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(րոպեներ),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'name' => q(վայրկյաններ),
					},
					# Core Unit Identifier
					'arc-second' => {
						'name' => q(վայրկյաններ),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(աստիճան),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(աստիճան),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'name' => q(ռադ),
						'one' => q({0} ռադ),
						'other' => q({0} ռադ),
					},
					# Core Unit Identifier
					'radian' => {
						'name' => q(ռադ),
						'one' => q({0} ռադ),
						'other' => q({0} ռադ),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(պտ),
						'one' => q({0} պտ),
						'other' => q({0} պտ),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(պտ),
						'one' => q({0} պտ),
						'other' => q({0} պտ),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ակր),
						'one' => q({0} ակր),
						'other' => q({0} ակր),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ակր),
						'one' => q({0} ակր),
						'other' => q({0} ակր),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(դունամ),
						'one' => q({0} դունամ),
						'other' => q({0} դունամ),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(դունամ),
						'one' => q({0} դունամ),
						'other' => q({0} դունամ),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(հա),
						'one' => q({0} հա),
						'other' => q({0} հա),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(հա),
						'one' => q({0} հա),
						'other' => q({0} հա),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(սմ²),
						'one' => q({0} սմ²),
						'other' => q({0} սմ²),
						'per' => q({0}/սմ²),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(սմ²),
						'one' => q({0} սմ²),
						'other' => q({0} սմ²),
						'per' => q({0}/սմ²),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(ֆտ²),
						'one' => q({0} ֆտ²),
						'other' => q({0} ֆտ²),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(ֆտ²),
						'one' => q({0} ֆտ²),
						'other' => q({0} ֆտ²),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(մատ²),
						'one' => q({0} մատ²),
						'other' => q({0} մատ²),
						'per' => q({0}/մատ²),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(մատ²),
						'one' => q({0} մատ²),
						'other' => q({0} մատ²),
						'per' => q({0}/մատ²),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(կմ²),
						'one' => q({0} կմ²),
						'other' => q({0} կմ²),
						'per' => q({0}/կմ²),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(կմ²),
						'one' => q({0} կմ²),
						'other' => q({0} կմ²),
						'per' => q({0}/կմ²),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(մ²),
						'one' => q({0} մ²),
						'other' => q({0} մ²),
						'per' => q({0}/մ²),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(մ²),
						'one' => q({0} մ²),
						'other' => q({0} մ²),
						'per' => q({0}/մ²),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'name' => q(մղ²),
						'one' => q({0} մղ²),
						'other' => q({0} մղ²),
						'per' => q({0}/մղ²),
					},
					# Core Unit Identifier
					'square-mile' => {
						'name' => q(մղ²),
						'one' => q({0} մղ²),
						'other' => q({0} մղ²),
						'per' => q({0}/մղ²),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(յրդ²),
						'one' => q({0} յրդ²),
						'other' => q({0} յրդ²),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(յրդ²),
						'one' => q({0} յրդ²),
						'other' => q({0} յրդ²),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'name' => q(միույթ),
						'one' => q({0} միույթ),
						'other' => q({0} միույթ),
					},
					# Core Unit Identifier
					'item' => {
						'name' => q(միույթ),
						'one' => q({0} միույթ),
						'other' => q({0} միույթ),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'name' => q(կար),
						'one' => q({0} կար),
						'other' => q({0} կար),
					},
					# Core Unit Identifier
					'karat' => {
						'name' => q(կար),
						'one' => q({0} կար),
						'other' => q({0} կար),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(մգ/դլ),
						'one' => q({0} մգ/դլ),
						'other' => q({0} մգ/դլ),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(մգ/դլ),
						'one' => q({0} մգ/դլ),
						'other' => q({0} մգ/դլ),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(մմոլ/լ),
						'one' => q({0} մմոլ/լ),
						'other' => q({0} մմոլ/լ),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(մմոլ/լ),
						'one' => q({0} մմոլ/լ),
						'other' => q({0} մմոլ/լ),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'name' => q(մոլ),
						'one' => q({0} մոլ),
						'other' => q({0} մոլ),
					},
					# Core Unit Identifier
					'mole' => {
						'name' => q(մոլ),
						'one' => q({0} մոլ),
						'other' => q({0} մոլ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(տոկոս),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(տոկոս),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(պրոմիլ),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(պրոմիլ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(մասնիկ/միլիոն),
						'one' => q({0} մմվ),
						'other' => q({0} մմվ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(մասնիկ/միլիոն),
						'one' => q({0} մմվ),
						'other' => q({0} մմվ),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(Լ/100 կմ),
						'one' => q({0} Լ/100 կմ),
						'other' => q({0} Լ/100 կմ),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(Լ/100 կմ),
						'one' => q({0} Լ/100 կմ),
						'other' => q({0} Լ/100 կմ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(լ/կմ),
						'one' => q({0} լ/կմ),
						'other' => q({0} լ/կմ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(լ/կմ),
						'one' => q({0} լ/կմ),
						'other' => q({0} լ/կմ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(մղ/գալ),
						'one' => q({0} մղ/գալ),
						'other' => q({0} մղ/գալ),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(մղ/գալ),
						'one' => q({0} մղ/գալ),
						'other' => q({0} մղ/գալ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(մղ/անգլ․ գալ),
						'one' => q({0} մղ/անգլ․ գալ),
						'other' => q({0} մղ/անգլ․ գալ),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(մղ/անգլ․ գալ),
						'one' => q({0} մղ/անգլ․ գալ),
						'other' => q({0} մղ/անգլ․ գալ),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} ավ․ ե․),
						'north' => q({0} հս․ լ․),
						'south' => q({0} հվ․ լ․),
						'west' => q({0} ամ․ ե․),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} ավ․ ե․),
						'north' => q({0} հս․ լ․),
						'south' => q({0} հվ․ լ․),
						'west' => q({0} ամ․ ե․),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'name' => q(բիթ),
						'one' => q({0} բիթ),
						'other' => q({0} բիթ),
					},
					# Core Unit Identifier
					'bit' => {
						'name' => q(բիթ),
						'one' => q({0} բիթ),
						'other' => q({0} բիթ),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(Բ),
						'one' => q({0} Բայթ),
						'other' => q({0} Բ),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(Բ),
						'one' => q({0} Բայթ),
						'other' => q({0} Բ),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(Գբիթ),
						'one' => q({0} Գբիթ),
						'other' => q({0} Գբիթ),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(Գբիթ),
						'one' => q({0} Գբիթ),
						'other' => q({0} Գբիթ),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ԳԲայթ),
						'one' => q({0} ԳԲ),
						'other' => q({0} ԳԲ),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ԳԲայթ),
						'one' => q({0} ԳԲ),
						'other' => q({0} ԳԲ),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(կբիթ),
						'one' => q({0} կբիթ),
						'other' => q({0} կբիթ),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(կբիթ),
						'one' => q({0} կբիթ),
						'other' => q({0} կբիթ),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(կԲայթ),
						'one' => q({0} կԲ),
						'other' => q({0} կԲ),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(կԲայթ),
						'one' => q({0} կԲ),
						'other' => q({0} կԲ),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(Մբիթ),
						'one' => q({0} Մբիթ),
						'other' => q({0} Մբիթ),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(Մբիթ),
						'one' => q({0} Մբիթ),
						'other' => q({0} Մբիթ),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(ՄԲայթ),
						'one' => q({0} ՄԲ),
						'other' => q({0} ՄԲ),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(ՄԲայթ),
						'one' => q({0} ՄԲ),
						'other' => q({0} ՄԲ),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(ՊԲայթ),
						'one' => q({0} ՊԲ),
						'other' => q({0} ՊԲ),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(ՊԲայթ),
						'one' => q({0} ՊԲ),
						'other' => q({0} ՊԲ),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(Տբիթ),
						'one' => q({0} Տբիթ),
						'other' => q({0} Տբիթ),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(Տբիթ),
						'one' => q({0} Տբիթ),
						'other' => q({0} Տբիթ),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(ՏԲայթ),
						'one' => q({0} ՏԲ),
						'other' => q({0} ՏԲ),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(ՏԲայթ),
						'one' => q({0} ՏԲ),
						'other' => q({0} ՏԲ),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(դ․),
						'one' => q({0} դ․),
						'other' => q({0} դ․),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(դ․),
						'one' => q({0} դ․),
						'other' => q({0} դ․),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(օր),
						'one' => q({0} օր),
						'other' => q({0} օր),
						'per' => q({0}/օր),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(օր),
						'one' => q({0} օր),
						'other' => q({0} օր),
						'per' => q({0}/օր),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(10-ամյակ),
						'one' => q({0} 10-ամյակ),
						'other' => q({0} 10-ամյակ),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(10-ամյակ),
						'one' => q({0} 10-ամյակ),
						'other' => q({0} 10-ամյակ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ժ),
						'one' => q({0} ժ),
						'other' => q({0} ժ),
						'per' => q({0}/ժ),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ժ),
						'one' => q({0} ժ),
						'other' => q({0} ժ),
						'per' => q({0}/ժ),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(մկվ),
						'one' => q({0} մկվ),
						'other' => q({0} մկվ),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(մկվ),
						'one' => q({0} մկվ),
						'other' => q({0} մկվ),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(մվ),
						'one' => q({0} մվ),
						'other' => q({0} մվ),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(մվ),
						'one' => q({0} մվ),
						'other' => q({0} մվ),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(ր),
						'one' => q({0} ր),
						'other' => q({0} ր),
						'per' => q({0}/ր),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(ր),
						'one' => q({0} ր),
						'other' => q({0} ր),
						'per' => q({0}/ր),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ամս),
						'one' => q({0} ամս),
						'other' => q({0} ամս),
						'per' => q({0}/ամս),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ամս),
						'one' => q({0} ամս),
						'other' => q({0} ամս),
						'per' => q({0}/ամս),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'name' => q(նվ),
						'one' => q({0} նվ),
						'other' => q({0} նվ),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'name' => q(նվ),
						'one' => q({0} նվ),
						'other' => q({0} նվ),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'name' => q(եռմս),
						'one' => q({0} եռմս),
						'other' => q({0} եռմս),
						'per' => q({0}/եռմս),
					},
					# Core Unit Identifier
					'quarter' => {
						'name' => q(եռմս),
						'one' => q({0} եռմս),
						'other' => q({0} եռմս),
						'per' => q({0}/եռմս),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(վրկ),
						'one' => q({0} վրկ),
						'other' => q({0} վրկ),
						'per' => q({0}/վրկ),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(վրկ),
						'one' => q({0} վրկ),
						'other' => q({0} վրկ),
						'per' => q({0}/վրկ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(շաբ),
						'one' => q({0} շաբ),
						'other' => q({0} շաբ),
						'per' => q({0}/շաբ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(շաբ),
						'one' => q({0} շաբ),
						'other' => q({0} շաբ),
						'per' => q({0}/շաբ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(տ),
						'one' => q({0} տ),
						'other' => q({0} տ),
						'per' => q({0}/տ),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(տ),
						'one' => q({0} տ),
						'other' => q({0} տ),
						'per' => q({0}/տ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(Ա),
						'one' => q({0} Ա),
						'other' => q({0} Ա),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(Ա),
						'one' => q({0} Ա),
						'other' => q({0} Ա),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(մԱ),
						'one' => q({0} մԱ),
						'other' => q({0} մԱ),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(մԱ),
						'one' => q({0} մԱ),
						'other' => q({0} մԱ),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'name' => q(օհմեր),
						'one' => q({0} Օհմ),
						'other' => q({0} Օհմ),
					},
					# Core Unit Identifier
					'ohm' => {
						'name' => q(օհմեր),
						'one' => q({0} Օհմ),
						'other' => q({0} Օհմ),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'name' => q(Վ),
						'one' => q({0} Վ),
						'other' => q({0} Վ),
					},
					# Core Unit Identifier
					'volt' => {
						'name' => q(Վ),
						'one' => q({0} Վ),
						'other' => q({0} Վ),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(ԲՋՄ),
						'one' => q({0} Բջմ),
						'other' => q({0} Բջմ),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(ԲՋՄ),
						'one' => q({0} Բջմ),
						'other' => q({0} Բջմ),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(կալ),
						'one' => q({0} կալ),
						'other' => q({0} կալ),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(կալ),
						'one' => q({0} կալ),
						'other' => q({0} կալ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(էՎ),
						'one' => q({0} էՎ),
						'other' => q({0} էՎ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(էՎ),
						'one' => q({0} էՎ),
						'other' => q({0} էՎ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(կալ),
						'one' => q({0} կալ),
						'other' => q({0} կալ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(կալ),
						'one' => q({0} կալ),
						'other' => q({0} կալ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'name' => q(Ջ),
						'one' => q({0} Ջ),
						'other' => q({0} Ջ),
					},
					# Core Unit Identifier
					'joule' => {
						'name' => q(Ջ),
						'one' => q({0} Ջ),
						'other' => q({0} Ջ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(կկալ),
						'one' => q({0} կկալ),
						'other' => q({0} կկալ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(կկալ),
						'one' => q({0} կկալ),
						'other' => q({0} կկալ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'name' => q(կՋ),
						'one' => q({0} կՋ),
						'other' => q({0} կՋ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'name' => q(կՋ),
						'one' => q({0} կՋ),
						'other' => q({0} կՋ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(կՎտ·ժ),
						'one' => q({0} կՎտ·ժ),
						'other' => q({0} կՎտ·ժ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(կՎտ·ժ),
						'one' => q({0} կՎտ·ժ),
						'other' => q({0} կՎտ·ժ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ԱՄՆ ջերմ),
						'one' => q({0} ԱՄՆ ջերմ),
						'other' => q({0} ԱՄՆ ջերմ),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ԱՄՆ ջերմ),
						'one' => q({0} ԱՄՆ ջերմ),
						'other' => q({0} ԱՄՆ ջերմ),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'name' => q(կՎտ⋅ժ/100 կմ),
						'one' => q({0} կՎտ⋅ժ/100 կմ),
						'other' => q({0} կՎտ⋅ժ/100 կմ),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'name' => q(կՎտ⋅ժ/100 կմ),
						'one' => q({0} կՎտ⋅ժ/100 կմ),
						'other' => q({0} կՎտ⋅ժ/100 կմ),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(Ն),
						'one' => q({0} Ն),
						'other' => q({0} Ն),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(Ն),
						'one' => q({0} Ն),
						'other' => q({0} Ն),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ֆնտ․ ու․),
						'one' => q({0} ֆնտ․ ու․),
						'other' => q({0} ֆնտ․ ու․),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ֆնտ․ ու․),
						'one' => q({0} ֆնտ․ ու․),
						'other' => q({0} ֆնտ․ ու․),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(ԳՀց),
						'one' => q({0} ԳՀց),
						'other' => q({0} ԳՀց),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(ԳՀց),
						'one' => q({0} ԳՀց),
						'other' => q({0} ԳՀց),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'name' => q(Հց),
						'one' => q({0} Հց),
						'other' => q({0} Հց),
					},
					# Core Unit Identifier
					'hertz' => {
						'name' => q(Հց),
						'one' => q({0} Հց),
						'other' => q({0} Հց),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'name' => q(կՀց),
						'one' => q({0} կՀց),
						'other' => q({0} կՀց),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'name' => q(կՀց),
						'one' => q({0} կՀց),
						'other' => q({0} կՀց),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'name' => q(ՄՀց),
						'one' => q({0} ՄՀց),
						'other' => q({0} ՄՀց),
					},
					# Core Unit Identifier
					'megahertz' => {
						'name' => q(ՄՀց),
						'one' => q({0} ՄՀց),
						'other' => q({0} ՄՀց),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(կետ),
						'one' => q({0} կետ),
						'other' => q({0} կետ),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(կետ),
						'one' => q({0} կետ),
						'other' => q({0} կետ),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(կսմ),
						'one' => q({0} կսմ),
						'other' => q({0} կսմ),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(կսմ),
						'one' => q({0} կսմ),
						'other' => q({0} կսմ),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(կմչ),
						'one' => q({0} կմչ),
						'other' => q({0} կմչ),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(կմչ),
						'one' => q({0} կմչ),
						'other' => q({0} կմչ),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'name' => q(մեգափիքսելներ),
						'one' => q({0} ՄՓ),
						'other' => q({0} ՄՓ),
					},
					# Core Unit Identifier
					'megapixel' => {
						'name' => q(մեգափիքսելներ),
						'one' => q({0} ՄՓ),
						'other' => q({0} ՄՓ),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'name' => q(փիքսելներ),
						'one' => q({0} փքս),
						'other' => q({0} փքս),
					},
					# Core Unit Identifier
					'pixel' => {
						'name' => q(փիքսելներ),
						'one' => q({0} փքս),
						'other' => q({0} փքս),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'name' => q(փսմ),
						'one' => q({0} փսմ),
						'other' => q({0} փսմ),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'name' => q(փսմ),
						'one' => q({0} փսմ),
						'other' => q({0} փսմ),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'name' => q(փմչ),
						'one' => q({0} փմչ),
						'other' => q({0} փմչ),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'name' => q(փմչ),
						'one' => q({0} փմչ),
						'other' => q({0} փմչ),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ա.մ.),
						'one' => q({0} ա.մ.),
						'other' => q({0} ա.մ.),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ա.մ.),
						'one' => q({0} ա.մ.),
						'other' => q({0} ա.մ.),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(սմ),
						'one' => q({0} սմ),
						'other' => q({0} սմ),
						'per' => q({0}/սմ),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(սմ),
						'one' => q({0} սմ),
						'other' => q({0} սմ),
						'per' => q({0}/սմ),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(դմ),
						'one' => q({0} դմ),
						'other' => q({0} դմ),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(դմ),
						'one' => q({0} դմ),
						'other' => q({0} դմ),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ծովային սաժեն),
						'one' => q({0} ֆատոմ),
						'other' => q({0} ֆատոմ),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ծովային սաժեն),
						'one' => q({0} ֆատոմ),
						'other' => q({0} ֆատոմ),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ֆտ),
						'one' => q({0} ֆտ),
						'other' => q({0} ֆտ),
						'per' => q({0}/ֆտ),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ֆտ),
						'one' => q({0} ֆտ),
						'other' => q({0} ֆտ),
						'per' => q({0}/ֆտ),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ֆուրլոնգ),
						'one' => q({0} ֆուրլ․),
						'other' => q({0} ֆուրլ․),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ֆուրլոնգ),
						'one' => q({0} ֆուրլ․),
						'other' => q({0} ֆուրլ․),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(մատ),
						'one' => q({0} մատ),
						'other' => q({0} մատ),
						'per' => q({0}/մատ),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(մատ),
						'one' => q({0} մատ),
						'other' => q({0} մատ),
						'per' => q({0}/մատ),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(կմ),
						'one' => q({0} կմ),
						'other' => q({0} կմ),
						'per' => q({0}/կմ),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(կմ),
						'one' => q({0} կմ),
						'other' => q({0} կմ),
						'per' => q({0}/կմ),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(լ․տ․),
						'one' => q({0} լ.տ.),
						'other' => q({0} լ.տ.),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(լ․տ․),
						'one' => q({0} լ.տ.),
						'other' => q({0} լ.տ.),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(մ),
						'one' => q({0} մ),
						'other' => q({0} մ),
						'per' => q({0}/մ),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(մ),
						'one' => q({0} մ),
						'other' => q({0} մ),
						'per' => q({0}/մ),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(մկմ),
						'one' => q({0} մկմ),
						'other' => q({0} մկմ),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(մկմ),
						'one' => q({0} մկմ),
						'other' => q({0} մկմ),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(մղ),
						'one' => q({0} մղ),
						'other' => q({0} մղ),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(մղ),
						'one' => q({0} մղ),
						'other' => q({0} մղ),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(սկանդ․ մղ),
						'one' => q({0} սկանդ․ մղ),
						'other' => q({0} սկանդ․ մղ),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(սկանդ․ մղ),
						'one' => q({0} սկանդ․ մղ),
						'other' => q({0} սկանդ․ մղ),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(մմ),
						'one' => q({0} մմ),
						'other' => q({0} մմ),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(մմ),
						'one' => q({0} մմ),
						'other' => q({0} մմ),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(նմ),
						'one' => q({0} նմ),
						'other' => q({0} նմ),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(նմ),
						'one' => q({0} նմ),
						'other' => q({0} նմ),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ծով․ մղ),
						'one' => q({0} ծով․ մղ),
						'other' => q({0} ծով․ մղ),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ծով․ մղ),
						'one' => q({0} ծով․ մղ),
						'other' => q({0} ծով․ մղ),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(պկ),
						'one' => q({0} պկ),
						'other' => q({0} պկ),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(պկ),
						'one' => q({0} պկ),
						'other' => q({0} պկ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(պմ),
						'one' => q({0} պմ),
						'other' => q({0} պմ),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(պմ),
						'one' => q({0} պմ),
						'other' => q({0} պմ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(յրդ),
						'one' => q({0} յրդ),
						'other' => q({0} յրդ),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(յրդ),
						'one' => q({0} յրդ),
						'other' => q({0} յրդ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'name' => q(կդ),
						'one' => q({0} կդ),
						'other' => q({0} կդ),
					},
					# Core Unit Identifier
					'candela' => {
						'name' => q(կդ),
						'one' => q({0} կդ),
						'other' => q({0} կդ),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'name' => q(լմ),
						'one' => q({0} լմ),
						'other' => q({0} լմ),
					},
					# Core Unit Identifier
					'lumen' => {
						'name' => q(լմ),
						'one' => q({0} լմ),
						'other' => q({0} լմ),
					},
					# Long Unit Identifier
					'light-lux' => {
						'name' => q(լք),
						'one' => q({0} լք),
						'other' => q({0} լք),
					},
					# Core Unit Identifier
					'lux' => {
						'name' => q(լք),
						'one' => q({0} լք),
						'other' => q({0} լք),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(կար),
						'one' => q({0} կար),
						'other' => q({0} կար),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(կար),
						'one' => q({0} կար),
						'other' => q({0} կար),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(դա),
						'one' => q({0} դա),
						'other' => q({0} դա),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(դա),
						'one' => q({0} դա),
						'other' => q({0} դա),
					},
					# Long Unit Identifier
					'mass-grain' => {
						'name' => q(գրան),
						'one' => q({0} գրան),
						'other' => q({0} գրան),
					},
					# Core Unit Identifier
					'grain' => {
						'name' => q(գրան),
						'one' => q({0} գրան),
						'other' => q({0} գրան),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(գ),
						'one' => q({0} գ),
						'other' => q({0} գ),
						'per' => q({0}/գ),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(գ),
						'one' => q({0} գ),
						'other' => q({0} գ),
						'per' => q({0}/գ),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(կգ),
						'one' => q({0} կգ),
						'other' => q({0} կգ),
						'per' => q({0}/կգ),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(կգ),
						'one' => q({0} կգ),
						'other' => q({0} կգ),
						'per' => q({0}/կգ),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'name' => q(մկգ),
						'one' => q({0} մկգ),
						'other' => q({0} մկգ),
					},
					# Core Unit Identifier
					'microgram' => {
						'name' => q(մկգ),
						'one' => q({0} մկգ),
						'other' => q({0} մկգ),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(մգ),
						'one' => q({0} մգ),
						'other' => q({0} մգ),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(մգ),
						'one' => q({0} մգ),
						'other' => q({0} մգ),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ունկ.),
						'one' => q({0} ունկ.),
						'other' => q({0} ունկ.),
						'per' => q({0}/ունկ.),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ունկ.),
						'one' => q({0} ունկ.),
						'other' => q({0} ունկ.),
						'per' => q({0}/ունկ.),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(տրոյ․ ունկ.),
						'one' => q({0} տրոյ․ ունկ.),
						'other' => q({0} տրոյ․ ունկ.),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(տրոյ․ ունկ.),
						'one' => q({0} տրոյ․ ունկ.),
						'other' => q({0} տրոյ․ ունկ.),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ֆունտ),
						'one' => q({0} ֆունտ),
						'other' => q({0} ֆունտ),
						'per' => q({0}/ֆունտ),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ֆունտ),
						'one' => q({0} ֆունտ),
						'other' => q({0} ֆունտ),
						'per' => q({0}/ֆունտ),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'name' => q(սթոուն),
						'one' => q({0} սթոուն),
						'other' => q({0} սթոուն),
					},
					# Core Unit Identifier
					'stone' => {
						'name' => q(սթոուն),
						'one' => q({0} սթոուն),
						'other' => q({0} սթոուն),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ամեր․ տ),
						'one' => q({0} ամեր․ տ),
						'other' => q({0} ամեր․ տ),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ամեր․ տ),
						'one' => q({0} ամեր․ տ),
						'other' => q({0} ամեր․ տ),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(տ),
						'one' => q({0} տ),
						'other' => q({0} տ),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(տ),
						'one' => q({0} տ),
						'other' => q({0} տ),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(ԳՎտ),
						'one' => q({0} ԳՎտ),
						'other' => q({0} ԳՎտ),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(ԳՎտ),
						'one' => q({0} ԳՎտ),
						'other' => q({0} ԳՎտ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ձ․ու․),
						'one' => q({0} ձ․ու․),
						'other' => q({0} ձ․ու․),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ձ․ու․),
						'one' => q({0} ձ․ու․),
						'other' => q({0} ձ․ու․),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(կՎտ),
						'one' => q({0} կՎտ),
						'other' => q({0} կՎտ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(կՎտ),
						'one' => q({0} կՎտ),
						'other' => q({0} կՎտ),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(ՄՎտ),
						'one' => q({0} ՄՎտ),
						'other' => q({0} ՄՎտ),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(ՄՎտ),
						'one' => q({0} ՄՎտ),
						'other' => q({0} ՄՎտ),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(մՎտ),
						'one' => q({0} մՎտ),
						'other' => q({0} մՎտ),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(մՎտ),
						'one' => q({0} մՎտ),
						'other' => q({0} մՎտ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'name' => q(Վտ),
						'one' => q({0} Վտ),
						'other' => q({0} Վտ),
					},
					# Core Unit Identifier
					'watt' => {
						'name' => q(Վտ),
						'one' => q({0} Վտ),
						'other' => q({0} Վտ),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'name' => q(մթն),
						'one' => q({0} մթն),
						'other' => q({0} մթն),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'name' => q(մթն),
						'one' => q({0} մթն),
						'other' => q({0} մթն),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'name' => q(բար),
						'one' => q({0} բար),
						'other' => q({0} բար),
					},
					# Core Unit Identifier
					'bar' => {
						'name' => q(բար),
						'one' => q({0} բար),
						'other' => q({0} բար),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'name' => q(հՊա),
						'one' => q({0} հՊա),
						'other' => q({0} հՊա),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'name' => q(հՊա),
						'one' => q({0} հՊա),
						'other' => q({0} հՊա),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(դյույմ ս.ս.),
						'one' => q({0} դյմ. ս.ս.),
						'other' => q({0} դյմ. ս.ս.),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(դյույմ ս.ս.),
						'one' => q({0} դյմ. ս.ս.),
						'other' => q({0} դյմ. ս.ս.),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(կՊա),
						'one' => q({0} կՊա),
						'other' => q({0} կՊա),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(կՊա),
						'one' => q({0} կՊա),
						'other' => q({0} կՊա),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(ՄՊա),
						'one' => q({0} ՄՊա),
						'other' => q({0} ՄՊա),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(ՄՊա),
						'one' => q({0} ՄՊա),
						'other' => q({0} ՄՊա),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(մբար),
						'one' => q({0} մբար),
						'other' => q({0} մբար),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(մբար),
						'one' => q({0} մբար),
						'other' => q({0} մբար),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(մմ ս.ս.),
						'one' => q({0} մմ ս.ս.),
						'other' => q({0} մմ ս.ս.),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(մմ ս.ս.),
						'one' => q({0} մմ ս.ս.),
						'other' => q({0} մմ ս.ս.),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'name' => q(Պա),
						'one' => q({0} Պա),
						'other' => q({0} Պա),
					},
					# Core Unit Identifier
					'pascal' => {
						'name' => q(Պա),
						'one' => q({0} Պա),
						'other' => q({0} Պա),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ֆ․/քառ․ դյմ),
						'one' => q({0} ֆ./քառ․ դյմ),
						'other' => q({0} ֆ./քառ․ դյմ),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ֆ․/քառ․ դյմ),
						'one' => q({0} ֆ./քառ․ դյմ),
						'other' => q({0} ֆ./քառ․ դյմ),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'name' => q(Բֆտ),
						'one' => q(Բ {0}),
						'other' => q(Բ {0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'name' => q(Բֆտ),
						'one' => q(Բ {0}),
						'other' => q(Բ {0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(կմ/ժ),
						'one' => q({0} կմ/ժ),
						'other' => q({0} կմ/ժ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(կմ/ժ),
						'one' => q({0} կմ/ժ),
						'other' => q({0} կմ/ժ),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(հնգ),
						'one' => q({0} հնգ),
						'other' => q({0} հնգ),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(հնգ),
						'one' => q({0} հնգ),
						'other' => q({0} հնգ),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(մ/վ),
						'one' => q({0} մ/վ),
						'other' => q({0} մ/վ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(մ/վ),
						'one' => q({0} մ/վ),
						'other' => q({0} մ/վ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(մղ/ժ),
						'one' => q({0} մղ/ժ),
						'other' => q({0} մղ/ժ),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(մղ/ժ),
						'one' => q({0} մղ/ժ),
						'other' => q({0} մղ/ժ),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'one' => q({0} °C),
						'other' => q({0} °C),
					},
					# Core Unit Identifier
					'celsius' => {
						'one' => q({0} °C),
						'other' => q({0} °C),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'name' => q(Կ),
						'one' => q({0} Կ),
						'other' => q({0} Կ),
					},
					# Core Unit Identifier
					'kelvin' => {
						'name' => q(Կ),
						'one' => q({0} Կ),
						'other' => q({0} Կ),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(Ն·մ),
						'one' => q({0} Ն·մ),
						'other' => q({0} Ն·մ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(Ն·մ),
						'one' => q({0} Ն·մ),
						'other' => q({0} Ն·մ),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(ֆնտ-ֆտ),
						'one' => q({0} ֆնտ-ֆտ),
						'other' => q({0} ֆնտ-ֆտ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(ֆնտ-ֆտ),
						'one' => q({0} ֆնտ-ֆտ),
						'other' => q({0} ֆնտ-ֆտ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ակր ֆտ),
						'one' => q({0} ակր ֆտ),
						'other' => q({0} ակր ֆտ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ակր ֆտ),
						'one' => q({0} ակր ֆտ),
						'other' => q({0} ակր ֆտ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(տակառ),
						'one' => q({0} տկռ),
						'other' => q({0} տկռ),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(տակառ),
						'one' => q({0} տկռ),
						'other' => q({0} տկռ),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(սլ),
						'one' => q({0} սլ),
						'other' => q({0} սլ),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(սլ),
						'one' => q({0} սլ),
						'other' => q({0} սլ),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(սմ³),
						'one' => q({0} սմ³),
						'other' => q({0} սմ³),
						'per' => q({0}/սմ³),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(սմ³),
						'one' => q({0} սմ³),
						'other' => q({0} սմ³),
						'per' => q({0}/սմ³),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ֆտ³),
						'one' => q({0} ֆտ³),
						'other' => q({0} ֆտ³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ֆտ³),
						'one' => q({0} ֆտ³),
						'other' => q({0} ֆտ³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(մատ³),
						'one' => q({0} մատ³),
						'other' => q({0} մատ³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(մատ³),
						'one' => q({0} մատ³),
						'other' => q({0} մատ³),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(կմ³),
						'one' => q({0} կմ³),
						'other' => q({0} կմ³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(կմ³),
						'one' => q({0} կմ³),
						'other' => q({0} կմ³),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(մ³),
						'one' => q({0} մ³),
						'other' => q({0} մ³),
						'per' => q({0}/մ³),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(մ³),
						'one' => q({0} մ³),
						'other' => q({0} մ³),
						'per' => q({0}/մ³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(մղ³),
						'one' => q({0} մղ³),
						'other' => q({0} մղ³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(մղ³),
						'one' => q({0} մղ³),
						'other' => q({0} մղ³),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(յրդ³),
						'one' => q({0} յրդ³),
						'other' => q({0} յրդ³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(յրդ³),
						'one' => q({0} յրդ³),
						'other' => q({0} յրդ³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'name' => q(բաժակներ),
						'one' => q({0} բաժ․),
						'other' => q({0} բաժ․),
					},
					# Core Unit Identifier
					'cup' => {
						'name' => q(բաժակներ),
						'one' => q({0} բաժ․),
						'other' => q({0} բաժ․),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(մ․ բաժ․),
						'one' => q({0} մ․ բաժ․),
						'other' => q({0} մ․ բաժ․),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(մ․ բաժ․),
						'one' => q({0} մ․ բաժ․),
						'other' => q({0} մ․ բաժ․),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(դլ),
						'one' => q({0} դլ),
						'other' => q({0} դլ),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(դլ),
						'one' => q({0} դլ),
						'other' => q({0} դլ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(ագ․),
						'one' => q({0} ագ․),
						'other' => q({0} ագ․),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(ագ․),
						'one' => q({0} ագ․),
						'other' => q({0} ագ․),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(անգլ․ ագ․),
						'one' => q({0} անգլ․ ագ․),
						'other' => q({0} անգլ․ ագ․),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(անգլ․ ագ․),
						'one' => q({0} անգլ․ ագ․),
						'other' => q({0} անգլ․ ագ․),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(հեղուկ դրամ),
						'one' => q({0} հեղուկ դրամ),
						'other' => q({0} հեղուկ դրամ),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(հեղուկ դրամ),
						'one' => q({0} հեղուկ դրամ),
						'other' => q({0} հեղուկ դրամ),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(կաթիլ),
						'one' => q({0} կաթիլ),
						'other' => q({0} կաթիլ),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(կաթիլ),
						'one' => q({0} կաթիլ),
						'other' => q({0} կաթիլ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(հղ․ ունկ․),
						'one' => q({0} հղ. ունկ․),
						'other' => q({0} հղ. ունկ․),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(հղ․ ունկ․),
						'one' => q({0} հղ. ունկ․),
						'other' => q({0} հղ. ունկ․),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ա․ հ․ ու․),
						'one' => q({0} ա․ հ․ ու․),
						'other' => q({0} ա․ հ․ ու․),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ա․ հ․ ու․),
						'one' => q({0} ա․ հ․ ու․),
						'other' => q({0} ա․ հ․ ու․),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(գալ),
						'one' => q({0} գալ),
						'other' => q({0} գալ),
						'per' => q({0}/գալ),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(գալ),
						'one' => q({0} գալ),
						'other' => q({0} գալ),
						'per' => q({0}/գալ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(անգլ․ գալ),
						'one' => q({0} անգլ․ գալ),
						'other' => q({0} անգլ․ գալ),
						'per' => q({0}/անգլ․ գալ),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(անգլ․ գալ),
						'one' => q({0} անգլ․ գալ),
						'other' => q({0} անգլ․ գալ),
						'per' => q({0}/անգլ․ գալ),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(հլ),
						'one' => q({0} հլ),
						'other' => q({0} հլ),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(հլ),
						'one' => q({0} հլ),
						'other' => q({0} հլ),
					},
					# Long Unit Identifier
					'volume-jigger' => {
						'name' => q(ջիգեր),
						'one' => q({0} ջիգեր),
						'other' => q({0} ջիգեր),
					},
					# Core Unit Identifier
					'jigger' => {
						'name' => q(ջիգեր),
						'one' => q({0} ջիգեր),
						'other' => q({0} ջիգեր),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(լ),
						'one' => q({0} լ),
						'other' => q({0} լ),
						'per' => q({0}/լ),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(լ),
						'one' => q({0} լ),
						'other' => q({0} լ),
						'per' => q({0}/լ),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(Մլ),
						'one' => q({0} Մլ),
						'other' => q({0} Մլ),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(Մլ),
						'one' => q({0} Մլ),
						'other' => q({0} Մլ),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(մլ),
						'one' => q({0} մլ),
						'other' => q({0} մլ),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(մլ),
						'one' => q({0} մլ),
						'other' => q({0} մլ),
					},
					# Long Unit Identifier
					'volume-pinch' => {
						'name' => q(պտղունց),
						'one' => q({0} պտղունց),
						'other' => q({0} պտղունց),
					},
					# Core Unit Identifier
					'pinch' => {
						'name' => q(պտղունց),
						'one' => q({0} պտղունց),
						'other' => q({0} պտղունց),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'name' => q(փինթեր),
						'one' => q({0} փինթ),
						'other' => q({0} փինթ),
					},
					# Core Unit Identifier
					'pint' => {
						'name' => q(փինթեր),
						'one' => q({0} փինթ),
						'other' => q({0} փինթ),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(մետր․ փինթ),
						'one' => q({0} մետր․ փինթ),
						'other' => q({0} մետր․ փինթ),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(մետր․ փինթ),
						'one' => q({0} մետր․ փինթ),
						'other' => q({0} մետր․ փինթ),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(քվարտ),
						'one' => q({0} քվարտ),
						'other' => q({0} քվարտ),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(քվարտ),
						'one' => q({0} քվարտ),
						'other' => q({0} քվարտ),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'name' => q(անգլիական քվարտ),
						'one' => q({0} անգլիական քվարտ),
						'other' => q({0} անգլիական քվարտ),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'name' => q(անգլիական քվարտ),
						'one' => q({0} անգլիական քվարտ),
						'other' => q({0} անգլիական քվարտ),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(ճգ.),
						'one' => q({0} ճգ.),
						'other' => q({0} ճգ.),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(ճգ.),
						'one' => q({0} ճգ.),
						'other' => q({0} ճգ.),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(թգ.),
						'one' => q({0} թգ.),
						'other' => q({0} թգ.),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(թգ.),
						'one' => q({0} թգ.),
						'other' => q({0} թգ.),
					},
				},
			} }
);

has 'yesstr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:այո|ա|yes|y)$' }
);

has 'nostr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ոչ|ո|no|n)$' }
);

has 'listPatterns' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
				end => q({0} և {1}),
				2 => q({0} և {1}),
		} }
);

has traditional_numbering_system => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> 'armn',
);

has 'number_symbols' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'latn' => {
			'decimal' => q(,),
			'group' => q( ),
			'nan' => q(ՈչԹ),
		},
	} }
);

has 'number_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		decimalFormat => {
			'long' => {
				'1000' => {
					'one' => '0 հազար',
					'other' => '0 հազար',
				},
				'10000' => {
					'one' => '00 հազար',
					'other' => '00 հազար',
				},
				'100000' => {
					'one' => '000 հազար',
					'other' => '000 հազար',
				},
				'1000000' => {
					'one' => '0 միլիոն',
					'other' => '0 միլիոն',
				},
				'10000000' => {
					'one' => '00 միլիոն',
					'other' => '00 միլիոն',
				},
				'100000000' => {
					'one' => '000 միլիոն',
					'other' => '000 միլիոն',
				},
				'1000000000' => {
					'one' => '0 միլիարդ',
					'other' => '0 միլիարդ',
				},
				'10000000000' => {
					'one' => '00 միլիարդ',
					'other' => '00 միլիարդ',
				},
				'100000000000' => {
					'one' => '000 միլիարդ',
					'other' => '000 միլիարդ',
				},
				'1000000000000' => {
					'one' => '0 տրիլիոն',
					'other' => '0 տրիլիոն',
				},
				'10000000000000' => {
					'one' => '00 տրիլիոն',
					'other' => '00 տրիլիոն',
				},
				'100000000000000' => {
					'one' => '000 տրիլիոն',
					'other' => '000 տրիլիոն',
				},
			},
			'short' => {
				'1000' => {
					'one' => '0 հզր',
					'other' => '0 հզր',
				},
				'10000' => {
					'one' => '00 հզր',
					'other' => '00 հզր',
				},
				'100000' => {
					'one' => '000 հզր',
					'other' => '000 հզր',
				},
				'1000000' => {
					'one' => '0 մլն',
					'other' => '0 մլն',
				},
				'10000000' => {
					'one' => '00 մլն',
					'other' => '00 մլն',
				},
				'100000000' => {
					'one' => '000 մլն',
					'other' => '000 մլն',
				},
				'1000000000' => {
					'one' => '0 մլրդ',
					'other' => '0 մլրդ',
				},
				'10000000000' => {
					'one' => '00 մլրդ',
					'other' => '00 մլրդ',
				},
				'100000000000' => {
					'one' => '000 մլրդ',
					'other' => '000 մլրդ',
				},
				'1000000000000' => {
					'one' => '0 տրլն',
					'other' => '0 տրլն',
				},
				'10000000000000' => {
					'one' => '00 տրլն',
					'other' => '00 տրլն',
				},
				'100000000000000' => {
					'one' => '000 տրլն',
					'other' => '000 տրլն',
				},
			},
		},
} },
);

has 'number_currency_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'latn' => {
			'pattern' => {
				'default' => {
					'standard' => {
						'positive' => '#,##0.00 ¤',
					},
				},
			},
		},
} },
);

has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'AED' => {
			display_name => {
				'currency' => q(Արաբական Միացյալ Էմիրությունների դիրհամ),
				'one' => q(ԱՄԷ դիրհամ),
				'other' => q(ԱՄԷ դիրհամ),
			},
		},
		'AFN' => {
			display_name => {
				'currency' => q(աֆղանական աֆղանի),
			},
		},
		'ALL' => {
			display_name => {
				'currency' => q(ալբանական լեկ),
			},
		},
		'AMD' => {
			symbol => '֏',
			display_name => {
				'currency' => q(հայկական դրամ),
			},
		},
		'ANG' => {
			display_name => {
				'currency' => q(նիդեռլանդական անտիլյան գուլդեն),
			},
		},
		'AOA' => {
			display_name => {
				'currency' => q(անգոլական կվանզա),
			},
		},
		'ARS' => {
			display_name => {
				'currency' => q(արգենտինական պեսո),
			},
		},
		'AUD' => {
			display_name => {
				'currency' => q(ավստրալիական դոլար),
			},
		},
		'AWG' => {
			display_name => {
				'currency' => q(արուբական ֆլորին),
			},
		},
		'AZN' => {
			display_name => {
				'currency' => q(ադրբեջանական մանաթ),
			},
		},
		'BAM' => {
			display_name => {
				'currency' => q(Բոսնիա և Հերցեգովինայի փոխարկվող մարկ),
			},
		},
		'BBD' => {
			display_name => {
				'currency' => q(բարբադոսյան դոլար),
			},
		},
		'BDT' => {
			display_name => {
				'currency' => q(Բանգլադեշի տակա),
			},
		},
		'BGN' => {
			display_name => {
				'currency' => q(բուլղարական լև),
			},
		},
		'BHD' => {
			display_name => {
				'currency' => q(Բահրեյնի դինար),
			},
		},
		'BIF' => {
			display_name => {
				'currency' => q(բուրունդիական ֆրանկ),
			},
		},
		'BMD' => {
			display_name => {
				'currency' => q(բերմուդյան դոլար),
			},
		},
		'BND' => {
			display_name => {
				'currency' => q(Բրունեյի դոլար),
			},
		},
		'BOB' => {
			display_name => {
				'currency' => q(բոլիվիական բոլիվիանո),
			},
		},
		'BRL' => {
			display_name => {
				'currency' => q(բրազիլական ռեալ),
			},
		},
		'BSD' => {
			display_name => {
				'currency' => q(բահամյան դոլար),
			},
		},
		'BTN' => {
			display_name => {
				'currency' => q(բութանական նգուլտրում),
			},
		},
		'BWP' => {
			display_name => {
				'currency' => q(բոթսվանական պուլա),
			},
		},
		'BYN' => {
			symbol => 'р.',
			display_name => {
				'currency' => q(բելառուսական ռուբլի),
			},
		},
		'BYR' => {
			display_name => {
				'currency' => q(Բելառուսական ռուբլի \(2000–2016\)),
				'one' => q(բելառուսական ռուբլի \(2000–2016\)),
				'other' => q(բելառուսական ռուբլի \(2000–2016\)),
			},
		},
		'BZD' => {
			display_name => {
				'currency' => q(Բելիզի դոլար),
			},
		},
		'CAD' => {
			display_name => {
				'currency' => q(կանադական դոլար),
			},
		},
		'CDF' => {
			display_name => {
				'currency' => q(Կոնգոյի ֆրանկ),
			},
		},
		'CHF' => {
			display_name => {
				'currency' => q(շվեյցարական ֆրանկ),
			},
		},
		'CLP' => {
			display_name => {
				'currency' => q(չիլիական պեսո),
			},
		},
		'CNH' => {
			display_name => {
				'currency' => q(չինական օֆշորային յուան),
			},
		},
		'CNY' => {
			display_name => {
				'currency' => q(չինական յուան),
			},
		},
		'COP' => {
			display_name => {
				'currency' => q(կոլումբիական պեսո),
			},
		},
		'CRC' => {
			display_name => {
				'currency' => q(Կոստա Ռիկայի կոլոն),
			},
		},
		'CUC' => {
			display_name => {
				'currency' => q(կուբայական փոխարկվող պեսո),
			},
		},
		'CUP' => {
			display_name => {
				'currency' => q(կուբայական պեսո),
			},
		},
		'CVE' => {
			display_name => {
				'currency' => q(Կաբո Վերդեի էսկուդո),
			},
		},
		'CZK' => {
			display_name => {
				'currency' => q(չեխական կրոն),
			},
		},
		'DJF' => {
			display_name => {
				'currency' => q(Ջիբութիի ֆրանկ),
			},
		},
		'DKK' => {
			display_name => {
				'currency' => q(դանիական կրոն),
			},
		},
		'DOP' => {
			display_name => {
				'currency' => q(դոմինիկյան պեսո),
			},
		},
		'DZD' => {
			display_name => {
				'currency' => q(ալժիրական դինար),
			},
		},
		'EGP' => {
			display_name => {
				'currency' => q(եգիպտական ֆունտ),
			},
		},
		'ERN' => {
			display_name => {
				'currency' => q(էրիթրեական նակվա),
				'one' => q(էրիթրեական նակֆա),
				'other' => q(էրիթրեական նակֆա),
			},
		},
		'ETB' => {
			display_name => {
				'currency' => q(եթովպիական բիր),
			},
		},
		'EUR' => {
			display_name => {
				'currency' => q(եվրո),
			},
		},
		'FJD' => {
			display_name => {
				'currency' => q(ֆիջիական դոլար),
			},
		},
		'FKP' => {
			display_name => {
				'currency' => q(Ֆոլքլենդյան կղզիների ֆունտ),
			},
		},
		'GBP' => {
			display_name => {
				'currency' => q(բրիտանական ֆունտ ստերլինգ),
			},
		},
		'GEL' => {
			display_name => {
				'currency' => q(վրացական լարի),
			},
		},
		'GHS' => {
			display_name => {
				'currency' => q(գայանական սեդի),
				'one' => q(գանայական սեդի),
				'other' => q(գանայական սեդի),
			},
		},
		'GIP' => {
			display_name => {
				'currency' => q(Ջիբրալթարի ֆունտ),
			},
		},
		'GMD' => {
			display_name => {
				'currency' => q(գամբիական դալասի),
			},
		},
		'GNF' => {
			display_name => {
				'currency' => q(գվինեական ֆրանկ),
			},
		},
		'GTQ' => {
			display_name => {
				'currency' => q(գվատեմալական կետսալ),
			},
		},
		'GYD' => {
			display_name => {
				'currency' => q(գայանական դոլար),
			},
		},
		'HKD' => {
			display_name => {
				'currency' => q(Հոնկոնգի դոլար),
			},
		},
		'HNL' => {
			display_name => {
				'currency' => q(հոնդուրասական լեմպիրա),
			},
		},
		'HRK' => {
			display_name => {
				'currency' => q(խորվաթական կունա),
			},
		},
		'HTG' => {
			display_name => {
				'currency' => q(հայիթյան գուրդ),
			},
		},
		'HUF' => {
			display_name => {
				'currency' => q(հունգարական ֆորինտ),
			},
		},
		'IDR' => {
			display_name => {
				'currency' => q(ինդոնեզիական ռուփի),
			},
		},
		'ILS' => {
			display_name => {
				'currency' => q(Իսրայելի նոր շեկել),
			},
		},
		'INR' => {
			display_name => {
				'currency' => q(հնդկական ռուփի),
			},
		},
		'IQD' => {
			display_name => {
				'currency' => q(իրաքյան դինար),
			},
		},
		'IRR' => {
			display_name => {
				'currency' => q(իրանական ռիալ),
			},
		},
		'ISK' => {
			display_name => {
				'currency' => q(իսլանդական կրոն),
			},
		},
		'JMD' => {
			display_name => {
				'currency' => q(Ճամայկայի դոլար),
			},
		},
		'JOD' => {
			display_name => {
				'currency' => q(հորդանանյան դինար),
			},
		},
		'JPY' => {
			display_name => {
				'currency' => q(ճապոնական իեն),
			},
		},
		'KES' => {
			display_name => {
				'currency' => q(քենիական շիլինգ),
			},
		},
		'KGS' => {
			display_name => {
				'currency' => q(ղրղզական սոմ),
			},
		},
		'KHR' => {
			display_name => {
				'currency' => q(կամբոջական ռիել),
			},
		},
		'KMF' => {
			display_name => {
				'currency' => q(կոմորյան ֆրանկ),
			},
		},
		'KPW' => {
			display_name => {
				'currency' => q(հյուսիսկորեական վոն),
			},
		},
		'KRW' => {
			display_name => {
				'currency' => q(հարավկորեական վոն),
			},
		},
		'KWD' => {
			display_name => {
				'currency' => q(Քուվեյթի դինար),
			},
		},
		'KYD' => {
			display_name => {
				'currency' => q(Կայմանյան կղզիների դոլար),
			},
		},
		'KZT' => {
			display_name => {
				'currency' => q(ղազախական տենգե),
			},
		},
		'LAK' => {
			display_name => {
				'currency' => q(լաոսական կիպ),
			},
		},
		'LBP' => {
			display_name => {
				'currency' => q(լիբանանյան ֆունտ),
			},
		},
		'LKR' => {
			display_name => {
				'currency' => q(Շրի Լանկայի ռուփի),
			},
		},
		'LRD' => {
			display_name => {
				'currency' => q(լիբերիական դոլար),
			},
		},
		'LSL' => {
			display_name => {
				'currency' => q(լեսոթոյական լոտի),
			},
		},
		'LTL' => {
			display_name => {
				'currency' => q(Լիտվական լիտ),
			},
		},
		'LVL' => {
			display_name => {
				'currency' => q(Լատվիական լատ),
			},
		},
		'LYD' => {
			display_name => {
				'currency' => q(լիբիական դինար),
			},
		},
		'MAD' => {
			display_name => {
				'currency' => q(Մարոկկոյի դիրհամ),
			},
		},
		'MDL' => {
			display_name => {
				'currency' => q(մոլդովական լեյ),
			},
		},
		'MGA' => {
			display_name => {
				'currency' => q(Մադագասկարի արիարի),
			},
		},
		'MKD' => {
			display_name => {
				'currency' => q(մակեդոնական դենար),
			},
		},
		'MMK' => {
			display_name => {
				'currency' => q(Մյանմայի կյատ),
			},
		},
		'MNT' => {
			display_name => {
				'currency' => q(մոնղոլական տուգրիկ),
			},
		},
		'MOP' => {
			display_name => {
				'currency' => q(Մակաոյի պատակա),
			},
		},
		'MRO' => {
			display_name => {
				'currency' => q(մավրիտանական ուգիյա \(1973–2017\)),
			},
		},
		'MRU' => {
			display_name => {
				'currency' => q(մավրիտանական ուգիյա),
			},
		},
		'MUR' => {
			display_name => {
				'currency' => q(մավրիկյան ռուփի),
			},
		},
		'MVR' => {
			display_name => {
				'currency' => q(մալդիվյան ռուֆիյա),
			},
		},
		'MWK' => {
			display_name => {
				'currency' => q(մալավիական կվաչա),
			},
		},
		'MXN' => {
			display_name => {
				'currency' => q(մեքսիկական պեսո),
			},
		},
		'MYR' => {
			display_name => {
				'currency' => q(մալայզիական ռինգիտ),
			},
		},
		'MZN' => {
			display_name => {
				'currency' => q(մոզամբիկյան մետիկալ),
			},
		},
		'NAD' => {
			display_name => {
				'currency' => q(նամիբիական դոլար),
			},
		},
		'NGN' => {
			display_name => {
				'currency' => q(նիգերիական նայրա),
			},
		},
		'NIO' => {
			display_name => {
				'currency' => q(նիկարագուական կորդոբա),
			},
		},
		'NOK' => {
			display_name => {
				'currency' => q(նորվեգական կրոն),
			},
		},
		'NPR' => {
			display_name => {
				'currency' => q(Նեպալի ռուփի),
			},
		},
		'NZD' => {
			display_name => {
				'currency' => q(նորզելանդական դոլար),
			},
		},
		'OMR' => {
			display_name => {
				'currency' => q(Օմանի ռիալ),
			},
		},
		'PAB' => {
			display_name => {
				'currency' => q(պանամական բալբոա),
			},
		},
		'PEN' => {
			display_name => {
				'currency' => q(Պերուի սոլ),
			},
		},
		'PGK' => {
			display_name => {
				'currency' => q(Պապուա Նոր Գվինեայի կինա),
			},
		},
		'PHP' => {
			symbol => 'PHP',
			display_name => {
				'currency' => q(ֆիլիպինյան պեսո),
			},
		},
		'PKR' => {
			display_name => {
				'currency' => q(պակիստանյան ռուփի),
			},
		},
		'PLN' => {
			display_name => {
				'currency' => q(լեհական զլոտի),
			},
		},
		'PYG' => {
			display_name => {
				'currency' => q(պարագվայական գուարանի),
			},
		},
		'QAR' => {
			display_name => {
				'currency' => q(Կատարի ռիալ),
			},
		},
		'RON' => {
			display_name => {
				'currency' => q(ռումինական լեյ),
			},
		},
		'RSD' => {
			display_name => {
				'currency' => q(սերբական դինար),
			},
		},
		'RUB' => {
			display_name => {
				'currency' => q(ռուսական ռուբլի),
			},
		},
		'RWF' => {
			display_name => {
				'currency' => q(ռուանդական ֆրանկ),
			},
		},
		'SAR' => {
			display_name => {
				'currency' => q(Սաուդյան Արաբիայի ռիալ),
			},
		},
		'SBD' => {
			display_name => {
				'currency' => q(Սողոմոնյան կղզիների դոլար),
			},
		},
		'SCR' => {
			display_name => {
				'currency' => q(սեյշելյան ռուփի),
			},
		},
		'SDG' => {
			display_name => {
				'currency' => q(սուդանական ֆունտ),
			},
		},
		'SEK' => {
			display_name => {
				'currency' => q(շվեդական կրոն),
			},
		},
		'SGD' => {
			display_name => {
				'currency' => q(Սինգապուրի դոլար),
			},
		},
		'SHP' => {
			display_name => {
				'currency' => q(Սուրբ Հեղինեի ֆունտ),
			},
		},
		'SLE' => {
			display_name => {
				'currency' => q(Սիեռա Լեոնեի լեոնե),
			},
		},
		'SLL' => {
			display_name => {
				'currency' => q(Սիեռա Լեոնեի լեոնե \(1964—2022\)),
			},
		},
		'SOS' => {
			display_name => {
				'currency' => q(սոմալիական շիլինգ),
			},
		},
		'SRD' => {
			display_name => {
				'currency' => q(սուրինամական դոլար),
			},
		},
		'SSP' => {
			display_name => {
				'currency' => q(հարավսուդանական ֆունտ),
			},
		},
		'STD' => {
			display_name => {
				'currency' => q(Սան Տոմե և Փրինսիպիի դոբրա \(1977–2017\)),
			},
		},
		'STN' => {
			display_name => {
				'currency' => q(Սան Տոմե և Փրինսիպիի դոբրա),
			},
		},
		'SYP' => {
			display_name => {
				'currency' => q(սիրիական ֆունտ),
			},
		},
		'SZL' => {
			display_name => {
				'currency' => q(սվազիլենդական լիլանգենի),
			},
		},
		'THB' => {
			symbol => '฿',
			display_name => {
				'currency' => q(թայլանդական բատ),
			},
		},
		'TJS' => {
			display_name => {
				'currency' => q(տաջիկական սոմոնի),
			},
		},
		'TMT' => {
			display_name => {
				'currency' => q(թուրքմենական մանաթ),
			},
		},
		'TND' => {
			display_name => {
				'currency' => q(թունիսյան դինար),
			},
		},
		'TOP' => {
			display_name => {
				'currency' => q(Տոնգայի պաանգա),
			},
		},
		'TRY' => {
			display_name => {
				'currency' => q(թուրքական լիրա),
			},
		},
		'TTD' => {
			display_name => {
				'currency' => q(Տրինիդադ և Տոբագոյի դոլար),
			},
		},
		'TWD' => {
			symbol => 'NT$',
			display_name => {
				'currency' => q(թայվանական նոր դոլար),
			},
		},
		'TZS' => {
			display_name => {
				'currency' => q(տանզանիական շիլինգ),
			},
		},
		'UAH' => {
			display_name => {
				'currency' => q(ուկրաինական գրիվնա),
			},
		},
		'UGX' => {
			display_name => {
				'currency' => q(ուգանդական շիլինգ),
			},
		},
		'USD' => {
			symbol => '$',
			display_name => {
				'currency' => q(ԱՄՆ դոլար),
			},
		},
		'UYU' => {
			display_name => {
				'currency' => q(ուրուգվայական պեսո),
			},
		},
		'UZS' => {
			display_name => {
				'currency' => q(ուզբեկական սոմ),
			},
		},
		'VEF' => {
			display_name => {
				'currency' => q(վենեսուելական բոլիվար \(2008–2018\)),
			},
		},
		'VES' => {
			display_name => {
				'currency' => q(վենեսուելական բոլիվար),
			},
		},
		'VND' => {
			display_name => {
				'currency' => q(վիետնամական դոնգ),
			},
		},
		'VUV' => {
			display_name => {
				'currency' => q(Վանուատուի վատու),
			},
		},
		'WST' => {
			display_name => {
				'currency' => q(սամոական տալա),
			},
		},
		'XAF' => {
			display_name => {
				'currency' => q(Կենտրոնական Աֆրիկայի ԿՖԱ ֆրանկ),
			},
		},
		'XCD' => {
			display_name => {
				'currency' => q(արևելակարիբյան դոլար),
			},
		},
		'XOF' => {
			display_name => {
				'currency' => q(Արևմտյան Աֆրիկայի ԿՖԱ ֆրանկ),
			},
		},
		'XPF' => {
			display_name => {
				'currency' => q(ԿՊՖ ֆրանկ),
			},
		},
		'XXX' => {
			display_name => {
				'currency' => q(անհայտ արժույթ),
				'one' => q(\(անհայտ արժույթ\)),
				'other' => q(\(անհայտ արժույթ\)),
			},
		},
		'YER' => {
			display_name => {
				'currency' => q(եմենական ռիալ),
			},
		},
		'ZAR' => {
			display_name => {
				'currency' => q(հարավաֆրիկյան ռանդ),
			},
		},
		'ZMK' => {
			display_name => {
				'currency' => q(Զամբիական կվաչա \(1968–2012\)),
			},
		},
		'ZMW' => {
			display_name => {
				'currency' => q(զամբիական կվաչա),
			},
		},
	} },
);


has 'calendar_months' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'հնվ',
							'փտվ',
							'մրտ',
							'ապր',
							'մյս',
							'հնս',
							'հլս',
							'օգս',
							'սեպ',
							'հոկ',
							'նոյ',
							'դեկ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'հունվարի',
							'փետրվարի',
							'մարտի',
							'ապրիլի',
							'մայիսի',
							'հունիսի',
							'հուլիսի',
							'օգոստոսի',
							'սեպտեմբերի',
							'հոկտեմբերի',
							'նոյեմբերի',
							'դեկտեմբերի'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					narrow => {
						nonleap => [
							'Հ',
							'Փ',
							'Մ',
							'Ա',
							'Մ',
							'Հ',
							'Հ',
							'Օ',
							'Ս',
							'Հ',
							'Ն',
							'Դ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'հունվար',
							'փետրվար',
							'մարտ',
							'ապրիլ',
							'մայիս',
							'հունիս',
							'հուլիս',
							'օգոստոս',
							'սեպտեմբեր',
							'հոկտեմբեր',
							'նոյեմբեր',
							'դեկտեմբեր'
						],
						leap => [
							
						],
					},
				},
			},
	} },
);

has 'calendar_days' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						mon => 'երկ',
						tue => 'երք',
						wed => 'չրք',
						thu => 'հնգ',
						fri => 'ուր',
						sat => 'շբթ',
						sun => 'կիր'
					},
					short => {
						mon => 'եկ',
						tue => 'եք',
						wed => 'չք',
						thu => 'հգ',
						fri => 'ու',
						sat => 'շբ',
						sun => 'կր'
					},
					wide => {
						mon => 'երկուշաբթի',
						tue => 'երեքշաբթի',
						wed => 'չորեքշաբթի',
						thu => 'հինգշաբթի',
						fri => 'ուրբաթ',
						sat => 'շաբաթ',
						sun => 'կիրակի'
					},
				},
				'stand-alone' => {
					narrow => {
						mon => 'Ե',
						tue => 'Ե',
						wed => 'Չ',
						thu => 'Հ',
						fri => 'Ո',
						sat => 'Շ',
						sun => 'Կ'
					},
				},
			},
	} },
);

has 'calendar_quarters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {0 => '1-ին եռմս.',
						1 => '2-րդ եռմս.',
						2 => '3-րդ եռմս.',
						3 => '4-րդ եռմս.'
					},
					wide => {0 => '1-ին եռամսյակ',
						1 => '2-րդ եռամսյակ',
						2 => '3-րդ եռամսյակ',
						3 => '4-րդ եռամսյակ'
					},
				},
			},
	} },
);

has 'day_period_data' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub { sub {
		# Time in hhmm format
		my ($self, $type, $time, $day_period_type) = @_;
		$day_period_type //= 'default';
		SWITCH:
		for ($type) {
			if ($_ eq 'generic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2400;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 0
						&& $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2400;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 0
						&& $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'gregorian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2400;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 0
						&& $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2400;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 0
						&& $time < 600;
				}
				last SWITCH;
				}
		}
	} },
);

around day_period_data => sub {
    my ($orig, $self) = @_;
    return $self->$orig;
};

has 'day_periods' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'format' => {
				'abbreviated' => {
					'afternoon1' => q{ցերեկը},
					'evening1' => q{երեկոյան},
					'midnight' => q{կեսգիշեր},
					'morning1' => q{առավոտյան},
					'night1' => q{գիշերը},
					'noon' => q{կեսօր},
				},
				'narrow' => {
					'afternoon1' => q{ցրկ},
					'am' => q{ա},
					'evening1' => q{երկ},
					'midnight' => q{կգ․},
					'morning1' => q{առվ},
					'night1' => q{գշր},
					'noon' => q{կօ․},
					'pm' => q{հ},
				},
				'wide' => {
					'afternoon1' => q{ցերեկվա},
					'evening1' => q{երեկոյան},
					'midnight' => q{կեսգիշերին},
					'morning1' => q{առավոտյան},
					'night1' => q{գիշերվա},
					'noon' => q{կեսօրին},
				},
			},
			'stand-alone' => {
				'abbreviated' => {
					'afternoon1' => q{ցերեկ},
					'evening1' => q{երեկո},
					'morning1' => q{առավոտ},
					'night1' => q{գիշեր},
				},
			},
		},
	} },
);

has 'eras' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			abbreviated => {
				'0' => 'մ.թ.ա.',
				'1' => 'մ.թ.'
			},
			wide => {
				'0' => 'Քրիստոսից առաջ',
				'1' => 'Քրիստոսից հետո'
			},
		},
	} },
);

has 'date_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{d MMMM, y թ. G, EEEE},
			'long' => q{dd MMMM, y թ. G},
			'medium' => q{dd MMM, y թ. G},
			'short' => q{dd.MM.y GGGGG},
		},
		'gregorian' => {
			'full' => q{y թ. MMMM d, EEEE},
			'long' => q{dd MMMM, y թ.},
			'medium' => q{dd MMM, y թ.},
			'short' => q{dd.MM.yy},
		},
	} },
);

has 'time_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			'full' => q{HH:mm:ss zzzz},
			'long' => q{HH:mm:ss z},
			'medium' => q{HH:mm:ss},
			'short' => q{HH:mm},
		},
	} },
);

has 'datetime_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{{1}, {0}},
			'long' => q{{1}, {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
		'gregorian' => {
			'full' => q{{1}, {0}},
			'long' => q{{1}, {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
	} },
);

has 'datetime_formats_available_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Bh => q{B h-ին},
			Bhm => q{B h:mm-ին},
			Bhms => q{B h:mm:ss},
			EBhm => q{E B h:mm-ին},
			EBhms => q{E B h:mm:ss},
			Ed => q{d, ccc},
			Gy => q{G y թ․},
			GyMMM => q{G y թ․ MMM},
			GyMMMEd => q{G y թ․ MMM d, E},
			GyMMMd => q{G y թ․ MMM d},
			GyMd => q{dd.MM.y GGGGG},
			H => q{H},
			Hm => q{H:mm},
			Hms => q{H:mm:ss},
			MEd => q{dd.MM, E},
			MMMEd => q{d MMM, E},
			MMMd => q{d MMM},
			Md => q{dd.MM},
			y => q{y, G},
			yyyy => q{y, G},
			yyyyM => q{G y թ. MM},
			yyyyMEd => q{d.MM.y թ., G, E},
			yyyyMMM => q{G y թ. LLL},
			yyyyMMMEd => q{d MMM, y թ. G, E},
			yyyyMMMd => q{d MMM, y թ., G},
			yyyyMd => q{d.M.y թ., G},
			yyyyQQQ => q{G y թ, QQQ},
			yyyyQQQQ => q{G y թ, QQQQ},
		},
		'gregorian' => {
			Bh => q{B h-ին},
			Bhm => q{B h:mm-ին},
			Bhms => q{B h:mm:ss},
			EBhm => q{E B h:mm-ին},
			EBhms => q{E B h:mm:ss},
			EHm => q{E, HH:mm},
			EHms => q{E, HH:mm:ss},
			Ed => q{d, ccc},
			Ehm => q{E, h:mm a},
			Ehms => q{E, h:mm:ss a},
			Gy => q{G y թ.},
			GyMMM => q{G y թ. MMM},
			GyMMMEd => q{G y թ. MMM d, E},
			GyMMMd => q{G y թ․ MMM d},
			GyMd => q{dd.MM.y GGGGG},
			H => q{H},
			Hm => q{H:mm},
			Hms => q{H:mm:ss},
			MEd => q{dd.MM, E},
			MMMEd => q{d MMM, E},
			MMMMW => q{MMMM W-րդ շաբաթ},
			MMMd => q{d MMM},
			Md => q{dd.MM},
			yM => q{MM.y},
			yMEd => q{d.MM.y թ., E},
			yMMM => q{y թ. LLL},
			yMMMEd => q{y թ. MMM d, E},
			yMMMM => q{y թ․ LLLL},
			yMMMd => q{d MMM, y թ.},
			yMd => q{dd.MM.y},
			yQQQ => q{y թ. QQQ},
			yQQQQ => q{y թ. QQQQ},
			yw => q{Y թ․ w-րդ շաբաթ},
		},
	} },
);

has 'datetime_formats_append_item' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
	} },
);

has 'datetime_formats_interval' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Bh => {
				B => q{B h–ից B h-ը},
				h => q{B h–ից h-ը},
			},
			Bhm => {
				B => q{B h:mm – B h:mm},
				h => q{B h:mm – h:mm},
				m => q{B h:mm – h:mm},
			},
			H => {
				H => q{H–H},
			},
			Hm => {
				H => q{H:mm–H:mm},
				m => q{H:mm–H:mm},
			},
			Hmv => {
				H => q{H:mm–H:mm v},
				m => q{H:mm–H:mm v},
			},
			Hv => {
				H => q{H–H v},
			},
			M => {
				M => q{M–M},
			},
			MEd => {
				M => q{E, dd.MM – E, dd.MM},
				d => q{E, dd.MM – E, dd.MM},
			},
			MMM => {
				M => q{MMM–MMM},
			},
			MMMEd => {
				M => q{E, MMM dd – E, MMM dd},
				d => q{E, MMM dd – E, MMM dd},
			},
			MMMd => {
				M => q{MMM dd – MMM dd},
				d => q{MMM dd–dd},
			},
			Md => {
				M => q{dd.MM – dd.MM},
				d => q{dd.MM – dd.MM},
			},
			fallback => '{0} - {1}',
			y => {
				y => q{y–y G},
			},
			yM => {
				M => q{MM.y – MM.y G},
				y => q{MM.y – MM.y G},
			},
			yMEd => {
				M => q{ccc, dd.MM.y – ccc, dd.MM.y G},
				d => q{ccc, dd.MM.y – ccc, dd.MM.y G},
				y => q{ccc, dd.MM.y – ccc, dd.MM.y G},
			},
			yMMM => {
				M => q{MMM–MMM y թ. G},
				y => q{MMM y – MMM y թ. G},
			},
			yMMMEd => {
				M => q{E, d MMM – E, d MMM, y թ. G},
				d => q{E, d MMM – E, d MMM, y թ. G},
				y => q{E, d MMM, y – E, d MMM, y թ. G},
			},
			yMMMM => {
				M => q{G y թ. MMM – MMM},
				y => q{MMM y – MMM y թ G},
			},
			yMMMd => {
				M => q{dd MMM – dd MMM, y թ. G},
				d => q{dd–dd MMM, y թ. G},
				y => q{dd MMM, y – dd MMM, y թ. G},
			},
			yMd => {
				M => q{dd.MM.y – dd.MM.y G},
				d => q{dd.MM.y – dd.MM.y G},
				y => q{dd.MM.y – dd.MM.y G},
			},
		},
		'gregorian' => {
			Bh => {
				B => q{B h–ից B h-ը},
				h => q{B h–ից h-ը},
			},
			Bhm => {
				B => q{B h:mm – B h:mm},
				h => q{B h:mm–h:mm},
				m => q{B h:mm – h:mm},
			},
			Gy => {
				y => q{G y–y թթ․},
			},
			GyM => {
				G => q{GGGGG MM.y – GGGGG MM.y},
				M => q{GGGGG MM.y – MM.y},
				y => q{GGGGG MM.y – MM.y},
			},
			GyMEd => {
				G => q{GGGGG dd.MM.y ccc – GGGGG dd.MM.y ccc},
				M => q{GGGGG dd.MM.y ccc – dd.MM.y ccc},
				d => q{GGGGG dd.MM.y, ccc – dd.MM.y, ccc},
				y => q{GGGGG dd.MM.y ccc – dd.MM.y ccc},
			},
			GyMMM => {
				M => q{G y թ. MMM – MMM},
			},
			GyMMMEd => {
				G => q{G y թ. MMM d E – G MMM d E},
				M => q{G y թ. MMM d E – MMM d E},
				d => q{G y թ. MMM d E – MMM d E},
				y => q{G y թ. MMM d E – y թ. MMM d E},
			},
			GyMMMd => {
				G => q{G y թ․ MMM dd – G y թ. MMM dd},
				M => q{G y թ. MMM dd – MMM dd},
				d => q{G y թ. MMM dd–dd},
				y => q{G y թ․ MMM dd – G y թ. MMM dd},
			},
			GyMd => {
				G => q{GGGGG dd.MM.y – GGGGG dd.MM.y},
				M => q{GGGGG dd.MM.y – dd.MM.y},
				d => q{GGGGG dd.MM.y – dd.MM.y},
				y => q{GGGGG dd.MM.y – dd.MM.y},
			},
			H => {
				H => q{H–H},
			},
			Hm => {
				H => q{H:mm–H:mm},
				m => q{H:mm–H:mm},
			},
			Hmv => {
				H => q{H:mm–H:mm, v},
				m => q{H:mm–H:mm, v},
			},
			Hv => {
				H => q{H–H, v},
			},
			M => {
				M => q{M–M},
			},
			MEd => {
				M => q{E, dd.MM – E, dd.MM},
				d => q{E, dd.MM – E, dd.MM},
			},
			MMM => {
				M => q{MMM–MMM},
			},
			MMMEd => {
				M => q{E, MMM dd – E, MMM dd},
				d => q{E, MMM dd – E, MMM dd},
			},
			MMMd => {
				M => q{MMM dd – MMM dd},
				d => q{MMM dd–dd},
			},
			Md => {
				M => q{dd.MM – dd.MM},
				d => q{dd.MM – dd.MM},
			},
			fallback => '{0} – {1}',
			yM => {
				M => q{MM.y – MM.y},
				y => q{MM.y – MM.y},
			},
			yMEd => {
				M => q{ccc, dd.MM.y – ccc, dd.MM.y},
				d => q{ccc, dd.MM.y – ccc, dd.MM.y},
				y => q{ccc, dd.MM.y – ccc, dd.MM.y},
			},
			yMMM => {
				M => q{y թ. MMM – MMM},
			},
			yMMMEd => {
				M => q{E, d MMM – E, d MMM, y թ.},
				d => q{E, d MMM – E, d MMM, y թ.},
				y => q{E, d MMM, y – E, d MMM, y թ.},
			},
			yMMMM => {
				M => q{y թ․ LLLL – LLLL},
				y => q{y թ․ LLLL – y թ․ LLLL},
			},
			yMMMd => {
				M => q{dd MMM – dd MMM, y թ.},
				d => q{dd–dd MMM, y թ.},
				y => q{dd MMM, y թ․ – dd MMM, y թ.},
			},
			yMd => {
				M => q{dd.MM.y – dd.MM.y},
				d => q{dd.MM.y – dd.MM.y},
				y => q{dd.MM.y – dd.MM.y},
			},
		},
	} },
);

has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		'Afghanistan' => {
			long => {
				'standard' => q#Աֆղանստանի ժամանակ#,
			},
		},
		'Africa/Abidjan' => {
			exemplarCity => q#Աբիջան#,
		},
		'Africa/Accra' => {
			exemplarCity => q#Աքրա#,
		},
		'Africa/Addis_Ababa' => {
			exemplarCity => q#Ադիս Աբեբա#,
		},
		'Africa/Algiers' => {
			exemplarCity => q#Ալժիր#,
		},
		'Africa/Asmera' => {
			exemplarCity => q#Ասմերա#,
		},
		'Africa/Bamako' => {
			exemplarCity => q#Բամակո#,
		},
		'Africa/Bangui' => {
			exemplarCity => q#Բանգի#,
		},
		'Africa/Banjul' => {
			exemplarCity => q#Բանժուլ#,
		},
		'Africa/Bissau' => {
			exemplarCity => q#Բիսաու#,
		},
		'Africa/Blantyre' => {
			exemplarCity => q#Բլանթայր#,
		},
		'Africa/Brazzaville' => {
			exemplarCity => q#Բրազավիլ#,
		},
		'Africa/Bujumbura' => {
			exemplarCity => q#Բուժումբուրա#,
		},
		'Africa/Cairo' => {
			exemplarCity => q#Կահիրե#,
		},
		'Africa/Casablanca' => {
			exemplarCity => q#Կասաբլանկա#,
		},
		'Africa/Ceuta' => {
			exemplarCity => q#Սեուտա#,
		},
		'Africa/Conakry' => {
			exemplarCity => q#Կոնակրի#,
		},
		'Africa/Dakar' => {
			exemplarCity => q#Դաքար#,
		},
		'Africa/Dar_es_Salaam' => {
			exemplarCity => q#Դար-Էս-Սալամ#,
		},
		'Africa/Djibouti' => {
			exemplarCity => q#Ջիբութի#,
		},
		'Africa/Douala' => {
			exemplarCity => q#Դուալա#,
		},
		'Africa/El_Aaiun' => {
			exemplarCity => q#Էլ Այուն#,
		},
		'Africa/Freetown' => {
			exemplarCity => q#Ֆրիթաուն#,
		},
		'Africa/Gaborone' => {
			exemplarCity => q#Գաբորոնե#,
		},
		'Africa/Harare' => {
			exemplarCity => q#Հարարե#,
		},
		'Africa/Johannesburg' => {
			exemplarCity => q#Յոհանեսբուրգ#,
		},
		'Africa/Juba' => {
			exemplarCity => q#Ջուբա#,
		},
		'Africa/Kampala' => {
			exemplarCity => q#Կամպալա#,
		},
		'Africa/Khartoum' => {
			exemplarCity => q#Խարթում#,
		},
		'Africa/Kigali' => {
			exemplarCity => q#Կիգալի#,
		},
		'Africa/Kinshasa' => {
			exemplarCity => q#Կինշասա#,
		},
		'Africa/Lagos' => {
			exemplarCity => q#Լագոս#,
		},
		'Africa/Libreville' => {
			exemplarCity => q#Լիբրևիլ#,
		},
		'Africa/Lome' => {
			exemplarCity => q#Լոմե#,
		},
		'Africa/Luanda' => {
			exemplarCity => q#Լուանդա#,
		},
		'Africa/Lubumbashi' => {
			exemplarCity => q#Լուբումբաշի#,
		},
		'Africa/Lusaka' => {
			exemplarCity => q#Լուսակա#,
		},
		'Africa/Malabo' => {
			exemplarCity => q#Մալաբո#,
		},
		'Africa/Maputo' => {
			exemplarCity => q#Մապուտու#,
		},
		'Africa/Maseru' => {
			exemplarCity => q#Մասերու#,
		},
		'Africa/Mbabane' => {
			exemplarCity => q#Մբաբանե#,
		},
		'Africa/Mogadishu' => {
			exemplarCity => q#Մոգադիշո#,
		},
		'Africa/Monrovia' => {
			exemplarCity => q#Մոնրովիա#,
		},
		'Africa/Nairobi' => {
			exemplarCity => q#Նայրոբի#,
		},
		'Africa/Ndjamena' => {
			exemplarCity => q#Նջամենա#,
		},
		'Africa/Niamey' => {
			exemplarCity => q#Նիամեյ#,
		},
		'Africa/Nouakchott' => {
			exemplarCity => q#Նուակշոտ#,
		},
		'Africa/Ouagadougou' => {
			exemplarCity => q#Ուագադուգու#,
		},
		'Africa/Porto-Novo' => {
			exemplarCity => q#Պորտո Նովո#,
		},
		'Africa/Sao_Tome' => {
			exemplarCity => q#Սան Տոմե#,
		},
		'Africa/Tripoli' => {
			exemplarCity => q#Տրիպոլի#,
		},
		'Africa/Tunis' => {
			exemplarCity => q#Թունիս#,
		},
		'Africa/Windhoek' => {
			exemplarCity => q#Վինդհուկ#,
		},
		'Africa_Central' => {
			long => {
				'standard' => q#Կենտրոնական Աֆրիկայի ժամանակ#,
			},
		},
		'Africa_Eastern' => {
			long => {
				'standard' => q#Արևելյան Աֆրիկայի ժամանակ#,
			},
		},
		'Africa_Southern' => {
			long => {
				'standard' => q#Հարավային Աֆրիկայի ժամանակ#,
			},
		},
		'Africa_Western' => {
			long => {
				'daylight' => q#Արևմտյան Աֆրիկայի ամառային ժամանակ#,
				'generic' => q#Արևմտյան Աֆրիկայի ժամանակ#,
				'standard' => q#Արևմտյան Աֆրիկայի ստանդարտ ժամանակ#,
			},
		},
		'Alaska' => {
			long => {
				'daylight' => q#Ալյասկայի ամառային ժամանակ#,
				'generic' => q#Ալյասկայի ժամանակ#,
				'standard' => q#Ալյասկայի ստանդարտ ժամանակ#,
			},
		},
		'Amazon' => {
			long => {
				'daylight' => q#Ամազոնյան ամառային ժամանակ#,
				'generic' => q#Ամազոնյան ժամանակ#,
				'standard' => q#Ամազոնյան ստանդարտ ժամանակ#,
			},
		},
		'America/Adak' => {
			exemplarCity => q#Ադակ կղզի#,
		},
		'America/Anchorage' => {
			exemplarCity => q#Անքորիջ#,
		},
		'America/Anguilla' => {
			exemplarCity => q#Անգուիլա#,
		},
		'America/Antigua' => {
			exemplarCity => q#Անտիգուա#,
		},
		'America/Araguaina' => {
			exemplarCity => q#Արագուաինա#,
		},
		'America/Argentina/La_Rioja' => {
			exemplarCity => q#Լա Ռիոխա#,
		},
		'America/Argentina/Rio_Gallegos' => {
			exemplarCity => q#Ռիո Գալյեգոս#,
		},
		'America/Argentina/Salta' => {
			exemplarCity => q#Սալտա#,
		},
		'America/Argentina/San_Juan' => {
			exemplarCity => q#Սան Խուան#,
		},
		'America/Argentina/San_Luis' => {
			exemplarCity => q#Սան Լուիս#,
		},
		'America/Argentina/Tucuman' => {
			exemplarCity => q#Տուկուման#,
		},
		'America/Argentina/Ushuaia' => {
			exemplarCity => q#Ուշուայա#,
		},
		'America/Aruba' => {
			exemplarCity => q#Արուբա#,
		},
		'America/Asuncion' => {
			exemplarCity => q#Ասունսյոն#,
		},
		'America/Bahia' => {
			exemplarCity => q#Բաիյա#,
		},
		'America/Bahia_Banderas' => {
			exemplarCity => q#Բաիյա Բանդերաս#,
		},
		'America/Barbados' => {
			exemplarCity => q#Բարբադոս#,
		},
		'America/Belem' => {
			exemplarCity => q#Բելեմ#,
		},
		'America/Belize' => {
			exemplarCity => q#Բելիզ#,
		},
		'America/Blanc-Sablon' => {
			exemplarCity => q#Բլանկ-Սաբլոն#,
		},
		'America/Boa_Vista' => {
			exemplarCity => q#Բոա Վիստա#,
		},
		'America/Bogota' => {
			exemplarCity => q#Բոգոտա#,
		},
		'America/Boise' => {
			exemplarCity => q#Բոյսե#,
		},
		'America/Buenos_Aires' => {
			exemplarCity => q#Բուենոս Այրես#,
		},
		'America/Cambridge_Bay' => {
			exemplarCity => q#Քեմբրիջ Բեյ#,
		},
		'America/Campo_Grande' => {
			exemplarCity => q#Կամպու Գրանդի#,
		},
		'America/Cancun' => {
			exemplarCity => q#Կանկուն#,
		},
		'America/Caracas' => {
			exemplarCity => q#Կարակաս#,
		},
		'America/Catamarca' => {
			exemplarCity => q#Կատամարկա#,
		},
		'America/Cayenne' => {
			exemplarCity => q#Կայեն#,
		},
		'America/Cayman' => {
			exemplarCity => q#Կայման կղզիներ#,
		},
		'America/Chicago' => {
			exemplarCity => q#Չիկագո#,
		},
		'America/Chihuahua' => {
			exemplarCity => q#Չիուաուա#,
		},
		'America/Ciudad_Juarez' => {
			exemplarCity => q#Սյուդադ Խուարես#,
		},
		'America/Coral_Harbour' => {
			exemplarCity => q#Ատիկոկան#,
		},
		'America/Cordoba' => {
			exemplarCity => q#Կորդովա#,
		},
		'America/Costa_Rica' => {
			exemplarCity => q#Կոստա Ռիկա#,
		},
		'America/Creston' => {
			exemplarCity => q#Քրեսթոն#,
		},
		'America/Cuiaba' => {
			exemplarCity => q#Կույաբա#,
		},
		'America/Curacao' => {
			exemplarCity => q#Կյուրասաո#,
		},
		'America/Danmarkshavn' => {
			exemplarCity => q#Դենմարքսհավն#,
		},
		'America/Dawson' => {
			exemplarCity => q#Դոուսոն#,
		},
		'America/Dawson_Creek' => {
			exemplarCity => q#Դոուսոն Քրիք#,
		},
		'America/Denver' => {
			exemplarCity => q#Դենվեր#,
		},
		'America/Detroit' => {
			exemplarCity => q#Դետրոյթ#,
		},
		'America/Dominica' => {
			exemplarCity => q#Դոմինիկա#,
		},
		'America/Edmonton' => {
			exemplarCity => q#Էդմոնտոն#,
		},
		'America/Eirunepe' => {
			exemplarCity => q#Էյրունեպե#,
		},
		'America/El_Salvador' => {
			exemplarCity => q#Սալվադոր#,
		},
		'America/Fort_Nelson' => {
			exemplarCity => q#Ֆորտ Նելսոն#,
		},
		'America/Fortaleza' => {
			exemplarCity => q#Ֆորտալեզա#,
		},
		'America/Glace_Bay' => {
			exemplarCity => q#Գլեյս Բեյ#,
		},
		'America/Godthab' => {
			exemplarCity => q#Նուուկ#,
		},
		'America/Goose_Bay' => {
			exemplarCity => q#Գուս Բեյ#,
		},
		'America/Grand_Turk' => {
			exemplarCity => q#Գրանդ Տյորք#,
		},
		'America/Grenada' => {
			exemplarCity => q#Գրենադա#,
		},
		'America/Guadeloupe' => {
			exemplarCity => q#Գվադելուպա#,
		},
		'America/Guatemala' => {
			exemplarCity => q#Գվատեմալա#,
		},
		'America/Guayaquil' => {
			exemplarCity => q#Գուայակիլ#,
		},
		'America/Guyana' => {
			exemplarCity => q#Գայանա#,
		},
		'America/Halifax' => {
			exemplarCity => q#Հալիֆաքս#,
		},
		'America/Havana' => {
			exemplarCity => q#Հավանա#,
		},
		'America/Hermosillo' => {
			exemplarCity => q#Էրմոսիլյո#,
		},
		'America/Indiana/Knox' => {
			exemplarCity => q#Նոքս, Ինդիանա#,
		},
		'America/Indiana/Marengo' => {
			exemplarCity => q#Մարենգո, Ինդիանա#,
		},
		'America/Indiana/Petersburg' => {
			exemplarCity => q#Պետերսբուրգ, Ինդիանա#,
		},
		'America/Indiana/Tell_City' => {
			exemplarCity => q#Թել Սիթի, Ինդիանա#,
		},
		'America/Indiana/Vevay' => {
			exemplarCity => q#Վիվեյ, Ինդիանա#,
		},
		'America/Indiana/Vincennes' => {
			exemplarCity => q#Վինսենս, Ինդիանա#,
		},
		'America/Indiana/Winamac' => {
			exemplarCity => q#Վինամակ, Ինդիանա#,
		},
		'America/Indianapolis' => {
			exemplarCity => q#Ինդիանապոլիս#,
		},
		'America/Inuvik' => {
			exemplarCity => q#Ինուվիկ#,
		},
		'America/Iqaluit' => {
			exemplarCity => q#Իկալուիտ#,
		},
		'America/Jamaica' => {
			exemplarCity => q#Ճամայկա#,
		},
		'America/Jujuy' => {
			exemplarCity => q#Ժուժույ#,
		},
		'America/Juneau' => {
			exemplarCity => q#Ջունո#,
		},
		'America/Kentucky/Monticello' => {
			exemplarCity => q#Մոնտիսելո, Կենտուկի#,
		},
		'America/Kralendijk' => {
			exemplarCity => q#Կրալենդեյկ#,
		},
		'America/La_Paz' => {
			exemplarCity => q#Լա Պաս#,
		},
		'America/Lima' => {
			exemplarCity => q#Լիմա#,
		},
		'America/Los_Angeles' => {
			exemplarCity => q#Լոս Անջելես#,
		},
		'America/Louisville' => {
			exemplarCity => q#Լուիսվիլ#,
		},
		'America/Lower_Princes' => {
			exemplarCity => q#Լոուեր Պրինսես Քվորթեր#,
		},
		'America/Maceio' => {
			exemplarCity => q#Մասեյո#,
		},
		'America/Managua' => {
			exemplarCity => q#Մանագուա#,
		},
		'America/Manaus' => {
			exemplarCity => q#Մանաուս#,
		},
		'America/Marigot' => {
			exemplarCity => q#Մարիգո#,
		},
		'America/Martinique' => {
			exemplarCity => q#Մարտինիկա#,
		},
		'America/Matamoros' => {
			exemplarCity => q#Մատամորոս#,
		},
		'America/Mazatlan' => {
			exemplarCity => q#Մազաթլան#,
		},
		'America/Mendoza' => {
			exemplarCity => q#Մենդոսա#,
		},
		'America/Menominee' => {
			exemplarCity => q#Մենոմինի#,
		},
		'America/Merida' => {
			exemplarCity => q#Մերիդա#,
		},
		'America/Metlakatla' => {
			exemplarCity => q#Մետլակատլա#,
		},
		'America/Mexico_City' => {
			exemplarCity => q#Մեխիկո#,
		},
		'America/Miquelon' => {
			exemplarCity => q#Միքելոն#,
		},
		'America/Moncton' => {
			exemplarCity => q#Մոնկտոն#,
		},
		'America/Monterrey' => {
			exemplarCity => q#Մոնտեռեյ#,
		},
		'America/Montevideo' => {
			exemplarCity => q#Մոնտեվիդեո#,
		},
		'America/Montserrat' => {
			exemplarCity => q#Մոնսեռատ#,
		},
		'America/Nassau' => {
			exemplarCity => q#Նասաու#,
		},
		'America/New_York' => {
			exemplarCity => q#Նյու Յորք#,
		},
		'America/Nipigon' => {
			exemplarCity => q#Նիպիգոն#,
		},
		'America/Nome' => {
			exemplarCity => q#Նոմ#,
		},
		'America/Noronha' => {
			exemplarCity => q#Նորոնյա#,
		},
		'America/North_Dakota/Beulah' => {
			exemplarCity => q#Բոյլա, Հյուսիսային Դակոտա#,
		},
		'America/North_Dakota/Center' => {
			exemplarCity => q#Հյուսիսային Դակոտա - Կենտրոն#,
		},
		'America/North_Dakota/New_Salem' => {
			exemplarCity => q#Նյու Սալեմ, Հյուսիսային Դակոտա#,
		},
		'America/Ojinaga' => {
			exemplarCity => q#Օխինագա#,
		},
		'America/Panama' => {
			exemplarCity => q#Պանամա#,
		},
		'America/Pangnirtung' => {
			exemplarCity => q#Պանգնիրտանգ#,
		},
		'America/Paramaribo' => {
			exemplarCity => q#Պարամարիբո#,
		},
		'America/Phoenix' => {
			exemplarCity => q#Ֆինիքս#,
		},
		'America/Port-au-Prince' => {
			exemplarCity => q#Պորտ-օ-Պրենս#,
		},
		'America/Port_of_Spain' => {
			exemplarCity => q#Պորտ-օֆ-Սփեյն#,
		},
		'America/Porto_Velho' => {
			exemplarCity => q#Պորտու Վելյու#,
		},
		'America/Puerto_Rico' => {
			exemplarCity => q#Պուերտո Ռիկո#,
		},
		'America/Punta_Arenas' => {
			exemplarCity => q#Պունտա Արենաս#,
		},
		'America/Rainy_River' => {
			exemplarCity => q#Ռեյնի Ռիվեր#,
		},
		'America/Rankin_Inlet' => {
			exemplarCity => q#Ռանկին Ինլեթ#,
		},
		'America/Recife' => {
			exemplarCity => q#Ռեսիֆի#,
		},
		'America/Regina' => {
			exemplarCity => q#Ռեջայնա#,
		},
		'America/Resolute' => {
			exemplarCity => q#Ռեզոլյուտ#,
		},
		'America/Rio_Branco' => {
			exemplarCity => q#Ռիու Բրանկու#,
		},
		'America/Santa_Isabel' => {
			exemplarCity => q#Սանտա Իզաբել#,
		},
		'America/Santarem' => {
			exemplarCity => q#Սանտարեմ#,
		},
		'America/Santiago' => {
			exemplarCity => q#Սանտյագո#,
		},
		'America/Santo_Domingo' => {
			exemplarCity => q#Սանտո Դոմինգո#,
		},
		'America/Sao_Paulo' => {
			exemplarCity => q#Սան Պաուլու#,
		},
		'America/Scoresbysund' => {
			exemplarCity => q#Սկորսբիսուն#,
		},
		'America/Sitka' => {
			exemplarCity => q#Սիտկա#,
		},
		'America/St_Barthelemy' => {
			exemplarCity => q#Սեն Բարտելմի#,
		},
		'America/St_Johns' => {
			exemplarCity => q#Սենթ Ջոնս#,
		},
		'America/St_Kitts' => {
			exemplarCity => q#Սենթ Քիտս#,
		},
		'America/St_Lucia' => {
			exemplarCity => q#Սենթ Լյուսիա#,
		},
		'America/St_Thomas' => {
			exemplarCity => q#Սենթ Թոմաս#,
		},
		'America/St_Vincent' => {
			exemplarCity => q#Սենթ Վինսենթ#,
		},
		'America/Swift_Current' => {
			exemplarCity => q#Սվիֆթ Քարենթ#,
		},
		'America/Tegucigalpa' => {
			exemplarCity => q#Տեգուսիգալպա#,
		},
		'America/Thule' => {
			exemplarCity => q#Տուլե#,
		},
		'America/Thunder_Bay' => {
			exemplarCity => q#Թանդեր Բեյ#,
		},
		'America/Tijuana' => {
			exemplarCity => q#Տիխուանա#,
		},
		'America/Toronto' => {
			exemplarCity => q#Տորոնտո#,
		},
		'America/Tortola' => {
			exemplarCity => q#Թորթոլա#,
		},
		'America/Vancouver' => {
			exemplarCity => q#Վանկուվեր#,
		},
		'America/Whitehorse' => {
			exemplarCity => q#Ուայթհորս#,
		},
		'America/Winnipeg' => {
			exemplarCity => q#Վինիպեգ#,
		},
		'America/Yakutat' => {
			exemplarCity => q#Յակուտատ#,
		},
		'America/Yellowknife' => {
			exemplarCity => q#Յելոունայֆ#,
		},
		'America_Central' => {
			long => {
				'daylight' => q#Կենտրոնական Ամերիկայի ամառային ժամանակ#,
				'generic' => q#Կենտրոնական Ամերիկայի ժամանակ#,
				'standard' => q#Կենտրոնական Ամերիկայի ստանդարտ ժամանակ#,
			},
		},
		'America_Eastern' => {
			long => {
				'daylight' => q#Արևելյան Ամերիկայի ամառային ժամանակ#,
				'generic' => q#Արևելյան Ամերիկայի ժամանակ#,
				'standard' => q#Արևելյան Ամերիկայի ստանդարտ ժամանակ#,
			},
		},
		'America_Mountain' => {
			long => {
				'daylight' => q#Լեռնային ամառային ժամանակ (ԱՄՆ)#,
				'generic' => q#Լեռնային ժամանակ (ԱՄՆ)#,
				'standard' => q#Լեռնային ստանդարտ ժամանակ (ԱՄՆ)#,
			},
		},
		'America_Pacific' => {
			long => {
				'daylight' => q#Խաղաղօվկիանոսյան ամառային ժամանակ#,
				'generic' => q#Խաղաղօվկիանոսյան ժամանակ#,
				'standard' => q#Խաղաղօվկիանոսյան ստանդարտ ժամանակ#,
			},
		},
		'Antarctica/Casey' => {
			exemplarCity => q#Քեյսի#,
		},
		'Antarctica/Davis' => {
			exemplarCity => q#Դեյվիս#,
		},
		'Antarctica/DumontDUrville' => {
			exemplarCity => q#Դյումոն դ’Յուրվիլ#,
		},
		'Antarctica/Macquarie' => {
			exemplarCity => q#Մակկուորի կղզի#,
		},
		'Antarctica/Mawson' => {
			exemplarCity => q#Մոուսոն#,
		},
		'Antarctica/McMurdo' => {
			exemplarCity => q#Մակ-Մերդո#,
		},
		'Antarctica/Palmer' => {
			exemplarCity => q#Պալմեր#,
		},
		'Antarctica/Rothera' => {
			exemplarCity => q#Ռոտերա#,
		},
		'Antarctica/Syowa' => {
			exemplarCity => q#Սյովա#,
		},
		'Antarctica/Troll' => {
			exemplarCity => q#Տրոլլ#,
		},
		'Antarctica/Vostok' => {
			exemplarCity => q#Վոստոկ#,
		},
		'Apia' => {
			long => {
				'daylight' => q#Ապիայի ամառային ժամանակ#,
				'generic' => q#Ապիայի ժամանակ#,
				'standard' => q#Ապիայի ստանդարտ ժամանակ#,
			},
		},
		'Arabian' => {
			long => {
				'daylight' => q#Սաուդյան Արաբիայի ամառային ժամանակ#,
				'generic' => q#Սաուդյան Արաբիայի ժամանակ#,
				'standard' => q#Սաուդյան Արաբիայի ստանդարտ ժամանակ#,
			},
		},
		'Arctic/Longyearbyen' => {
			exemplarCity => q#Լոնգյիր#,
		},
		'Argentina' => {
			long => {
				'daylight' => q#Արգենտինայի ամառային ժամանակ#,
				'generic' => q#Արգենտինայի ժամանակ#,
				'standard' => q#Արգենտինայի ստնադարտ ժամանակ#,
			},
		},
		'Argentina_Western' => {
			long => {
				'daylight' => q#Արևմտյան Արգենտինայի ամառային ժամանակ#,
				'generic' => q#Արևմտյան Արգենտինայի ժամանակ#,
				'standard' => q#Արևմտյան Արգենտինայի ստնադարտ ժամանակ#,
			},
		},
		'Armenia' => {
			long => {
				'daylight' => q#Հայաստանի ամառային ժամանակ#,
				'generic' => q#Հայաստանի ժամանակ#,
				'standard' => q#Հայաստանի ստանդարտ ժամանակ#,
			},
		},
		'Asia/Aden' => {
			exemplarCity => q#Ադեն#,
		},
		'Asia/Almaty' => {
			exemplarCity => q#Ալմաթի#,
		},
		'Asia/Amman' => {
			exemplarCity => q#Ամման#,
		},
		'Asia/Anadyr' => {
			exemplarCity => q#Անադիր#,
		},
		'Asia/Aqtau' => {
			exemplarCity => q#Ակտաու#,
		},
		'Asia/Aqtobe' => {
			exemplarCity => q#Ակտոբե#,
		},
		'Asia/Ashgabat' => {
			exemplarCity => q#Աշխաբադ#,
		},
		'Asia/Atyrau' => {
			exemplarCity => q#Ատիրաու#,
		},
		'Asia/Baghdad' => {
			exemplarCity => q#Բաղդադ#,
		},
		'Asia/Bahrain' => {
			exemplarCity => q#Բահրեյն#,
		},
		'Asia/Baku' => {
			exemplarCity => q#Բաքու#,
		},
		'Asia/Bangkok' => {
			exemplarCity => q#Բանգկոկ#,
		},
		'Asia/Barnaul' => {
			exemplarCity => q#Բառնաուլ#,
		},
		'Asia/Beirut' => {
			exemplarCity => q#Բեյրութ#,
		},
		'Asia/Bishkek' => {
			exemplarCity => q#Բիշքեկ#,
		},
		'Asia/Brunei' => {
			exemplarCity => q#Բրունեյ#,
		},
		'Asia/Calcutta' => {
			exemplarCity => q#Կալկուտա#,
		},
		'Asia/Chita' => {
			exemplarCity => q#Չիտա#,
		},
		'Asia/Choibalsan' => {
			exemplarCity => q#Չոյբալսան#,
		},
		'Asia/Colombo' => {
			exemplarCity => q#Կոլոմբո#,
		},
		'Asia/Damascus' => {
			exemplarCity => q#Դամասկոս#,
		},
		'Asia/Dhaka' => {
			exemplarCity => q#Դաքքա#,
		},
		'Asia/Dili' => {
			exemplarCity => q#Դիլի#,
		},
		'Asia/Dubai' => {
			exemplarCity => q#Դուբայ#,
		},
		'Asia/Dushanbe' => {
			exemplarCity => q#Դուշանբե#,
		},
		'Asia/Famagusta' => {
			exemplarCity => q#Ֆամագուստա#,
		},
		'Asia/Gaza' => {
			exemplarCity => q#Գազա#,
		},
		'Asia/Hebron' => {
			exemplarCity => q#Հեբրոն#,
		},
		'Asia/Hong_Kong' => {
			exemplarCity => q#Հոնկոնգ#,
		},
		'Asia/Hovd' => {
			exemplarCity => q#Հովդ#,
		},
		'Asia/Irkutsk' => {
			exemplarCity => q#Իրկուտսկ#,
		},
		'Asia/Jakarta' => {
			exemplarCity => q#Ջակարտա#,
		},
		'Asia/Jayapura' => {
			exemplarCity => q#Ջայպուրա#,
		},
		'Asia/Jerusalem' => {
			exemplarCity => q#Երուսաղեմ#,
		},
		'Asia/Kabul' => {
			exemplarCity => q#Քաբուլ#,
		},
		'Asia/Kamchatka' => {
			exemplarCity => q#Կամչատկա#,
		},
		'Asia/Karachi' => {
			exemplarCity => q#Կարաչի#,
		},
		'Asia/Katmandu' => {
			exemplarCity => q#Կատմանդու#,
		},
		'Asia/Khandyga' => {
			exemplarCity => q#Խանդիգա#,
		},
		'Asia/Krasnoyarsk' => {
			exemplarCity => q#Կրասնոյարսկ#,
		},
		'Asia/Kuala_Lumpur' => {
			exemplarCity => q#Կուալա Լումպուր#,
		},
		'Asia/Kuching' => {
			exemplarCity => q#Կուչինգ#,
		},
		'Asia/Kuwait' => {
			exemplarCity => q#Քուվեյթ#,
		},
		'Asia/Macau' => {
			exemplarCity => q#Մակաո#,
		},
		'Asia/Magadan' => {
			exemplarCity => q#Մագադան#,
		},
		'Asia/Makassar' => {
			exemplarCity => q#Մակասար#,
		},
		'Asia/Manila' => {
			exemplarCity => q#Մանիլա#,
		},
		'Asia/Muscat' => {
			exemplarCity => q#Մասկատ#,
		},
		'Asia/Nicosia' => {
			exemplarCity => q#Նիկոսիա#,
		},
		'Asia/Novokuznetsk' => {
			exemplarCity => q#Նովոկուզնեցկ#,
		},
		'Asia/Novosibirsk' => {
			exemplarCity => q#Նովոսիբիրսկ#,
		},
		'Asia/Omsk' => {
			exemplarCity => q#Օմսկ#,
		},
		'Asia/Oral' => {
			exemplarCity => q#Ուրալսկ#,
		},
		'Asia/Phnom_Penh' => {
			exemplarCity => q#Պնոմպեն#,
		},
		'Asia/Pontianak' => {
			exemplarCity => q#Պոնտիանակ#,
		},
		'Asia/Pyongyang' => {
			exemplarCity => q#Փխենյան#,
		},
		'Asia/Qatar' => {
			exemplarCity => q#Կատար#,
		},
		'Asia/Qostanay' => {
			exemplarCity => q#Կոստանայ#,
		},
		'Asia/Qyzylorda' => {
			exemplarCity => q#Կիզիլորդա#,
		},
		'Asia/Rangoon' => {
			exemplarCity => q#Ռանգուն#,
		},
		'Asia/Riyadh' => {
			exemplarCity => q#Էր Ռիադ#,
		},
		'Asia/Saigon' => {
			exemplarCity => q#Հոշիմին#,
		},
		'Asia/Sakhalin' => {
			exemplarCity => q#Սախալին#,
		},
		'Asia/Samarkand' => {
			exemplarCity => q#Սամարղանդ#,
		},
		'Asia/Seoul' => {
			exemplarCity => q#Սեուլ#,
		},
		'Asia/Shanghai' => {
			exemplarCity => q#Շանհայ#,
		},
		'Asia/Singapore' => {
			exemplarCity => q#Սինգապուր#,
		},
		'Asia/Srednekolymsk' => {
			exemplarCity => q#Սրեդնեկոլիմսկ#,
		},
		'Asia/Taipei' => {
			exemplarCity => q#Թայպեյ#,
		},
		'Asia/Tashkent' => {
			exemplarCity => q#Տաշքենդ#,
		},
		'Asia/Tbilisi' => {
			exemplarCity => q#Թբիլիսի#,
		},
		'Asia/Tehran' => {
			exemplarCity => q#Թեհրան#,
		},
		'Asia/Thimphu' => {
			exemplarCity => q#Տհիմպհու#,
		},
		'Asia/Tokyo' => {
			exemplarCity => q#Տոկիո#,
		},
		'Asia/Tomsk' => {
			exemplarCity => q#Տոմսկ#,
		},
		'Asia/Ulaanbaatar' => {
			exemplarCity => q#Ուլան Բատոր#,
		},
		'Asia/Urumqi' => {
			exemplarCity => q#Ուրումչի#,
		},
		'Asia/Ust-Nera' => {
			exemplarCity => q#Ուստ-Ներա#,
		},
		'Asia/Vientiane' => {
			exemplarCity => q#Վյենտյան#,
		},
		'Asia/Vladivostok' => {
			exemplarCity => q#Վլադիվոստոկ#,
		},
		'Asia/Yakutsk' => {
			exemplarCity => q#Յակուտսկ#,
		},
		'Asia/Yekaterinburg' => {
			exemplarCity => q#Եկատերինբուրգ#,
		},
		'Asia/Yerevan' => {
			exemplarCity => q#Երևան#,
		},
		'Atlantic' => {
			long => {
				'daylight' => q#Ատլանտյան ամառային ժամանակ#,
				'generic' => q#Ատլանտյան ժամանակ#,
				'standard' => q#Ատլանտյան ստանդարտ ժամանակ#,
			},
		},
		'Atlantic/Azores' => {
			exemplarCity => q#Ազորյան կղզիներ#,
		},
		'Atlantic/Bermuda' => {
			exemplarCity => q#Բերմուդներ#,
		},
		'Atlantic/Canary' => {
			exemplarCity => q#Կանարյան կղզիներ#,
		},
		'Atlantic/Cape_Verde' => {
			exemplarCity => q#Կաբո Վերդե#,
		},
		'Atlantic/Faeroe' => {
			exemplarCity => q#Ֆարերյան կղզիներ#,
		},
		'Atlantic/Madeira' => {
			exemplarCity => q#Մադեյրա#,
		},
		'Atlantic/Reykjavik' => {
			exemplarCity => q#Ռեյկյավիկ#,
		},
		'Atlantic/South_Georgia' => {
			exemplarCity => q#Հարավային Ջորջիա#,
		},
		'Atlantic/St_Helena' => {
			exemplarCity => q#Սուրբ Հեղինեի կղզի#,
		},
		'Atlantic/Stanley' => {
			exemplarCity => q#Սթենլի#,
		},
		'Australia/Adelaide' => {
			exemplarCity => q#Ադելաիդա#,
		},
		'Australia/Brisbane' => {
			exemplarCity => q#Բրիսբեն#,
		},
		'Australia/Broken_Hill' => {
			exemplarCity => q#Բրոքեն Հիլ#,
		},
		'Australia/Currie' => {
			exemplarCity => q#Քերի#,
		},
		'Australia/Darwin' => {
			exemplarCity => q#Դարվին#,
		},
		'Australia/Eucla' => {
			exemplarCity => q#Յուկլա#,
		},
		'Australia/Hobart' => {
			exemplarCity => q#Հոբարտ#,
		},
		'Australia/Lindeman' => {
			exemplarCity => q#Լինդեման#,
		},
		'Australia/Lord_Howe' => {
			exemplarCity => q#Լորդ Հաու կղզի#,
		},
		'Australia/Melbourne' => {
			exemplarCity => q#Մելբուրն#,
		},
		'Australia/Perth' => {
			exemplarCity => q#Պերթ#,
		},
		'Australia/Sydney' => {
			exemplarCity => q#Սիդնեյ#,
		},
		'Australia_Central' => {
			long => {
				'daylight' => q#Կենտրոնական Ավստրալիայի ամառային ժամանակ#,
				'generic' => q#Կենտրոնական Ավստրալիայի ժամանակ#,
				'standard' => q#Կենտրոնական Ավստրալիայի ստանդարտ ժամանակ#,
			},
		},
		'Australia_CentralWestern' => {
			long => {
				'daylight' => q#Կենտրոնական Ավստրալիայի արևմտյան ամառային ժամանակ#,
				'generic' => q#Կենտրոնական Ավստրալիայի արևմտյան ժամանակ#,
				'standard' => q#Կենտրոնական Ավստրալիայի արևմտյան ստանդարտ ժամանակ#,
			},
		},
		'Australia_Eastern' => {
			long => {
				'daylight' => q#Արևելյան Ավստրալիայի ամառային ժամանակ#,
				'generic' => q#Արևելյան Ավստրալիայի ժամանակ#,
				'standard' => q#Արևելյան Ավստրալիայի ստանդարտ ժամանակ#,
			},
		},
		'Australia_Western' => {
			long => {
				'daylight' => q#Արևմտյան Ավստրալիայի ամառային ժամանակ#,
				'generic' => q#Արևմտյան Ավստրալիայի ժամանակ#,
				'standard' => q#Արևմտյան Ավստրալիայի ստանդարտ ժամանակ#,
			},
		},
		'Azerbaijan' => {
			long => {
				'daylight' => q#Ադրբեջանի ամառային ժամանակ#,
				'generic' => q#Ադրբեջանի ժամանակ#,
				'standard' => q#Ադրբեջանի ստանդարտ ժամանակ#,
			},
		},
		'Azores' => {
			long => {
				'daylight' => q#Ազորյան կղզիների ամառային ժամանակ#,
				'generic' => q#Ազորյան կղզիների ժամանակ#,
				'standard' => q#Ազորյան կղզիների ստանդարտ ժամանակ#,
			},
		},
		'Bangladesh' => {
			long => {
				'daylight' => q#Բանգլադեշի ամառային ժամանակ#,
				'generic' => q#Բանգլադեշի ժամանակ#,
				'standard' => q#Բանգլադեշի ստանդարտ ժամանակ#,
			},
		},
		'Bhutan' => {
			long => {
				'standard' => q#Բութանի ժամանակ#,
			},
		},
		'Bolivia' => {
			long => {
				'standard' => q#Բոլիվիայի ժամանակ#,
			},
		},
		'Brasilia' => {
			long => {
				'daylight' => q#Բրազիլիայի ամառային ժամանակ#,
				'generic' => q#Բրազիլիայի ժամանակ#,
				'standard' => q#Բրազիլիայի ստանդարտ ժամանակ#,
			},
		},
		'Brunei' => {
			long => {
				'standard' => q#Բրունեյի ժամանակ#,
			},
		},
		'Cape_Verde' => {
			long => {
				'daylight' => q#Կաբո Վերդեի ամառային ժամանակ#,
				'generic' => q#Կաբո Վերդեի ժամանակ#,
				'standard' => q#Կաբո Վերդեի ստանդարտ ժամանակ#,
			},
		},
		'Chamorro' => {
			long => {
				'standard' => q#Չամոռոյի ժամանակ#,
			},
		},
		'Chatham' => {
			long => {
				'daylight' => q#Չաթեմ կղզու ամառային ժամանակ#,
				'generic' => q#Չաթեմ կղզու ժամանակ#,
				'standard' => q#Չաթեմ կղզու ստանդարտ ժամանակ#,
			},
		},
		'Chile' => {
			long => {
				'daylight' => q#Չիլիի ամառային ժամանակ#,
				'generic' => q#Չիլիի ժամանակ#,
				'standard' => q#Չիլիի ստանդարտ ժամանակ#,
			},
		},
		'China' => {
			long => {
				'daylight' => q#Չինաստանի ամառային ժամանակ#,
				'generic' => q#Չինաստանի ժամանակ#,
				'standard' => q#Չինաստանի ստանդարտ ժամանակ#,
			},
		},
		'Choibalsan' => {
			long => {
				'daylight' => q#Չոյբալսանի ամառային ժամանակ#,
				'generic' => q#Չոյբալսանի ժամանակ#,
				'standard' => q#Չոյբալսանի ստանդարտ ժամանակ#,
			},
		},
		'Christmas' => {
			long => {
				'standard' => q#Սուրբ Ծննդյան կղզու ժամանակ#,
			},
		},
		'Cocos' => {
			long => {
				'standard' => q#Կոկոսյան կղզիների ժամանակ#,
			},
		},
		'Colombia' => {
			long => {
				'daylight' => q#Կոլումբիայի ամառային ժամանակ#,
				'generic' => q#Կոլումբիայի ժամանակ#,
				'standard' => q#Կոլումբիայի ստանդարտ ժամանակ#,
			},
		},
		'Cook' => {
			long => {
				'daylight' => q#Կուկի կղզիների կիսաամառային ժամանակ#,
				'generic' => q#Կուկի կղզիների ժամանակ#,
				'standard' => q#Կուկի կղզիների ստանդարտ ժամանակ#,
			},
		},
		'Cuba' => {
			long => {
				'daylight' => q#Կուբայի ամառային ժամանակ#,
				'generic' => q#Կուբայի ժամանակ#,
				'standard' => q#Կուբայի ստանդարտ ժամանակ#,
			},
		},
		'Davis' => {
			long => {
				'standard' => q#Դեյվիսի ժամանակ#,
			},
		},
		'DumontDUrville' => {
			long => {
				'standard' => q#Դյումոն դ’Յուրվիլի ժամանակ#,
			},
		},
		'East_Timor' => {
			long => {
				'standard' => q#Արևելյան Թիմորի ժամանակ#,
			},
		},
		'Easter' => {
			long => {
				'daylight' => q#Զատկի կղզու ամառային ժամանակ#,
				'generic' => q#Զատկի կղզու ժամանակ#,
				'standard' => q#Զատկի կղզու ստանդարտ ժամանակ#,
			},
		},
		'Ecuador' => {
			long => {
				'standard' => q#Էկվադորի ժամանակ#,
			},
		},
		'Etc/UTC' => {
			long => {
				'standard' => q#Համաշխարհային կոորդինացված ժամանակ#,
			},
		},
		'Etc/Unknown' => {
			exemplarCity => q#Անհայտ քաղաք#,
		},
		'Europe/Amsterdam' => {
			exemplarCity => q#Ամստերդամ#,
		},
		'Europe/Andorra' => {
			exemplarCity => q#Անդորրա#,
		},
		'Europe/Astrakhan' => {
			exemplarCity => q#Աստրախան#,
		},
		'Europe/Athens' => {
			exemplarCity => q#Աթենք#,
		},
		'Europe/Belgrade' => {
			exemplarCity => q#Բելգրադ#,
		},
		'Europe/Berlin' => {
			exemplarCity => q#Բեռլին#,
		},
		'Europe/Bratislava' => {
			exemplarCity => q#Բրատիսլավա#,
		},
		'Europe/Brussels' => {
			exemplarCity => q#Բրյուսել#,
		},
		'Europe/Bucharest' => {
			exemplarCity => q#Բուխարեստ#,
		},
		'Europe/Budapest' => {
			exemplarCity => q#Բուդապեշտ#,
		},
		'Europe/Busingen' => {
			exemplarCity => q#Բյուզինգեն#,
		},
		'Europe/Chisinau' => {
			exemplarCity => q#Քիշնև#,
		},
		'Europe/Copenhagen' => {
			exemplarCity => q#Կոպենհագեն#,
		},
		'Europe/Dublin' => {
			exemplarCity => q#Դուբլին#,
			long => {
				'daylight' => q#Իռլանդական ստանդարտ ժամանակ#,
			},
		},
		'Europe/Gibraltar' => {
			exemplarCity => q#Ջիբրալթար#,
		},
		'Europe/Guernsey' => {
			exemplarCity => q#Գերնսի#,
		},
		'Europe/Helsinki' => {
			exemplarCity => q#Հելսինկի#,
		},
		'Europe/Isle_of_Man' => {
			exemplarCity => q#Մեն կղզի#,
		},
		'Europe/Istanbul' => {
			exemplarCity => q#Ստամբուլ#,
		},
		'Europe/Jersey' => {
			exemplarCity => q#Ջերսի#,
		},
		'Europe/Kaliningrad' => {
			exemplarCity => q#Կալինինգրադ#,
		},
		'Europe/Kiev' => {
			exemplarCity => q#Կիև#,
		},
		'Europe/Kirov' => {
			exemplarCity => q#Կիրով#,
		},
		'Europe/Lisbon' => {
			exemplarCity => q#Լիսաբոն#,
		},
		'Europe/Ljubljana' => {
			exemplarCity => q#Լյուբլյանա#,
		},
		'Europe/London' => {
			exemplarCity => q#Լոնդոն#,
			long => {
				'daylight' => q#Բրիտանական ամառային ժամանակ#,
			},
		},
		'Europe/Luxembourg' => {
			exemplarCity => q#Լյուքսեմբուրգ#,
		},
		'Europe/Madrid' => {
			exemplarCity => q#Մադրիդ#,
		},
		'Europe/Malta' => {
			exemplarCity => q#Մալթա#,
		},
		'Europe/Mariehamn' => {
			exemplarCity => q#Մարիեհամն#,
		},
		'Europe/Minsk' => {
			exemplarCity => q#Մինսկ#,
		},
		'Europe/Monaco' => {
			exemplarCity => q#Մոնակո#,
		},
		'Europe/Moscow' => {
			exemplarCity => q#Մոսկվա#,
		},
		'Europe/Oslo' => {
			exemplarCity => q#Օսլո#,
		},
		'Europe/Paris' => {
			exemplarCity => q#Փարիզ#,
		},
		'Europe/Podgorica' => {
			exemplarCity => q#Պոդգորիցա#,
		},
		'Europe/Prague' => {
			exemplarCity => q#Պրահա#,
		},
		'Europe/Riga' => {
			exemplarCity => q#Ռիգա#,
		},
		'Europe/Rome' => {
			exemplarCity => q#Հռոմ#,
		},
		'Europe/Samara' => {
			exemplarCity => q#Սամարա#,
		},
		'Europe/San_Marino' => {
			exemplarCity => q#Սան Մարինո#,
		},
		'Europe/Sarajevo' => {
			exemplarCity => q#Սարաևո#,
		},
		'Europe/Saratov' => {
			exemplarCity => q#Սարատով#,
		},
		'Europe/Simferopol' => {
			exemplarCity => q#Սիմֆերոպոլ#,
		},
		'Europe/Skopje' => {
			exemplarCity => q#Սկոպյե#,
		},
		'Europe/Sofia' => {
			exemplarCity => q#Սոֆիա#,
		},
		'Europe/Stockholm' => {
			exemplarCity => q#Ստոկհոլմ#,
		},
		'Europe/Tallinn' => {
			exemplarCity => q#Տալլին#,
		},
		'Europe/Tirane' => {
			exemplarCity => q#Տիրանա#,
		},
		'Europe/Ulyanovsk' => {
			exemplarCity => q#Ուլյանովսկ#,
		},
		'Europe/Uzhgorod' => {
			exemplarCity => q#Ուժգորոդ#,
		},
		'Europe/Vaduz' => {
			exemplarCity => q#Վադուց#,
		},
		'Europe/Vatican' => {
			exemplarCity => q#Վատիկան#,
		},
		'Europe/Vienna' => {
			exemplarCity => q#Վիեննա#,
		},
		'Europe/Vilnius' => {
			exemplarCity => q#Վիլնյուս#,
		},
		'Europe/Volgograd' => {
			exemplarCity => q#Վոլգոգրադ#,
		},
		'Europe/Warsaw' => {
			exemplarCity => q#Վարշավա#,
		},
		'Europe/Zagreb' => {
			exemplarCity => q#Զագրեբ#,
		},
		'Europe/Zaporozhye' => {
			exemplarCity => q#Զապոռոժյե#,
		},
		'Europe/Zurich' => {
			exemplarCity => q#Ցյուրիխ#,
		},
		'Europe_Central' => {
			long => {
				'daylight' => q#Կենտրոնական Եվրոպայի ամառային ժամանակ#,
				'generic' => q#Կենտրոնական Եվրոպայի ժամանակ#,
				'standard' => q#Կենտրոնական Եվրոպայի ստանդարտ ժամանակ#,
			},
		},
		'Europe_Eastern' => {
			long => {
				'daylight' => q#Արևելյան Եվրոպայի ամառային ժամանակ#,
				'generic' => q#Արևելյան Եվրոպայի ժամանակ#,
				'standard' => q#Արևելյան Եվրոպայի ստանդարտ ժամանակ#,
			},
		},
		'Europe_Further_Eastern' => {
			long => {
				'standard' => q#Մինսկի ժամանակ#,
			},
		},
		'Europe_Western' => {
			long => {
				'daylight' => q#Արևմտյան Եվրոպայի ամառային ժամանակ#,
				'generic' => q#Արևմտյան Եվրոպայի ժամանակ#,
				'standard' => q#Արևմտյան Եվրոպայի ստանդարտ ժամանակ#,
			},
		},
		'Falkland' => {
			long => {
				'daylight' => q#Ֆոլքլենդյան կղզիների ամառային ժամանակ#,
				'generic' => q#Ֆոլքլենդյան կղզիների ժամանակ#,
				'standard' => q#Ֆոլքլենդյան կղզիների ստանդարտ ժամանակ#,
			},
		},
		'Fiji' => {
			long => {
				'daylight' => q#Ֆիջիի ամառային ժամանակ#,
				'generic' => q#Ֆիջիի ժամանակ#,
				'standard' => q#Ֆիջիի ստանդարտ ժամանակ#,
			},
		},
		'French_Guiana' => {
			long => {
				'standard' => q#Ֆրանսիական Գվիանայի ժամանակ#,
			},
		},
		'French_Southern' => {
			long => {
				'standard' => q#Ֆրանսիական հարավային և անտարկտիդյան ժամանակ#,
			},
		},
		'GMT' => {
			long => {
				'standard' => q#Գրինվիչի ժամանակ#,
			},
		},
		'Galapagos' => {
			long => {
				'standard' => q#Գալապագոսյան կղզիների ժամանակ#,
			},
		},
		'Gambier' => {
			long => {
				'standard' => q#Գամբյե կղզիների ժամանակ#,
			},
		},
		'Georgia' => {
			long => {
				'daylight' => q#Վրաստանի ամառային ժամանակ#,
				'generic' => q#Վրաստանի ժամանակ#,
				'standard' => q#Վրաստանի ստանդարտ ժամանակ#,
			},
		},
		'Gilbert_Islands' => {
			long => {
				'standard' => q#Ջիլբերթի կղզիների ժամանակ#,
			},
		},
		'Greenland_Eastern' => {
			long => {
				'daylight' => q#Արևելյան Գրենլանդիայի ամառային ժամանակ#,
				'generic' => q#Արևելյան Գրենլանդիայի ժամանակ#,
				'standard' => q#Արևելյան Գրենլանդիայի ստանդարտ ժամանակ#,
			},
		},
		'Greenland_Western' => {
			long => {
				'daylight' => q#Արևմտյան Գրենլանդիայի ամառային ժամանակ#,
				'generic' => q#Արևմտյան Գրենլանդիայի ժամանակ#,
				'standard' => q#Արևմտյան Գրենլանդիայի ստանդարտ ժամանակ#,
			},
		},
		'Gulf' => {
			long => {
				'standard' => q#Պարսից ծոցի ստանդարտ ժամանակ#,
			},
		},
		'Guyana' => {
			long => {
				'standard' => q#Գայանայի ժամանակ#,
			},
		},
		'Hawaii_Aleutian' => {
			long => {
				'daylight' => q#Հավայան-ալեության ամառային ժամանակ#,
				'generic' => q#Հավայան-ալեության ժամանակ#,
				'standard' => q#Հավայան-ալեության ստանդարտ ժամանակ#,
			},
		},
		'Hong_Kong' => {
			long => {
				'daylight' => q#Հոնկոնգի ամառային ժամանակ#,
				'generic' => q#Հոնկոնգի ժամանակ#,
				'standard' => q#Հոնկոնգի ստանդարտ ժամանակ#,
			},
		},
		'Hovd' => {
			long => {
				'daylight' => q#Հովդի ամառային ժամանակ#,
				'generic' => q#Հովդի ժամանակ#,
				'standard' => q#Հովդի ստանդարտ ժամանակ#,
			},
		},
		'India' => {
			long => {
				'standard' => q#Հնդկաստանի ստանդարտ ժամանակ#,
			},
		},
		'Indian/Antananarivo' => {
			exemplarCity => q#Անտանանարիվու#,
		},
		'Indian/Chagos' => {
			exemplarCity => q#Չագոս#,
		},
		'Indian/Christmas' => {
			exemplarCity => q#Սուրբ Ծննդյան կղզի#,
		},
		'Indian/Cocos' => {
			exemplarCity => q#Կոկոսյան կղզիներ#,
		},
		'Indian/Comoro' => {
			exemplarCity => q#Կոմորյան կղզիներ#,
		},
		'Indian/Kerguelen' => {
			exemplarCity => q#Կերգելեն#,
		},
		'Indian/Mahe' => {
			exemplarCity => q#Մաէ#,
		},
		'Indian/Maldives' => {
			exemplarCity => q#Մալդիվներ#,
		},
		'Indian/Mauritius' => {
			exemplarCity => q#Մավրիկիոս#,
		},
		'Indian/Mayotte' => {
			exemplarCity => q#Մայոթ#,
		},
		'Indian/Reunion' => {
			exemplarCity => q#Ռեյունիոն#,
		},
		'Indian_Ocean' => {
			long => {
				'standard' => q#Հնդկական օվկիանոսի ժամանակ#,
			},
		},
		'Indochina' => {
			long => {
				'standard' => q#Հնդկաչինական ժամանակ#,
			},
		},
		'Indonesia_Central' => {
			long => {
				'standard' => q#Կենտրոնական Ինդոնեզիայի ժամանակ#,
			},
		},
		'Indonesia_Eastern' => {
			long => {
				'standard' => q#Արևելյան Ինդոնեզիայի ժամանակ#,
			},
		},
		'Indonesia_Western' => {
			long => {
				'standard' => q#Արևմտյան Ինդոնեզիայի ժամանակ#,
			},
		},
		'Iran' => {
			long => {
				'daylight' => q#Իրանի ամառային ժամանակ#,
				'generic' => q#Իրանի ժամանակ#,
				'standard' => q#Իրանի ստանդարտ ժամանակ#,
			},
		},
		'Irkutsk' => {
			long => {
				'daylight' => q#Իրկուտսկի ամառային ժամանակ#,
				'generic' => q#Իրկուտսկի ժամանակ#,
				'standard' => q#Իրկուտսկի ստանդարտ ժամանակ#,
			},
		},
		'Israel' => {
			long => {
				'daylight' => q#Իսրայելի ամառային ժամանակ#,
				'generic' => q#Իսրայելի ժամանակ#,
				'standard' => q#Իսրայելի ստանդարտ ժամանակ#,
			},
		},
		'Japan' => {
			long => {
				'daylight' => q#Ճապոնիայի ամառային ժամանակ#,
				'generic' => q#Ճապոնիայի ժամանակ#,
				'standard' => q#Ճապոնիայի ստանդարտ ժամանակ#,
			},
		},
		'Kazakhstan_Eastern' => {
			long => {
				'standard' => q#Արևելյան Ղազախստանի ժամանակ#,
			},
		},
		'Kazakhstan_Western' => {
			long => {
				'standard' => q#Արևմտյան Ղազախստանի ժամանակ#,
			},
		},
		'Korea' => {
			long => {
				'daylight' => q#Կորեայի ամառային ժամանակ#,
				'generic' => q#Կորեայի ժամանակ#,
				'standard' => q#Կորեայի ստանդարտ ժամանակ#,
			},
		},
		'Kosrae' => {
			long => {
				'standard' => q#Կոսրաեյի ժամանակ#,
			},
		},
		'Krasnoyarsk' => {
			long => {
				'daylight' => q#Կրասնոյարսկի ամառային ժամանակ#,
				'generic' => q#Կրասնոյարսկի ժամանակ#,
				'standard' => q#Կրասնոյարսկի ստանդարտ ժամանակ#,
			},
		},
		'Kyrgystan' => {
			long => {
				'standard' => q#Ղրղզստանի ժամանակ#,
			},
		},
		'Line_Islands' => {
			long => {
				'standard' => q#Լայն կղզիների ժամանակ#,
			},
		},
		'Lord_Howe' => {
			long => {
				'daylight' => q#Լորդ Հաուի ամառային ժամանակ#,
				'generic' => q#Լորդ Հաուի ժամանակ#,
				'standard' => q#Լորդ Հաուի ստանդարտ ժամանակ#,
			},
		},
		'Macquarie' => {
			long => {
				'standard' => q#Մակկուորի կղզու ժամանակ#,
			},
		},
		'Magadan' => {
			long => {
				'daylight' => q#Մագադանի ամառային ժամանակ#,
				'generic' => q#Մագադանի ժամանակ#,
				'standard' => q#Մագադանի ստանդարտ ժամանակ#,
			},
		},
		'Malaysia' => {
			long => {
				'standard' => q#Մալայզիայի ժամանակ#,
			},
		},
		'Maldives' => {
			long => {
				'standard' => q#Մալդիվների ժամանակ#,
			},
		},
		'Marquesas' => {
			long => {
				'standard' => q#Մարկիզյան կղզիների ժամանակ#,
			},
		},
		'Marshall_Islands' => {
			long => {
				'standard' => q#Մարշալյան կղզիների ժամանակ#,
			},
		},
		'Mauritius' => {
			long => {
				'daylight' => q#Մավրիկիոսի ամառային ժամանակ#,
				'generic' => q#Մավրիկիոսի ժամանակ#,
				'standard' => q#Մավրիկիոսի ստանդարտ ժամանակ#,
			},
		},
		'Mawson' => {
			long => {
				'standard' => q#Մոուսոնի ժամանակ#,
			},
		},
		'Mexico_Northwest' => {
			long => {
				'daylight' => q#Հյուսիսարևմտյան Մեքսիկայի ամառային ժամանակ#,
				'generic' => q#Հյուսիսարևմտյան Մեքսիկայի ժամանակ#,
				'standard' => q#Հյուսիսարևմտյան Մեքսիկայի ստանդարտ ժամանակ#,
			},
		},
		'Mexico_Pacific' => {
			long => {
				'daylight' => q#Մեքսիկայի խաղաղօվկիանոսյան ամառային ժամանակ#,
				'generic' => q#Մեքսիկայի խաղաղօվկիանոսյան ժամանակ#,
				'standard' => q#Մեքսիկայի խաղաղօվկիանոսյան ստանդարտ ժամանակ#,
			},
		},
		'Mongolia' => {
			long => {
				'daylight' => q#Ուլան Բատորի ամառային ժամանակ#,
				'generic' => q#Ուլան Բատորի ժամանակ#,
				'standard' => q#Ուլան Բատորի ստանդարտ ժամանակ#,
			},
		},
		'Moscow' => {
			long => {
				'daylight' => q#Մոսկվայի ամառային ժամանակ#,
				'generic' => q#Մոսկվայի ժամանակ#,
				'standard' => q#Մոսկվայի ստանդարտ ժամանակ#,
			},
		},
		'Myanmar' => {
			long => {
				'standard' => q#Մյանմայի ժամանակ#,
			},
		},
		'Nauru' => {
			long => {
				'standard' => q#Նաուրուի ժամանակ#,
			},
		},
		'Nepal' => {
			long => {
				'standard' => q#Նեպալի ժամանակ#,
			},
		},
		'New_Caledonia' => {
			long => {
				'daylight' => q#Նոր Կալեդոնիայի ամառային ժամանակ#,
				'generic' => q#Նոր Կալեդոնիայի ժամանակ#,
				'standard' => q#Նոր Կալեդոնիայի ստանդարտ ժամանակ#,
			},
		},
		'New_Zealand' => {
			long => {
				'daylight' => q#Նոր Զելանդիայի ամառային ժամանակ#,
				'generic' => q#Նոր Զելանդիայի ժամանակ#,
				'standard' => q#Նոր Զելանդիայի ստանդարտ ժամանակ#,
			},
		},
		'Newfoundland' => {
			long => {
				'daylight' => q#Նյուֆաունդլենդի ամառային ժամանակ#,
				'generic' => q#Նյուֆաունդլենդի ժամանակ#,
				'standard' => q#Նյուֆաունդլենդի ստանդարտ ժամանակ#,
			},
		},
		'Niue' => {
			long => {
				'standard' => q#Նիուեյի ժամանակ#,
			},
		},
		'Norfolk' => {
			long => {
				'daylight' => q#Նորֆոլկ կղզու ամառային ժամանակ#,
				'generic' => q#Նորֆոլկ կղզու ժամանակ#,
				'standard' => q#Նորֆոլկ կղզու ստանդարտ ժամանակ#,
			},
		},
		'Noronha' => {
			long => {
				'daylight' => q#Ֆերնանդու դի Նորոնյայի ամառային ժամանակ#,
				'generic' => q#Ֆերնանդու դի Նորոնյայի ժամանակ#,
				'standard' => q#Ֆերնանդու դի Նորոնյայի ստանդարտ ժամանակ#,
			},
		},
		'Novosibirsk' => {
			long => {
				'daylight' => q#Նովոսիբիրսկի ամառային ժամանակ#,
				'generic' => q#Նովոսիբիրսկի ժամանակ#,
				'standard' => q#Նովոսիբիրսկի ստանդարտ ժամանակ#,
			},
		},
		'Omsk' => {
			long => {
				'daylight' => q#Օմսկի ամառային ժամանակ#,
				'generic' => q#Օմսկի ժամանակ#,
				'standard' => q#Օմսկի ստանդարտ ժամանակ#,
			},
		},
		'Pacific/Apia' => {
			exemplarCity => q#Ապիա#,
		},
		'Pacific/Auckland' => {
			exemplarCity => q#Օքլենդ#,
		},
		'Pacific/Bougainville' => {
			exemplarCity => q#Բուգենվիլ#,
		},
		'Pacific/Chatham' => {
			exemplarCity => q#Չաթեմ կղզի#,
		},
		'Pacific/Easter' => {
			exemplarCity => q#Զատկի կղզի#,
		},
		'Pacific/Efate' => {
			exemplarCity => q#Էֆատե#,
		},
		'Pacific/Enderbury' => {
			exemplarCity => q#Էնդերբերի կղզի#,
		},
		'Pacific/Fakaofo' => {
			exemplarCity => q#Ֆակաոֆո#,
		},
		'Pacific/Fiji' => {
			exemplarCity => q#Ֆիջի#,
		},
		'Pacific/Funafuti' => {
			exemplarCity => q#Ֆունաֆուտի#,
		},
		'Pacific/Galapagos' => {
			exemplarCity => q#Գալապագոսյան կղզիներ#,
		},
		'Pacific/Gambier' => {
			exemplarCity => q#Գամբյե կղզիներ#,
		},
		'Pacific/Guadalcanal' => {
			exemplarCity => q#Գուադալկանալ#,
		},
		'Pacific/Guam' => {
			exemplarCity => q#Գուամ#,
		},
		'Pacific/Honolulu' => {
			exemplarCity => q#Հոնոլուլու#,
		},
		'Pacific/Johnston' => {
			exemplarCity => q#Ջոնսթոն#,
		},
		'Pacific/Kanton' => {
			exemplarCity => q#Կանտոն#,
		},
		'Pacific/Kiritimati' => {
			exemplarCity => q#Կիրիտիմատի#,
		},
		'Pacific/Kosrae' => {
			exemplarCity => q#Կոսրաե#,
		},
		'Pacific/Kwajalein' => {
			exemplarCity => q#Քվաջալեյն#,
		},
		'Pacific/Majuro' => {
			exemplarCity => q#Մաջուրո#,
		},
		'Pacific/Marquesas' => {
			exemplarCity => q#Մարկիզյան կղզիներ#,
		},
		'Pacific/Midway' => {
			exemplarCity => q#Միդուեյ կղզի#,
		},
		'Pacific/Nauru' => {
			exemplarCity => q#Նաուրու#,
		},
		'Pacific/Niue' => {
			exemplarCity => q#Նիուե#,
		},
		'Pacific/Norfolk' => {
			exemplarCity => q#Նորֆոլկ#,
		},
		'Pacific/Noumea' => {
			exemplarCity => q#Նումեա#,
		},
		'Pacific/Pago_Pago' => {
			exemplarCity => q#Պագո Պագո#,
		},
		'Pacific/Palau' => {
			exemplarCity => q#Պալաու#,
		},
		'Pacific/Pitcairn' => {
			exemplarCity => q#Պիտկեռն#,
		},
		'Pacific/Ponape' => {
			exemplarCity => q#Պոնպեի#,
		},
		'Pacific/Port_Moresby' => {
			exemplarCity => q#Պորտ Մորսբի#,
		},
		'Pacific/Rarotonga' => {
			exemplarCity => q#Ռարոտոնգա#,
		},
		'Pacific/Saipan' => {
			exemplarCity => q#Սայպան#,
		},
		'Pacific/Tahiti' => {
			exemplarCity => q#Թաիթի#,
		},
		'Pacific/Tarawa' => {
			exemplarCity => q#Տարավա#,
		},
		'Pacific/Tongatapu' => {
			exemplarCity => q#Տոնգատապու#,
		},
		'Pacific/Truk' => {
			exemplarCity => q#Չուուկ#,
		},
		'Pacific/Wake' => {
			exemplarCity => q#Ուեյք կղզի#,
		},
		'Pacific/Wallis' => {
			exemplarCity => q#Ուոլիս#,
		},
		'Pakistan' => {
			long => {
				'daylight' => q#Պակիստանի ամառային ժամանակ#,
				'generic' => q#Պակիստանի ժամանակ#,
				'standard' => q#Պակիստանի ստանդարտ ժամանակ#,
			},
		},
		'Palau' => {
			long => {
				'standard' => q#Պալաույի ժամանակ#,
			},
		},
		'Papua_New_Guinea' => {
			long => {
				'standard' => q#Պապուա Նոր Գվինեայի ժամանակ#,
			},
		},
		'Paraguay' => {
			long => {
				'daylight' => q#Պարագվայի ամառային ժամանակ#,
				'generic' => q#Պարագվայի ժամանակ#,
				'standard' => q#Պարագվայի ստանդարտ ժամանակ#,
			},
		},
		'Peru' => {
			long => {
				'daylight' => q#Պերուի ամառային ժամանակ#,
				'generic' => q#Պերուի ժամանակ#,
				'standard' => q#Պերուի ստանդարտ ժամանակ#,
			},
		},
		'Philippines' => {
			long => {
				'daylight' => q#Ֆիլիպինների ամառային ժամանակ#,
				'generic' => q#Ֆիլիպինների ժամանակ#,
				'standard' => q#Ֆիլիպինների ստանդարտ ժամանակ#,
			},
		},
		'Phoenix_Islands' => {
			long => {
				'standard' => q#Ֆինիքս կղզիների ժամանակ#,
			},
		},
		'Pierre_Miquelon' => {
			long => {
				'daylight' => q#Սեն Պիեռ և Միքելոնի ամառային ժամանակ#,
				'generic' => q#Սեն Պիեռ և Միքելոնի ժամանակ#,
				'standard' => q#Սեն Պիեռ և Միքելոնի ստանդարտ ժամանակ#,
			},
		},
		'Pitcairn' => {
			long => {
				'standard' => q#Պիտկեռնի ժամանակ#,
			},
		},
		'Ponape' => {
			long => {
				'standard' => q#Պոնապե կղզու ժամանակ#,
			},
		},
		'Pyongyang' => {
			long => {
				'standard' => q#Փխենյանի ժամանակ#,
			},
		},
		'Reunion' => {
			long => {
				'standard' => q#Ռեյունիոնի ժամանակ#,
			},
		},
		'Rothera' => {
			long => {
				'standard' => q#Ռոտերայի ժամանակ#,
			},
		},
		'Sakhalin' => {
			long => {
				'daylight' => q#Սախալինի ամառային ժամանակ#,
				'generic' => q#Սախալինի ժամանակ#,
				'standard' => q#Սախալինի ստանդարտ ժամանակ#,
			},
		},
		'Samoa' => {
			long => {
				'daylight' => q#Սամոայի ամառային ժամանակ#,
				'generic' => q#Սամոայի ժամանակ#,
				'standard' => q#Սամոայի ստանդարտ ժամանակ#,
			},
		},
		'Seychelles' => {
			long => {
				'standard' => q#Սեյշելյան կղզիների ժամանակ#,
			},
		},
		'Singapore' => {
			long => {
				'standard' => q#Սինգապուրի ժամանակ#,
			},
		},
		'Solomon' => {
			long => {
				'standard' => q#Սողոմոնի կղզիների ժամանակ#,
			},
		},
		'South_Georgia' => {
			long => {
				'standard' => q#Հարավային Ջորջիայի ժամանակ#,
			},
		},
		'Suriname' => {
			long => {
				'standard' => q#Սուրինամի ժամանակ#,
			},
		},
		'Syowa' => {
			long => {
				'standard' => q#Սյովայի ժամանակ#,
			},
		},
		'Tahiti' => {
			long => {
				'standard' => q#Թաիթիի ժամանակ#,
			},
		},
		'Taipei' => {
			long => {
				'daylight' => q#Թայպեյի ամառային ժամանակ#,
				'generic' => q#Թայպեյի ժամանակ#,
				'standard' => q#Թայպեյի ստանդարտ ժամանակ#,
			},
		},
		'Tajikistan' => {
			long => {
				'standard' => q#Տաջիկստանի ժամանակ#,
			},
		},
		'Tokelau' => {
			long => {
				'standard' => q#Տոկելաույի ժամանակ#,
			},
		},
		'Tonga' => {
			long => {
				'daylight' => q#Տոնգայի ամառային ժամանակ#,
				'generic' => q#Տոնգայի ժամանակ#,
				'standard' => q#Տոնգայի ստանդարտ ժամանակ#,
			},
		},
		'Truk' => {
			long => {
				'standard' => q#Տրուկի ժամանակ#,
			},
		},
		'Turkmenistan' => {
			long => {
				'daylight' => q#Թուրքմենստանի ամառային ժամանակ#,
				'generic' => q#Թուրքմենստանի ժամանակ#,
				'standard' => q#Թուրքմենստանի ստանդարտ ժամանակ#,
			},
		},
		'Tuvalu' => {
			long => {
				'standard' => q#Տուվալույի ժամանակ#,
			},
		},
		'Uruguay' => {
			long => {
				'daylight' => q#Ուրուգվայի ամառային ժամանակ#,
				'generic' => q#Ուրուգվայի ժամանակ#,
				'standard' => q#Ուրուգվայի ստանդարտ ժամանակ#,
			},
		},
		'Uzbekistan' => {
			long => {
				'daylight' => q#Ուզբեկստանի ամառային ժամանակ#,
				'generic' => q#Ուզբեկստանի ժամանակ#,
				'standard' => q#Ուզբեկստանի ստանդարտ ժամանակ#,
			},
		},
		'Vanuatu' => {
			long => {
				'daylight' => q#Վանուատույի ամառային ժամանակ#,
				'generic' => q#Վանուատույի ժամանակ#,
				'standard' => q#Վանուատույի ստանդարտ ժամանակ#,
			},
		},
		'Venezuela' => {
			long => {
				'standard' => q#Վենեսուելայի ժամանակ#,
			},
		},
		'Vladivostok' => {
			long => {
				'daylight' => q#Վլադիվոստոկի ամառային ժամանակ#,
				'generic' => q#Վլադիվոստոկի ժամանակ#,
				'standard' => q#Վլադիվոստոկի ստանդարտ ժամանակ#,
			},
		},
		'Volgograd' => {
			long => {
				'daylight' => q#Վոլգոգրադի ամառային ժամանակ#,
				'generic' => q#Վոլգոգրադի ժամանակ#,
				'standard' => q#Վոլգոգրադի ստանդարտ ժամանակ#,
			},
		},
		'Vostok' => {
			long => {
				'standard' => q#Վոստոկի ժամանակ#,
			},
		},
		'Wake' => {
			long => {
				'standard' => q#Ուեյք կղզու ժամանակ#,
			},
		},
		'Wallis' => {
			long => {
				'standard' => q#Ուոլիս և Ֆուտունայի ժամանակ#,
			},
		},
		'Yakutsk' => {
			long => {
				'daylight' => q#Յակուտսկի ամառային ժամանակ#,
				'generic' => q#Յակուտսկի ժամանակ#,
				'standard' => q#Յակուտսկի ստանդարտ ժամանակ#,
			},
		},
		'Yekaterinburg' => {
			long => {
				'daylight' => q#Եկատերինբուրգի ամառային ժամանակ#,
				'generic' => q#Եկատերինբուրգի ժամանակ#,
				'standard' => q#Եկատերինբուրգի ստանդարտ ժամանակ#,
			},
		},
		'Yukon' => {
			long => {
				'standard' => q#Յուկոնի ժամանակ#,
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
